Generated Factorio runtime API bindings.
These types exist for Rust type-checking and IDE support. Mod code is transpiled to Lua and never executes these stub implementations.
Re-exports
pub use event_filters::EventFilterEntry;pub use event_filters::FilterMethodSpec;pub use event_filters::filter_method_spec;pub use map::event_filter_type;pub use map::event_type_to_name;pub use unions::literal_enum_variant_str;
Modules
Structs
- LuaAny
- Opaque placeholder for complex Factorio Lua API values.
Traits
- LuaObject
- Marker trait for autogenerated Factorio API types. Do not implement this trait manually.
- Setting
Value - Marker trait for types that can be used as Factorio mod setting values.