Module classes

Module classes 

Structs

LuaAISettings
Collection of settings for overriding default AI behavior.
LuaAccumulatorControlBehavior
Control behavior for accumulators.
LuaAchievementPrototype
Prototype of a achievement.
LuaActiveTriggerPrototype
Prototype of an Active Trigger.
LuaAgriculturalTowerControlBehavior
Control behavior for agricultural tower
LuaAirbornePollutantPrototype
Airborne pollutant prototype.
LuaAmmoCategoryPrototype
Prototype of a ammo category.
LuaArithmeticCombinatorControlBehavior
Control behavior for arithmetic combinators.
LuaArtilleryTurretControlBehavior
Control behavior for artillery turrets.
LuaAssemblingMachineControlBehavior
Control behavior for assembling machines.
LuaAsteroidChunkPrototype
Prototype of an asteroid chunk.
LuaAsteroidCollectorControlBehavior
Control behavior for asteroid collectors.
LuaAutoplaceControlPrototype
Prototype of an autoplace control.
LuaBoilerControlBehavior
Control behavior for boiler.
LuaBootstrap
Entry point for registering event handlers. It is accessible through the global object named script.
LuaBootstrapFeatureFlags
LuaBootstrapLevel
LuaBootstrapRaiseBiterBaseBuiltParams
LuaBootstrapRaiseConsoleChatParams
LuaBootstrapRaiseMarketItemPurchasedParams
LuaBootstrapRaisePlayerCraftedItemParams
LuaBootstrapRaisePlayerFastTransferredParams
LuaBootstrapRaiseScriptBuiltParams
LuaBootstrapRaiseScriptDestroyParams
LuaBootstrapRaiseScriptDestroySegmentedUnitParams
LuaBootstrapRaiseScriptReviveParams
LuaBootstrapRaiseScriptSetTilesParams
LuaBootstrapRaiseScriptTeleportedParams
LuaBurner
A reference to the burner energy source owned by a specific LuaEntity or LuaEquipment.
LuaBurnerPrototype
Prototype of a burner energy source.
LuaBurnerPrototypeLightFlicker
LuaBurnerUsagePrototype
Description of burner usage.
LuaCargoHatch
A cargo hatch.
LuaCargoLandingPadControlBehavior
Control behavior for cargo landing pad.
LuaChunkIterator
A chunk iterator can be used for iterating chunks coordinates of a surface.
LuaCircuitNetwork
A circuit network associated with a given entity, connector, and wire type.
LuaCollisionLayerPrototype
Prototype of a collision layer.
LuaCombinatorControlBehavior
LuaCommandProcessor
Allows for the registration of custom console commands through the global object named commands. Similarly to event subscriptions, these don’t persist through a save-and-load cycle.
LuaCommandable
AI object which can be ordered commands. This can represent a UnitGroup (a set of multiple commandables) or can be a single Unit or SpiderUnit.
LuaConstantCombinatorControlBehavior
Control behavior for constant combinators.
LuaContainerControlBehavior
Control behavior for container entities.
LuaControl
This is an abstract base class containing the common functionality between LuaPlayer and entities (see LuaEntity). When accessing player-related functions through a LuaEntity, it must refer to a character entity.
LuaControlBeginCraftingParams
Begins crafting the given count of the given recipe.
LuaControlBehavior
The control behavior for an entity. Inserters have logistic network and circuit network behavior logic, lamps have circuit logic and so on. This is an abstract base class that concrete control behaviors inherit.
LuaControlCanPlaceEntityParams
Checks if this character or player can build the given entity at the given location on the surface the character or player is on.
LuaControlCancelCraftingParams
Cancels the given amount of crafts at the given crafting queue position. If this causes any later crafts that depend on the cancelled one to have insufficient ingredients, those crafts will also be cancelled.
LuaControlMiningState
LuaControlRepairState
LuaControlSetGuiArrowParams
Create an arrow which points at this entity. This is used in the tutorial. For examples, see control.lua in the campaign missions.
LuaControlShootingState
LuaControlWalkingState
LuaCustomChartTag
A custom tag that shows on the map view.
LuaCustomEventPrototype
Prototype of a custom event.
LuaCustomInputPrototype
Prototype of a custom input.
LuaCustomTable
Lazily evaluated table. For performance reasons, we sometimes return a custom table-like type instead of a native Lua table. This custom type lazily constructs the necessary Lua wrappers of the corresponding C++ objects, therefore preventing their unnecessary construction in some cases.
LuaDamagePrototype
Prototype of a damage.
LuaDebugAdapter
Factorio provides a Debug Adapter for compatible tools in single-session mode on stdin/stdout when launched with the --dap command line argument.
LuaDebugAdapterStartProfileParams
Start recording profiler timings. If there is a previous recording session running, it will be stopped first.
LuaDeciderCombinatorControlBehavior
Control behavior for decider combinators.
LuaDecorativePrototype
Prototype of an optimized decorative.
LuaDisplayPanelControlBehavior
Control behavior for display panels.
LuaElectricEnergySourcePrototype
Prototype of an electric energy source.
LuaElectricNetwork
A LuaElectricNetwork represents a group of LuaElectricSubNetworks that are directly or indirectly connected to each other through implicit connections (closed power switches, surface connections) and during next electric network update will transfer electricity from producers and consumers.
LuaElectricNetworkFlowLastTick
LuaElectricNetworkGetAccumulatorsEnergyParams
Gets total energy stored inside of accumulators that are part of any electric sub network covered by this electric network.
LuaElectricNetworkSetAccumulatorsEnergyParams
Changes energy stored inside of accumulators that are part of any electric sub network covered by this electric network.
LuaElectricSubNetwork
A LuaElectricSubNetwork represents an electricity supply group.
LuaElectricSubNetworkGetAccumulatorsEnergyParams
Gets total energy stored inside of accumulators connected to the electric sub network.
LuaElectricSubNetworkSetAccumulatorsEnergyParams
Changes energy stored inside of accumulators connected to the electric sub network.
LuaEntity
The primary interface for interacting with entities through the Lua API. Entities are everything that exists on the map except for tiles (see LuaTile).
LuaEntityBeltNeighbours
LuaEntityCliffNeighbours
LuaEntityCloneParams
Clones this entity.
LuaEntityCreateCargoPodParams
Creates a cargo pod if possible.
LuaEntityDestroyParams
Destroys the entity.
LuaEntityExtractFluidParams
Remove fluid from this entity.
LuaEntityFlipParams
Flips this entity
LuaEntityGetConnectedRailParams
LuaEntityMineParams
Mines this entity.
LuaEntityOrderUpgradeParams
Sets the entity to be upgraded by construction robots.
LuaEntityPrototype
Prototype of an entity.
LuaEntityPrototypeCreatedSmoke
LuaEntityPrototypeLogisticParameters
LuaEntityPrototypeSpawnCooldown
LuaEntityPrototypeStickerMovementModifiers
LuaEntityPrototypeStickerVehicleModifiers
LuaEntityReviveParams
Revive a ghost, which turns it from a ghost into a real entity or tile.
LuaEntityRotateParams
Rotates this entity as if the player rotated it.
LuaEntitySilentReviveParams
Revives a ghost silently, so the revival makes no sound and no smoke is created.
LuaEntityStickerVehicleModifiers
LuaEntityWallNeighbours
LuaEquipment
An item in a LuaEquipmentGrid, for example a fusion reactor placed in one’s power armor.
LuaEquipmentCategoryPrototype
Prototype of an equipment category.
LuaEquipmentGrid
An equipment grid is for example the inside of a power armor.
LuaEquipmentGridCanMoveParams
Check whether moving an equipment would succeed.
LuaEquipmentGridMoveParams
Move an equipment within this grid.
LuaEquipmentGridPrototype
Prototype of an equipment grid.
LuaEquipmentGridPutParams
Insert an equipment into the grid.
LuaEquipmentGridTakeParams
Remove an equipment from the grid.
LuaEquipmentPrototype
Prototype of a modular equipment.
LuaEquipmentPrototypeLogisticParameters
LuaEquipmentPrototypeShape
LuaEquipmentShape
LuaFlowStatistics
Encapsulates statistic data for different parts of the game.
LuaFlowStatisticsGetFlowCountParams
Gets the flow count value for the given time frame. If sample_index is not provided, then the value returned is the average across the provided precision time period. These are the values shown in the bottom section of the statistics GUIs.
LuaFluidBoxPrototype
A prototype of a fluidbox owned by some LuaEntityPrototype.
LuaFluidEnergySourcePrototype
Prototype of a fluid energy source.
LuaFluidPrototype
Prototype of a fluid.
LuaFontPrototype
Prototype of a font.
LuaForce
LuaForce encapsulates data local to each “force” or “faction” of the game. Default forces are player, enemy and neutral. Players and mods can create additional forces (up to 64 total).
LuaForceCreateSpacePlatformParams
Creates a new space platform on this force.
LuaFuelCategoryPrototype
Prototype of a fuel category.
LuaFurnaceControlBehavior
Control behavior for furnaces.
LuaGameScript
Main toplevel type, provides access to most of the API though its members. An instance of LuaGameScript is available as the global object named game.
LuaGameScriptGetVehiclesParams
Returns vehicles in game.
LuaGameScriptSetGameStateParams
Set scenario state. Any parameters not provided do not change the current state.
LuaGameScriptSetLoseEndingInfoParams
Set losing ending information for the current scenario.
LuaGameScriptSetWinEndingInfoParams
Set winning ending information for the current scenario.
LuaGameScriptShowMessageDialogParams
Show an in-game message dialog.
LuaGameScriptTakeScreenshotParams
Take a screenshot of the game and save it to the script-output folder, located in the game’s user data directory. The name of the image file can be specified via the path parameter.
LuaGameScriptTakeTechnologyScreenshotParams
Take a screenshot of the technology screen and save it to the script-output folder, located in the game’s user data directory. The name of the image file can be specified via the path parameter.
LuaGenericOnOffControlBehavior
An abstract base class for behaviors that support switching the entity on or off based on some condition.
LuaGroup
Item group or subgroup.
LuaGui
The root of the GUI. This type houses the root elements, top, left, center, goal, and screen, to which other elements can be added to be displayed on screen.
LuaGuiElement
An element of a custom GUI. This type is used to represent any kind of a GUI element - labels, buttons and frames are all instances of this type. Just like LuaEntity, different kinds of elements support different attributes; attempting to access an attribute on an element that doesn’t support it (for instance, trying to access the column_count of a textfield) will result in a runtime error.
LuaGuiElementAddParams
Add a new child element to this GuiElement.
LuaHeatBufferPrototype
Prototype of a heat buffer.
LuaHeatEnergySourcePrototype
Prototype of a heat energy source.
LuaHeatPipeControlBehavior
Control behavior for heat pipe
LuaHelpers
Provides various helper and utility functions. It is accessible through the global object named helpers in all stages (settings, prototype and runtime).
LuaInserterControlBehavior
Control behavior for inserters.
LuaInventory
A storage of item stacks.
LuaItem
A reference to an item with data. In contrast to LuaItemStack, this is binding to a specific item data even if it would move between entities or inventories.
LuaItemCommon
Common methods related to usage of item with data. It is useful when LuaItemStack contains item with data or in general with LuaItem as it can only point at an item with data.
LuaItemCommonBuildBlueprintParams
Build this blueprint at the given location.
LuaItemCommonCancelDeconstructAreaParams
Cancel deconstruct the given area with this deconstruction item.
LuaItemCommonCreateBlueprintParams
Sets up this blueprint using the found blueprintable entities/tiles on the surface.
LuaItemCommonDeconstructAreaParams
Deconstruct the given area with this deconstruction item.
LuaItemPrototype
Prototype of an item. For example, an item prototype can be obtained from LuaPrototypes::item by its name: prototypes.item["iron-plate"].
LuaItemStack
A reference to an item and count owned by some external entity.
LuaLabControlBehavior
Control behavior for lab.
LuaLampControlBehavior
Control behavior for lamps.
LuaLandMineControlBehavior
Control behavior for land mines.
LuaLazyLoadedValue
A lazily loaded value. For performance reasons, we sometimes return a custom lazily-loaded value type instead of the native Lua value. This custom type lazily constructs the necessary value when LuaLazyLoadedValue::get is called, therefore preventing its unnecessary construction in some cases.
LuaLoaderControlBehavior
Control behavior for loaders.
LuaLogisticCell
Logistic cell of a particular LuaEntity. A “Logistic Cell” is the given name for settings and properties used by what would normally be seen as a “Roboport”. A logistic cell however doesn’t have to be attached to the roboport entity (the character has one for the personal roboport).
LuaLogisticContainerControlBehavior
Control behavior for logistic chests.
LuaLogisticNetwork
A single logistic network of a given force on a given surface.
LuaLogisticNetworkSelectDropPointParams
Find a logistic point to drop the specific item stack.
LuaLogisticNetworkSelectPickupPointParams
Find the ‘best’ logistic point with this item ID and from the given position or from given chest type.
LuaLogisticPoint
Logistic point of a particular LuaEntity. A “Logistic point” is the name given for settings and properties used by requester, provider, and storage points in a given logistic network. These “points” don’t have to be a logistic container but often are. One other entity that can own several points is the “character” character type entity.
LuaLogisticSection
Logistic section of a particular LuaLogisticPoint or LuaConstantCombinatorControlBehavior.
LuaLogisticSections
Logistic sections of an entity.
LuaMiningDrillControlBehavior
Control behavior for mining drills.
LuaModData
Arbitrary data provided by mods.
LuaModSettingPrototype
Prototype of a mod setting.
LuaModuleCategoryPrototype
Prototype of a module category.
LuaNamedNoiseExpression
Prototype of a named noise expression.
LuaNamedNoiseFunction
Prototype of a named noise function.
LuaNotificationQueue
Object that keeps track of objects invalidation and queues notifications for when object becomes invalid.
LuaParticlePrototype
Prototype of an optimized particle.
LuaPermissionGroup
A permission group that defines what players in this group are allowed to do.
LuaPermissionGroups
All permission groups.
LuaPlanet
The runtime values of a planet
LuaPlayer
A player in the game. Pay attention that a player may or may not have a character, which is the LuaEntity of the little guy running around the world doing things.
LuaPlayerAddPinParams
Adds a pin to this player for the given pin specification. Either entity, player, or surface and position must be defined.
LuaPlayerBuildFromCursorParams
Builds whatever is in the cursor on the surface the player is on. The cursor stack will automatically be reduced as if the player built normally.
LuaPlayerCanBuildFromCursorParams
Checks if this player can build what ever is in the cursor on the surface the player is on.
LuaPlayerConnectToServerParams
Asks the player if they would like to connect to the given server.
LuaPlayerCreateLocalFlyingTextParams
Spawn flying text that is only visible to this player. Either position or create_at_cursor are required. When create_at_cursor is true, all parameters other than text are ignored.
LuaPlayerDragWireParams
Start/end wire dragging at the specified location, wire type is based on the cursor contents
LuaPlayerSetControllerParams
Set the controller type of the player.
LuaPlayerStackTransfersParams
Performs the given transfer action between the source and target as if the player did the action.
LuaProcessionLayerInheritanceGroupPrototype
Prototype of a procession inheritance group which synchronizes offsets between procession steps.
LuaProcessionPrototype
Prototype of a procession.
LuaProfiler
An object used to measure script performance.
LuaProgrammableSpeakerControlBehavior
Control behavior for programmable speakers.
LuaPrototypeBase
Base for all prototype classes.
LuaPrototypes
Provides read-only access to prototypes. It is accessible through the global object named prototypes.
LuaProxyContainerControlBehavior
Control behavior for proxy container.
LuaPumpControlBehavior
Control behavior for pumps.
LuaQualityPrototype
Prototype of a quality.
LuaRCON
An interface to send messages to the calling RCON interface through the global object named rcon.
LuaRadarControlBehavior
Control behavior for radars
LuaRailEnd
Utility object that binds to a rail entity and rail_direction to allow easier traversal over rails
LuaRailPath
A rail path.
LuaRailSignalBaseControlBehavior
Control behavior for rail signals and rail chain signals.
LuaRandomGenerator
A deterministic random generator independent from the core games random generator that can be seeded and re-seeded at will. This random generator can be saved and loaded and will maintain its state.
LuaReactorControlBehavior
Control behavior for Reactor
LuaRecipe
A crafting recipe. Recipes belong to forces (see LuaForce) because some recipes are unlocked by research, and researches are per-force.
LuaRecipeCategoryPrototype
Prototype of a recipe category.
LuaRecipePrototype
A crafting recipe prototype.
LuaRecord
A reference to a record in the blueprint library. Records in the “my blueprints” shelf are read-only, but records in the “game blueprints” shelf are read/write.
LuaRecordBuildBlueprintParams
Build this blueprint at the given location.
LuaRecordCancelDeconstructAreaParams
Cancel deconstruct the given area with this deconstruction planner.
LuaRecordCreateBlueprintParams
Sets up this blueprint using the found blueprintable entities/tiles on the surface.
LuaRecordDeconstructAreaParams
Deconstruct the given area with this deconstruction planner.
LuaRemote
Registry of interfaces between scripts. An interface is simply a dictionary mapping names to functions. A script or mod can then register an interface with LuaRemote, after that any script can call the registered functions, provided it knows the interface name and the desired function name. An instance of LuaRemote is available through the global object named remote.
LuaRenderObject
Reference to a single LuaRendering object.
LuaRendering
Allows rendering of geometric shapes, text and sprites in the game world through the global object named rendering. Each render object is identified by an id that is universally unique for the lifetime of a whole game.
LuaRenderingDrawAnimationParams
Create an animation.
LuaRenderingDrawArcParams
Create an arc.
LuaRenderingDrawCircleParams
Create a circle.
LuaRenderingDrawLightParams
Create a gradient light which is not occluded by any sprites. It is rendered at lower resolution, so it takes less GPU power. The same technique is used for lights drawn by LightDefinition.
LuaRenderingDrawLineParams
Create a line.
LuaRenderingDrawPolygonParams
Create a triangle mesh defined by a triangle strip.
LuaRenderingDrawRectangleParams
Create a rectangle.
LuaRenderingDrawSpriteParams
Create a sprite.
LuaRenderingDrawTextParams
Create a text.
LuaResourceCategoryPrototype
Prototype of a resource category.
LuaRoboportControlBehavior
Control behavior for roboports.
LuaRocketSiloControlBehavior
Control behavior for rocket silos.
LuaSchedule
The schedule of a particular LuaTrain or LuaSpacePlatform.
LuaSegment
An individual segment of a LuaSegmentedUnit. If the segment exists in a generated chunk, you can access the entity representation using LuaSegment::entity.
LuaSegmentedUnit
A surface-level object composed of one SegmentedUnitPrototype followed by up to 63 SegmentPrototypes.
LuaSegmentedUnitCloneParams
Clones this unit.
LuaSegmentedUnitDestroyParams
Destroys the segmented unit.
LuaSelectorCombinatorControlBehavior
Control behavior for selector combinators.
LuaSettings
Object containing the three different types of mod settings: startup settings, global runtime settings and per-player runtime settings. An instance of LuaSettings is available through the global object named settings.
LuaShortcutPrototype
Prototype of a shortcut.
LuaSimulation
Functions for use during simulations. This object cannot be saved, and cannot be used outside of a simulation.
LuaSimulationActivateRailPlannerParams
Activate the rail planner at the given position.
LuaSimulationControlDownParams
Send a control press event at the current cursor position.
LuaSimulationControlPressParams
Send a control down and up event at the current cursor position. This is equivalent to calling LuaSimulation::control_down, then LuaSimulation::control_up.
LuaSimulationControlUpParams
Send a control release event at the current cursor position.
LuaSimulationCreateTestPlayerParams
LuaSimulationGetSlotPositionParams
LuaSimulationGetWidgetPositionParams
LuaSimulationMoveCursorParams
Move the cursor towards the given position at the given speed.
LuaSimulationWriteParams
Write text as if it was typed by a player. Overwrites existing text by selecting it first.
LuaSingleFluidBoxControlBehavior
Control behavior for entities with a single fluid box (i.e. pipe, pipe-to-ground, storage-tank).
LuaSpaceConnectionPrototype
Prototype of a space connection.
LuaSpaceLocationPrototype
Prototype of a space location, such as a planet.
LuaSpacePlatform
A space platform.
LuaSpacePlatformDamageTileParams
Damages the given tile if it exists, the chunk is generated, and it is a platform foundation tile.
LuaSpacePlatformDestroyAsteroidChunksParams
Destroys all asteroid chunks from the given area. If no area and no position are given, then the entire surface is searched.
LuaSpacePlatformFindAsteroidChunksFilteredParams
Find asteroid chunks of a given name in a given area.
LuaSpacePlatformHubControlBehavior
Control behavior for space platform hubs
LuaSplitterControlBehavior
Control behavior for splitter.
LuaStyle
Style of a GUI element. All of the attributes listed here may be nil if not available for a particular GUI element.
LuaSurface
A “domain” of the world, such as a planet or space platform. Surfaces are uniquely identified by their name. Every game contains at least the surface “nauvis”.
LuaSurfaceCanFastReplaceParams
If there exists an entity at the given location that can be fast-replaced with the given entity parameters.
LuaSurfaceCanPlaceEntityParams
Check for collisions with terrain or other entities.
LuaSurfaceCancelDeconstructAreaParams
Cancel a deconstruction order.
LuaSurfaceCancelUpgradeAreaParams
Cancel a upgrade order.
LuaSurfaceCloneAreaParams
Clones the given area.
LuaSurfaceCloneBrushParams
Clones the given area.
LuaSurfaceCloneEntitiesParams
Clones the given entities.
LuaSurfaceCreateDecorativesParams
Adds the given decoratives to the surface.
LuaSurfaceCreateEntitiesFromBlueprintStringParams
This method only works when used in simulations.
LuaSurfaceCreateEntityParams
Create an entity on this surface.
LuaSurfaceCreateParticleParams
Creates a particle at the given location
LuaSurfaceCreateSegmentedUnitParams
Create a segmented unit on the surface. This differs from creating an entity with type "segmented-unit" in that this method can create the entity in non-generated chunks and with any arbitrary body shape and pre-assigned to a territory.
LuaSurfaceCreateTerritoryParams
Create a territory on the surface.
LuaSurfaceCreateTrivialSmokeParams
LuaSurfaceCreateUnitGroupParams
Create a new unit group at a given position.
LuaSurfaceDaytimeParameters
LuaSurfaceDeconstructAreaParams
Place a deconstruction request.
LuaSurfaceDestroyDecorativesParams
Removes all decoratives from the given area. If no area and no position are given, then the entire surface is searched.
LuaSurfaceExecuteLightningParams
Creates lightning. If other entities which can be lightning targets are nearby, the final position will be adjusted.
LuaSurfaceFindDecorativesFilteredParams
Find decoratives of a given name in a given area.
LuaSurfaceFindNearestEnemyEntityWithOwnerParams
Find the enemy entity-with-owner closest to the given position.
LuaSurfaceFindNearestEnemyParams
Find the enemy military target (military entity) closest to the given position.
LuaSurfaceFindUnitsParams
Find units (entities with type “unit”) of a given force and force condition within a given area.
LuaSurfacePropertyPrototype
Prototype of a surface property.
LuaSurfacePrototype
Prototype of a surface.
LuaSurfaceRequestPathParams
Generates a path with the specified constraints (as an array of PathfinderWaypoints) using the unit pathfinding algorithm. This path can be used to emulate pathing behavior by script for non-unit entities, such as vehicles. If you want to command actual units (such as biters or spitters) to move, use LuaCommandable::set_command via LuaEntity::commandable instead.
LuaSurfaceSetMultiCommandParams
Give a command to multiple units. This will automatically select suitable units for the task.
LuaSurfaceSpillInventoryParams
Spill inventory on the ground centered at a given location.
LuaSurfaceSpillItemStackParams
Spill items on the ground centered at a given location.
LuaSurfaceUpgradeAreaParams
Place an upgrade request.
LuaTechnology
One research item.
LuaTechnologyPrototype
A Technology prototype.
LuaTerritory
A set of chunks on a single LuaSurface that can be guarded by one or more LuaSegmentedUnits.
LuaTile
A single “square” on the map.
LuaTilePrototype
Prototype of a tile.
LuaTilePrototypeMineableProperties
LuaTrain
A train. Trains are a sequence of connected rolling stocks – locomotives and wagons.
LuaTrainLocomotives
LuaTrainManager
The train manager manages all the train in the game. LuaTrainManager allows to perform some direct queries to the train manager.
LuaTrainManagerRequestTrainPathParams
Direct access to train pathfinder. Allows to search rail paths or querying which stops are accessible
LuaTrainStopControlBehavior
Control behavior for train stops.
LuaTransportBeltControlBehavior
Control behavior for transport belts.
LuaTransportLine
One line on a transport belt.
LuaTrivialSmokePrototype
Prototype of a trivial smoke.
LuaTurretControlBehavior
Control behavior for turrets.
LuaUndoRedoStack
The undo queue for a player. The term item_index refers to the index of an undo item in the queue, while action_index refers to the index of one of the individual actions that make up an undo item.
LuaVirtualSignalPrototype
Prototype of a virtual signal.
LuaVoidEnergySourcePrototype
Prototype of a void energy source.
LuaWallControlBehavior
Control behavior for walls.
LuaWireConnector
A wire connector of a given entity. Allows to find wires, add or remove wires and do some basic operations specific to those connectors.