pub struct LuaAgriculturalTowerControlBehavior;Expand description
Control behavior for agricultural tower
Implementations
Sourceimpl LuaAgriculturalTowerControlBehavior
impl LuaAgriculturalTowerControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn set_input_networks(&self, value: CircuitNetworkSelection)
pub fn set_input_networks(&self, value: CircuitNetworkSelection)
Set the input_networks attribute (Lua: self.input_networks = value).
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn set_output_networks(&self, value: CircuitNetworkSelection)
pub fn set_output_networks(&self, value: CircuitNetworkSelection)
Set the output_networks attribute (Lua: self.output_networks = value).
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn circuit_condition(&self) -> CircuitConditionDefinition
pub fn circuit_condition(&self) -> CircuitConditionDefinition
The circuit condition. Writing nil clears the circuit condition.
Sourcepub fn set_circuit_condition(&self, value: CircuitConditionDefinition)
pub fn set_circuit_condition(&self, value: CircuitConditionDefinition)
Set the circuit_condition attribute (Lua: self.circuit_condition = value).
The circuit condition. Writing nil clears the circuit condition.
Sourcepub fn circuit_enable_disable(&self) -> bool
pub fn circuit_enable_disable(&self) -> bool
true if this entity enable/disable state is controlled by circuit condition
Sourcepub fn set_circuit_enable_disable(&self, value: bool)
pub fn set_circuit_enable_disable(&self, value: bool)
Set the circuit_enable_disable attribute (Lua: self.circuit_enable_disable = value).
true if this entity enable/disable state is controlled by circuit condition
Sourcepub fn connect_to_logistic_network(&self) -> bool
pub fn connect_to_logistic_network(&self) -> bool
true if this should connect to the logistic network.
Sourcepub fn set_connect_to_logistic_network(&self, value: bool)
pub fn set_connect_to_logistic_network(&self, value: bool)
Set the connect_to_logistic_network attribute (Lua: self.connect_to_logistic_network = value).
true if this should connect to the logistic network.
Sourcepub fn disabled(&self) -> bool
pub fn disabled(&self) -> bool
If the entity is currently disabled because of the control behavior.
Sourcepub fn logistic_condition(&self) -> CircuitConditionDefinition
pub fn logistic_condition(&self) -> CircuitConditionDefinition
The logistic condition. Writing nil clears the logistic condition.
Sourcepub fn set_logistic_condition(&self, value: CircuitConditionDefinition)
pub fn set_logistic_condition(&self, value: CircuitConditionDefinition)
Set the logistic_condition attribute (Lua: self.logistic_condition = value).
The logistic condition. Writing nil clears the logistic condition.
pub fn enable_harvesting_condition(&self) -> bool
Sourcepub fn set_enable_harvesting_condition(&self, value: bool)
pub fn set_enable_harvesting_condition(&self, value: bool)
Set the enable_harvesting_condition attribute (Lua: self.enable_harvesting_condition = value).
pub fn enable_planting_condition(&self) -> bool
Sourcepub fn set_enable_planting_condition(&self, value: bool)
pub fn set_enable_planting_condition(&self, value: bool)
Set the enable_planting_condition attribute (Lua: self.enable_planting_condition = value).
pub fn harvesting_condition(&self) -> CircuitConditionDefinition
Sourcepub fn set_harvesting_condition(&self, value: CircuitConditionDefinition)
pub fn set_harvesting_condition(&self, value: CircuitConditionDefinition)
Set the harvesting_condition attribute (Lua: self.harvesting_condition = value).
Sourcepub fn object_name(&self) -> &'static str
pub fn object_name(&self) -> &'static str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
pub fn planting_condition(&self) -> CircuitConditionDefinition
Sourcepub fn set_planting_condition(&self, value: CircuitConditionDefinition)
pub fn set_planting_condition(&self, value: CircuitConditionDefinition)
Set the planting_condition attribute (Lua: self.planting_condition = value).
Sourcepub fn read_contents(&self) -> bool
pub fn read_contents(&self) -> bool
true if the agricultural tower reads seeds and harvested plants.
Sourcepub fn set_read_contents(&self, value: bool)
pub fn set_read_contents(&self, value: bool)
Set the read_contents attribute (Lua: self.read_contents = value).
true if the agricultural tower reads seeds and harvested plants.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &'static str, ) -> Option<LuaCircuitNetwork>