pub struct LuaAssemblingMachineControlBehavior;Expand description
Control behavior for assembling machines.
Implementations
Sourceimpl LuaAssemblingMachineControlBehavior
impl LuaAssemblingMachineControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn set_input_networks(&self, value: CircuitNetworkSelection)
pub fn set_input_networks(&self, value: CircuitNetworkSelection)
Set the input_networks attribute (Lua: self.input_networks = value).
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn set_output_networks(&self, value: CircuitNetworkSelection)
pub fn set_output_networks(&self, value: CircuitNetworkSelection)
Set the output_networks attribute (Lua: self.output_networks = value).
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn circuit_condition(&self) -> CircuitConditionDefinition
pub fn circuit_condition(&self) -> CircuitConditionDefinition
The circuit condition. Writing nil clears the circuit condition.
Sourcepub fn set_circuit_condition(&self, value: CircuitConditionDefinition)
pub fn set_circuit_condition(&self, value: CircuitConditionDefinition)
Set the circuit_condition attribute (Lua: self.circuit_condition = value).
The circuit condition. Writing nil clears the circuit condition.
Sourcepub fn circuit_enable_disable(&self) -> bool
pub fn circuit_enable_disable(&self) -> bool
true if this entity enable/disable state is controlled by circuit condition
Sourcepub fn set_circuit_enable_disable(&self, value: bool)
pub fn set_circuit_enable_disable(&self, value: bool)
Set the circuit_enable_disable attribute (Lua: self.circuit_enable_disable = value).
true if this entity enable/disable state is controlled by circuit condition
Sourcepub fn connect_to_logistic_network(&self) -> bool
pub fn connect_to_logistic_network(&self) -> bool
true if this should connect to the logistic network.
Sourcepub fn set_connect_to_logistic_network(&self, value: bool)
pub fn set_connect_to_logistic_network(&self, value: bool)
Set the connect_to_logistic_network attribute (Lua: self.connect_to_logistic_network = value).
true if this should connect to the logistic network.
Sourcepub fn disabled(&self) -> bool
pub fn disabled(&self) -> bool
If the entity is currently disabled because of the control behavior.
Sourcepub fn logistic_condition(&self) -> CircuitConditionDefinition
pub fn logistic_condition(&self) -> CircuitConditionDefinition
The logistic condition. Writing nil clears the logistic condition.
Sourcepub fn set_logistic_condition(&self, value: CircuitConditionDefinition)
pub fn set_logistic_condition(&self, value: CircuitConditionDefinition)
Set the logistic_condition attribute (Lua: self.logistic_condition = value).
The logistic condition. Writing nil clears the logistic condition.
Sourcepub fn circuit_read_contents(&self) -> bool
pub fn circuit_read_contents(&self) -> bool
true if the assembling machine reads its ingredients contents, product contents, materials in crafting and trash inventories.
Sourcepub fn set_circuit_read_contents(&self, value: bool)
pub fn set_circuit_read_contents(&self, value: bool)
Set the circuit_read_contents attribute (Lua: self.circuit_read_contents = value).
true if the assembling machine reads its ingredients contents, product contents, materials in crafting and trash inventories.
Sourcepub fn circuit_read_ingredients(&self) -> bool
pub fn circuit_read_ingredients(&self) -> bool
true if the assembling machine outputs ingredients of current recipe as a signals to circuit network.
Sourcepub fn set_circuit_read_ingredients(&self, value: bool)
pub fn set_circuit_read_ingredients(&self, value: bool)
Set the circuit_read_ingredients attribute (Lua: self.circuit_read_ingredients = value).
true if the assembling machine outputs ingredients of current recipe as a signals to circuit network.
Sourcepub fn circuit_read_recipe_finished(&self) -> bool
pub fn circuit_read_recipe_finished(&self) -> bool
true if the the assembling machine sends a signal when the recipe finishes.
Sourcepub fn set_circuit_read_recipe_finished(&self, value: bool)
pub fn set_circuit_read_recipe_finished(&self, value: bool)
Set the circuit_read_recipe_finished attribute (Lua: self.circuit_read_recipe_finished = value).
true if the the assembling machine sends a signal when the recipe finishes.
Sourcepub fn circuit_read_working(&self) -> bool
pub fn circuit_read_working(&self) -> bool
true if the the assembling machine sends a signal when it is working.
Sourcepub fn set_circuit_read_working(&self, value: bool)
pub fn set_circuit_read_working(&self, value: bool)
Set the circuit_read_working attribute (Lua: self.circuit_read_working = value).
true if the the assembling machine sends a signal when it is working.
Sourcepub fn circuit_recipe_finished_signal(&self) -> SignalID
pub fn circuit_recipe_finished_signal(&self) -> SignalID
The signal sent when the assembling machine finishes a recipe.
Sourcepub fn set_circuit_recipe_finished_signal(&self, value: SignalID)
pub fn set_circuit_recipe_finished_signal(&self, value: SignalID)
Set the circuit_recipe_finished_signal attribute (Lua: self.circuit_recipe_finished_signal = value).
The signal sent when the assembling machine finishes a recipe.
Sourcepub fn circuit_set_recipe(&self) -> bool
pub fn circuit_set_recipe(&self) -> bool
true if the assembling machine sets its recipe from the circuit network.
See Circuit Recipe Selection for how that recipe is chosen.
Sourcepub fn set_circuit_set_recipe(&self, value: bool)
pub fn set_circuit_set_recipe(&self, value: bool)
Set the circuit_set_recipe attribute (Lua: self.circuit_set_recipe = value).
true if the assembling machine sets its recipe from the circuit network.
See Circuit Recipe Selection for how that recipe is chosen.
Sourcepub fn circuit_working_signal(&self) -> SignalID
pub fn circuit_working_signal(&self) -> SignalID
The signal sent when the assembling machine is working.
Sourcepub fn set_circuit_working_signal(&self, value: SignalID)
pub fn set_circuit_working_signal(&self, value: SignalID)
Set the circuit_working_signal attribute (Lua: self.circuit_working_signal = value).
The signal sent when the assembling machine is working.
Sourcepub fn include_in_crafting(&self) -> bool
pub fn include_in_crafting(&self) -> bool
true if the read contents should include items in crafting.
Sourcepub fn set_include_in_crafting(&self, value: bool)
pub fn set_include_in_crafting(&self, value: bool)
Set the include_in_crafting attribute (Lua: self.include_in_crafting = value).
true if the read contents should include items in crafting.
Sourcepub fn object_name(&self) -> &'static str
pub fn object_name(&self) -> &'static str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn set_read_fuel(&self, value: bool)
pub fn set_read_fuel(&self, value: bool)
Set the read_fuel attribute (Lua: self.read_fuel = value).
true if the fuel (content of energy source) should be read.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &'static str, ) -> Option<LuaCircuitNetwork>