pub struct LuaCargoHatch;Expand description
A cargo hatch.
Implementations
Sourceimpl LuaCargoHatch
impl LuaCargoHatch
pub fn busy(&self) -> bool
pub fn is_input_compatible(&self) -> bool
pub fn is_output_compatible(&self) -> bool
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
pub fn owner(&self) -> LuaEntity
pub fn reserved(&self) -> bool
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
Sourcepub fn create_cargo_pod(&self, cargo_pod_prototype: Option<LuaAny>) -> LuaEntity
pub fn create_cargo_pod(&self, cargo_pod_prototype: Option<LuaAny>) -> LuaEntity
Creates a cargo pod for output at the owning entity hatch location.