pub struct LuaControlBeginCraftingParams {
pub count: u32,
pub recipe: LuaAny,
pub silent: bool,
}Expand description
Begins crafting the given count of the given recipe.
Fields
count: u32The count to craft.
recipe: LuaAnyThe recipe to craft.
silent: boolIf false and the recipe can’t be crafted the requested number of times printing the failure is skipped.