pub struct LuaControlCanPlaceEntityParams {
pub direction: String,
pub name: LuaAny,
pub position: MapPosition,
}Expand description
Checks if this character or player can build the given entity at the given location on the surface the character or player is on.
Fields
direction: StringDirection the entity would be facing. Defaults to north.
name: LuaAnyName of the entity that would be built.
position: MapPositionWhere the entity would be placed.