pub struct LuaControlCancelCraftingParams {
pub count: u32,
pub index: u32,
}Expand description
Cancels the given amount of crafts at the given crafting queue position. If this causes any later crafts that depend on the cancelled one to have insufficient ingredients, those crafts will also be cancelled.
Fields
count: u32The count to cancel crafting.
index: u32The crafting queue index.