LuaCustomInputPrototype

Struct LuaCustomInputPrototype 

pub struct LuaCustomInputPrototype;
Prototype of a custom input.

Implementations

Source

impl LuaCustomInputPrototype

pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>

Extra description items in the tooltip and Factoriopedia.

pub fn factoriopedia_description(&self) -> &str

Provides additional description used in factoriopedia.

pub fn group(&self) -> LuaGroup

Group of this prototype.

pub fn hidden(&self) -> bool

pub fn hidden_in_factoriopedia(&self) -> bool

pub fn localised_description(&self) -> &str

pub fn localised_name(&self) -> &str

pub fn name(&self) -> &str

Name of this prototype.

pub fn order(&self) -> &str

The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.

pub fn parameter(&self) -> bool

pub fn subgroup(&self) -> LuaGroup

Subgroup of this prototype.

pub fn type(&self) -> &str

Type of this prototype.

pub fn action(&self) -> &str

The action that happens when this custom input is triggered.

pub fn alternative_key_sequence(&self) -> &str

The default alternative key sequence for this custom input, if any

pub fn consuming(&self) -> LuaCustomInputPrototypeConsuming

The consuming type.

pub fn controller_alternative_key_sequence(&self) -> &str

The default controller alternative key sequence for this custom input, if any

pub fn controller_key_sequence(&self) -> &str

The default controller key sequence for this custom input, if any

pub fn enabled(&self) -> bool

Whether this custom input is enabled. Disabled custom inputs exist but are not used by the game.

pub fn enabled_while_in_cutscene(&self) -> bool

Whether this custom input is enabled while using the cutscene controller.

pub fn enabled_while_spectating(&self) -> bool

Whether this custom input is enabled while using the spectator controller.

pub fn event_id(&self) -> &str

Event identifier associated with this custom input.

pub fn include_selected_prototype(&self) -> bool

Whether this custom input will include the selected prototype (if any) when triggered.

pub fn item_to_spawn(&self) -> LuaItemPrototype

The item that gets spawned when this custom input is fired, if any.

pub fn key_sequence(&self) -> &str

The default key sequence for this custom input.

pub fn linked_game_control(&self) -> LinkedGameControl

The linked game control name, if any.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.