pub struct LuaDeciderCombinatorControlBehavior;Expand description
Control behavior for decider combinators.
Implementations
Sourceimpl LuaDeciderCombinatorControlBehavior
impl LuaDeciderCombinatorControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn signals_last_tick(&self) -> Vec<Signal>
pub fn signals_last_tick(&self) -> Vec<Signal>
The circuit network signals sent by this combinator last tick.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn parameters(&self) -> DeciderCombinatorParameters
pub fn parameters(&self) -> DeciderCombinatorParameters
This decider combinator’s parameters. Writing nil clears the combinator’s parameters.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>
Sourcepub fn get_signal_last_tick(&self, signal: SignalID) -> Option<i32>
pub fn get_signal_last_tick(&self, signal: SignalID) -> Option<i32>
Gets the value of a specific signal sent by this combinator behavior last tick or nil if the signal didn’t exist.
Sourcepub fn add_condition(
&self,
condition: DeciderCombinatorCondition,
index: Option<u32>,
)
pub fn add_condition( &self, condition: DeciderCombinatorCondition, index: Option<u32>, )
Adds a new condition.
Sourcepub fn add_else_output(
&self,
index: Option<u32>,
output: DeciderCombinatorOutput,
)
pub fn add_else_output( &self, index: Option<u32>, output: DeciderCombinatorOutput, )
Adds a new else-output.
Sourcepub fn add_output(&self, index: Option<u32>, output: DeciderCombinatorOutput)
pub fn add_output(&self, index: Option<u32>, output: DeciderCombinatorOutput)
Adds a new output.
Sourcepub fn get_condition(&self, index: u32) -> DeciderCombinatorCondition
pub fn get_condition(&self, index: u32) -> DeciderCombinatorCondition
Gets the condition at index.
Sourcepub fn get_else_output(&self, index: u32) -> DeciderCombinatorOutput
pub fn get_else_output(&self, index: u32) -> DeciderCombinatorOutput
Gets the else-output at index.
Sourcepub fn get_output(&self, index: u32) -> DeciderCombinatorOutput
pub fn get_output(&self, index: u32) -> DeciderCombinatorOutput
Gets the output at index.
Sourcepub fn remove_condition(&self, index: u32)
pub fn remove_condition(&self, index: u32)
Removes the condition at index.
Sourcepub fn remove_else_output(&self, index: u32)
pub fn remove_else_output(&self, index: u32)
Removes the else-output at index.
Sourcepub fn remove_output(&self, index: u32)
pub fn remove_output(&self, index: u32)
Removes the output at index.
Sourcepub fn set_condition(&self, condition: DeciderCombinatorCondition, index: u32)
pub fn set_condition(&self, condition: DeciderCombinatorCondition, index: u32)
Sets the condition at index.
Sourcepub fn set_else_output(&self, index: u32, output: DeciderCombinatorOutput)
pub fn set_else_output(&self, index: u32, output: DeciderCombinatorOutput)
Sets the else-output at index.
Sourcepub fn set_output(&self, index: u32, output: DeciderCombinatorOutput)
pub fn set_output(&self, index: u32, output: DeciderCombinatorOutput)
Sets the output at index.