LuaDisplayPanelControlBehavior

Struct LuaDisplayPanelControlBehavior 

pub struct LuaDisplayPanelControlBehavior;
Control behavior for display panels.

Implementations

Source

impl LuaDisplayPanelControlBehavior

pub fn entity(&self) -> LuaEntity

The entity this control behavior belongs to.

pub fn input_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to read signals from. Defaults to both wire colors.

nil if this control behavior does not allow selecting the input networks.

pub fn output_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to send signals to. Defaults to both wire colors.

nil if this control behavior does not allow selecting the output networks.

pub fn type(&self) -> &str

The concrete type of this control behavior.

pub fn max_records_count(&self) -> u32

Provides a maximum amount of records that can be added to this behavior. When at full capacity, attempts to add more records will fail.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn records(&self) -> Vec<DisplayPanelMessageDefinition>

The full list of configured messages.

pub fn records_count(&self) -> u32

Current amount of records this control behavior has.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>

pub fn add_record( &self, index: Option<u32>, message: DisplayPanelMessageDefinition, ) -> bool

Adds a single message record.

pub fn get_record(&self, index: u32) -> DisplayPanelMessageDefinition

Get a single record.

pub fn move_record(&self, new_index: u32, old_index: u32)

Moves record from old position to a new position

pub fn remove_record(&self, index: u32)

Removes message record at specified index.

pub fn set_record(&self, index: u32, record: DisplayPanelMessageDefinition)

Change content of a specific record.