pub struct LuaElectricNetworkGetAccumulatorsEnergyParams {
pub name: LuaAny,
pub quality: LuaAny,
}Expand description
Gets total energy stored inside of accumulators that are part of any electric sub network covered by this electric network.
Fields
name: LuaAnyWhen given, only accumulators of this prototype will be considered.
quality: LuaAnyWhen given, only accumulators of this quality will be considered.