pub struct LuaElectricSubNetworkSetAccumulatorsEnergyParams {
pub energy: f64,
pub equalize: bool,
pub name: LuaAny,
pub quality: LuaAny,
}Expand description
Changes energy stored inside of accumulators connected to the electric sub network.
Fields
energy: f64New total energy to be set onto matching accumulators.
equalize: boolWhether all accumulators should have the same charge ratio, regardless of whether that means discharging some of them. Defaults to false.
name: LuaAnyWhen given, only accumulators of this prototype will be considered.
quality: LuaAnyWhen given, only accumulators of this quality will be considered.