pub struct LuaEntityCreateCargoPodParams {
pub cargo_hatch: LuaCargoHatch,
pub cargo_pod_prototype: LuaAny,
}Expand description
Creates a cargo pod if possible.
Cargo pod will be created with invalid destination type. Setting cargo_pod_destination will cause it to launch.
Fields
cargo_hatch: LuaCargoHatchThe hatch to create the pod at. A random (available) one is picked if not provided.
cargo_pod_prototype: LuaAnyThe cargo pod prototype to create. If not provided, the default cargo pod prototype of the hatch is used.