pub struct LuaEntityDestroyParams {
pub do_cliff_correction: bool,
pub player: PlayerIdentification,
pub raise_destroy: bool,
pub undo_index: u32,
}Expand description
Destroys the entity.
Not all entities can be destroyed - things such as rails under trains cannot be destroyed until the train is moved or destroyed.
Fields
do_cliff_correction: boolWhether neighbouring cliffs should be corrected. Defaults to false.
player: PlayerIdentificationThe player whose undo queue this action should be added to.
raise_destroy: boolIf true, script_raised_destroy will be called. Defaults to false.
undo_index: u32The index of the undo item to add this action to. An index of 0 creates a new undo item for it. Defaults to putting it into the appropriate undo item automatically if not specified.