LuaEntityExtractFluidParams

Struct LuaEntityExtractFluidParams 

pub struct LuaEntityExtractFluidParams {
    pub amount: LuaAny,
    pub maximum_temperature: f64,
    pub minimum_temperature: f64,
    pub name: String,
    pub temperature: f64,
}
Remove fluid from this entity.

If temperature is given only fluid matching that exact temperature is removed. If minimum and maximum is given fluid within that range is removed.

Fields

amount: LuaAny

Amount to remove

maximum_temperature: f64minimum_temperature: f64name: String

Fluid prototype name.

temperature: f64