LuaEntityOrderUpgradeParams

Struct LuaEntityOrderUpgradeParams 

pub struct LuaEntityOrderUpgradeParams {
    pub force: LuaAny,
    pub player: LuaAny,
    pub target: LuaAny,
    pub undo_index: u32,
}
Sets the entity to be upgraded by construction robots.

Fields

force: LuaAny

The force whose robots are supposed to do the upgrade.

player: LuaAny

The player whose undo queue this action should be added to.

target: LuaAny

The prototype of the entity to upgrade to.

undo_index: u32

The index of the undo item to add this action to. An index of 0 creates a new undo item for it. Defaults to putting it into the appropriate undo item automatically if not specified.