pub struct LuaEntityReviveParams {
pub overflow: LuaInventory,
pub raise_revive: bool,
}Expand description
Revive a ghost, which turns it from a ghost into a real entity or tile.
Fields
overflow: LuaInventoryItems that would be deleted will be transferred to this inventory. Must be a script inventory or inventory of other entity. Inventory references obtained from proxy container are not allowed.
raise_revive: boolIf true, and an entity ghost; script_raised_revive will be called. Else if true, and a tile ghost; script_raised_set_tiles will be called.