pub struct LuaEntitySilentReviveParams {
pub overflow: LuaInventory,
pub raise_revive: bool,
}Expand description
Revives a ghost silently, so the revival makes no sound and no smoke is created.
Fields
overflow: LuaInventoryItems that would be deleted will be transferred to this inventory. Must be a script inventory or inventory of other entity. Inventory references obtained from proxy container are not allowed.
raise_revive: boolIf true, and an entity ghost; script_raised_revive will be called. Else if true, and a tile ghost; script_raised_set_tiles will be called.