LuaFlowStatistics

Struct LuaFlowStatistics 

pub struct LuaFlowStatistics;
Encapsulates statistic data for different parts of the game.

In the context of flow statistics, input, output and storage describe in which position of the associated GUI the values are shown. Input values are shown on the far left side, output values to the immediate right, and storage values (if present) to the far right.

  • The item production GUI shows “consumption” on the right, thus output describes the item consumption numbers. The same goes for fluid consumption.

  • The kills GUI shows “losses” on the right, so output describes how many of the force’s entities were killed by enemies.

  • The electric network GUI shows “power consumption” on the left side, so in this case input describes the power consumption numbers. In addition, electric networks are currently the only ones that utilize the storage part of their statistics, showing accumulator charges to the far right of the GUI.

Implementations

Source

impl LuaFlowStatistics

pub fn current_input_quality_samples( &self, ) -> HashMap<String, HashMap<String, f64>>

A mapping of quality name to a list of current tick input samples indexed by prototype name.

pub fn current_output_quality_samples( &self, ) -> HashMap<String, HashMap<String, f64>>

A mapping of quality name to a list of current tick output samples indexed by prototype name.

pub fn force(&self) -> LuaForce

The force these statistics belong to. nil for pollution statistics.

pub fn input_counts(&self) -> HashMap<String, LuaAny>

List of input counts indexed by prototype name. Represents the data that is shown on the left side of the GUI for the given statistics.

pub fn input_quality_counts(&self) -> HashMap<String, HashMap<String, LuaAny>>

A mapping of quality name to a list of input counts indexed by prototype name. Represents the data that is shown on the left side of the GUI for the given statistics.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn output_counts(&self) -> HashMap<String, LuaAny>

List of output counts indexed by prototype name. Represents the data that is shown in the middle of the GUI for electric networks and on the right side for all other statistics types.

pub fn output_quality_counts(&self) -> HashMap<String, HashMap<String, LuaAny>>

A mapping of quality name to a list of output counts indexed by prototype name. Represents the data that is shown in the middle of the GUI for electric networks and on the right side for all other statistics types.

pub fn storage_counts(&self) -> HashMap<String, LuaAny>

List of storage counts indexed by prototype name. Represents the data that is shown on the right side of the GUI for electric networks. For other statistics types these values are currently unused and hidden.

pub fn storage_quality_counts(&self) -> HashMap<String, HashMap<String, LuaAny>>

A mapping of quality name to a list of storage counts indexed by prototype name. Represents the data that is shown on the right side of the GUI for electric networks. For other statistics types these values are currently unused and hidden.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn clear(&self)

Reset all the statistics data to 0.

pub fn get_current_input_sample(&self, id: LuaAny) -> f64

Gets the current-tick input sample for a given prototype.

These values get merged into the input counts at the end of the tick.

pub fn get_current_output_sample(&self, id: LuaAny) -> f64

Gets the current-tick output sample for a given prototype.

These values get merged into the output counts at the end of the tick.

pub fn get_flow_count(&self, params: LuaFlowStatisticsGetFlowCountParams) -> f64

Gets the flow count value for the given time frame. If sample_index is not provided, then the value returned is the average across the provided precision time period. These are the values shown in the bottom section of the statistics GUIs.

Use sample_index to access the data used to generate the statistics graphs. Each precision level contains 300 samples of data so at a precision of 1 minute, each sample contains data averaged across 60s / 300 = 0.2s = 12 ticks.

All return values are normalized to be per-tick for electric networks and per-minute for all other types.

pub fn get_input_count(&self, id: LuaAny) -> LuaAny

Gets the total input count for a given prototype.

pub fn get_output_count(&self, id: LuaAny) -> LuaAny

Gets the total output count for a given prototype.

pub fn get_storage_count(&self, id: LuaAny) -> LuaAny

Gets the total storage count for a given prototype.

pub fn on_flow(&self, count: f32, id: LuaAny)

Adds a value to this flow statistics.

pub fn set_current_input_sample(&self, count: f64, id: LuaAny)

Sets the current-tick input sample for a given prototype.

These values get merged into the input counts at the end of the tick.

pub fn set_current_output_sample(&self, count: f64, id: LuaAny)

Sets the current-tick output sample for a given prototype.

These values get merged into the output counts at the end of the tick.

pub fn set_input_count(&self, count: LuaAny, id: LuaAny)

Sets the total input count for a given prototype.

pub fn set_output_count(&self, count: LuaAny, id: LuaAny)

Sets the total output count for a given prototype.

pub fn set_storage_count(&self, count: LuaAny, id: LuaAny)

Sets the total storage count for a given prototype.