LuaFluidBoxPrototype

Struct LuaFluidBoxPrototype 

pub struct LuaFluidBoxPrototype;
A prototype of a fluidbox owned by some LuaEntityPrototype.

Implementations

Source

impl LuaFluidBoxPrototype

pub fn entity(&self) -> LuaEntityPrototype

The entity that this belongs to.

pub fn filter(&self) -> LuaFluidPrototype

The filter, if any is set.

pub fn index(&self) -> u32

The index of this fluidbox prototype in the owning entity.

pub fn maximum_temperature(&self) -> f64

The maximum temperature, if any is set.

pub fn minimum_temperature(&self) -> f64

The minimum temperature, if any is set.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn pipe_connections(&self) -> Vec<PipeConnectionDefinition>

The pipe connection points.

pub fn production_type(&self) -> ProductionType

The production type.

pub fn render_layer(&self) -> LuaAny

The render layer.

pub fn secondary_draw_orders(&self) -> Vec<i32>

The secondary draw orders for the 4 possible connection directions.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn get_volume(&self, quality: Option<LuaAny>) -> f64

Gets the volume of this fluidbox with the given quality.