pub struct LuaFluidEnergySourcePrototype;Expand description
Prototype of a fluid energy source.
Implementations
Sourceimpl LuaFluidEnergySourcePrototype
impl LuaFluidEnergySourcePrototype
pub fn burns_fluid(&self) -> bool
pub fn destroy_non_fuel_fluid(&self) -> bool
pub fn effectivity(&self) -> f64
Sourcepub fn emissions_per_joule(&self) -> HashMap<String, f64>
pub fn emissions_per_joule(&self) -> HashMap<String, f64>
The table of emissions of this energy source in pollution/Joule, indexed by pollutant type. Multiplying it by energy consumption in Watt gives pollution/second.
Sourcepub fn fluid_box(&self) -> LuaFluidBoxPrototype
pub fn fluid_box(&self) -> LuaFluidBoxPrototype
The fluid box for this energy source.
pub fn fluid_usage_per_tick(&self) -> f64
pub fn maximum_temperature(&self) -> f64
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
pub fn output_fluid_box(&self) -> LuaFluidBoxPrototype
pub fn render_no_network_icon(&self) -> bool
pub fn render_no_power_icon(&self) -> bool
pub fn scale_fluid_usage(&self) -> bool
Sourcepub fn smoke(&self) -> Vec<SmokeSource>
pub fn smoke(&self) -> Vec<SmokeSource>
The smoke sources for this prototype, if any.
pub fn spent_fluid(&self) -> SpentFluidSpecification
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.