pub struct LuaGameScriptShowMessageDialogParams {
pub image: String,
pub point_to: GuiArrowSpecification,
pub style: String,
pub text: String,
pub wrapper_frame_style: String,
}Expand description
Show an in-game message dialog.
Can only be used when the map contains exactly one player.
Fields
image: StringPath to an image to show on the dialog
point_to: GuiArrowSpecificationIf specified, dialog will show an arrow pointing to this place. When not specified, the arrow will point to the player’s position. (Use point_to={type="nowhere"} to remove the arrow entirely.) The dialog itself will be placed near the arrow’s target.
style: StringThe gui style to use for this speech bubble. Must be of type speech_bubble.
text: StringWhat the dialog should say
wrapper_frame_style: StringMust be of type flow_style.