LuaGameScriptTakeScreenshotParams

Struct LuaGameScriptTakeScreenshotParams 

pub struct LuaGameScriptTakeScreenshotParams {
Show 18 fields pub allow_in_replay: bool, pub anti_alias: bool, pub by_player: LuaAny, pub daytime: f64, pub force_render: bool, pub hide_clouds: bool, pub hide_fog: bool, pub path: String, pub player: LuaAny, pub position: MapPosition, pub quality: i32, pub resolution: TilePosition, pub show_cursor_building_preview: bool, pub show_entity_info: bool, pub show_gui: bool, pub surface: LuaAny, pub water_tick: u32, pub zoom: f64,
}
Take a screenshot of the game and save it to the script-output folder, located in the game’s user data directory. The name of the image file can be specified via the path parameter.

If Factorio is running headless, this function will do nothing.

Fields

allow_in_replay: bool

Whether to save the screenshot even during replay playback. Defaults to false.

anti_alias: bool

Whether to render in double resolution and downscale the result (including GUI). Defaults to false.

by_player: LuaAny

If defined, the screenshot will only be taken for this player.

daytime: f64

Overrides the current surface daytime for the duration of screenshot rendering.

force_render: bool

Screenshot requests are processed in between game update and render. The game may skip rendering (ie. drop frames) if the previous frame has not finished rendering or the game simulation starts to fall below 60 updates per second. If force_render is set to true, the game won’t drop frames and process the screenshot request at the end of the update in which the request was created. This is not honored on multiplayer clients that are catching up to server. Defaults to false.

hide_clouds: bool

If true cloud shadows on ground won’t be rendered. Defaults to false.

hide_fog: bool

If true fog effect and foreground space dust effect won’t be rendered. Defaults to false.

path: String

The name of the image file. It should include a file extension indicating the desired format. Supports .png, .jpg /.jpeg, .tga and .bmp. Providing a directory path (ex. "save/here/screenshot.png") will create the necessary folder structure in script-output. Defaults to "screenshot.png".

player: LuaAny

The player to focus on. Defaults to the local player.

position: MapPosition

If defined, the screenshot will be centered on this position. Otherwise, the screenshot will center on player.

quality: i32

The .jpg render quality as a percentage (from 0% to 100% inclusive), if used. A lower value means a more compressed image. Defaults to 80.

resolution: TilePosition

The maximum allowed resolution is 16384x16384 (8192x8192 when anti_alias is true), but the maximum recommended resolution is 4096x4096 (resp. 2048x2048). The x value of the position is used as the width, the y value as the height.

show_cursor_building_preview: bool

When true and when player is specified, the building preview for the item in the player’s cursor will also be rendered. Defaults to false.

show_entity_info: bool

Whether to include entity info (“Alt mode”) or not. Defaults to false.

show_gui: bool

Whether to include GUIs in the screenshot or not. Defaults to false.

surface: LuaAny

If defined, the screenshot will be taken on this surface.

water_tick: u32

Overrides the tick of water animation, if animated water is enabled.

zoom: f64

The map zoom to take the screenshot at. Defaults to 1.