LuaGameScriptTakeTechnologyScreenshotParams

Struct LuaGameScriptTakeTechnologyScreenshotParams 

pub struct LuaGameScriptTakeTechnologyScreenshotParams {
    pub allow_in_replay: Option<bool>,
    pub path: Option<String>,
    pub player: PlayerIdentification,
    pub quality: Option<i32>,
    pub selected_technology: Option<TechnologyID>,
    pub skip_disabled: Option<bool>,
}
Take a screenshot of the technology screen and save it to the script-output folder, located in the game’s user data directory. The name of the image file can be specified via the path parameter.

Fields

allow_in_replay: Option<bool>

Whether to save the screenshot even during replay playback. Defaults to false.

path: Option<String>

The name of the image file. It should include a file extension indicating the desired format. Supports .png, .jpg /.jpeg, .tga and .bmp. Providing a directory path (ex. "save/here/screenshot.png") will create the necessary folder structure in script-output. Defaults to "technology-screenshot.png".

player: PlayerIdentification

The screenshot will be taken for this player.

quality: Option<i32>

The .jpg render quality as a percentage (from 0% to 100% inclusive), if used. A lower value means a more compressed image. Defaults to 80.

selected_technology: Option<TechnologyID>

The technology to highlight.

skip_disabled: Option<bool>

If true, disabled technologies will be skipped. Their successors will be attached to the disabled technology’s parents. Defaults to false.