pub struct LuaGroup;Expand description
Item group or subgroup.
Implementations
Sourceimpl LuaGroup
impl LuaGroup
Sourcepub fn localised_name(&self) -> &str
pub fn localised_name(&self) -> &str
Localised name of the group.
pub fn name(&self) -> &str
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn order(&self) -> &str
pub fn order(&self) -> &str
The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.
Sourcepub fn order_in_recipe(&self) -> &str
pub fn order_in_recipe(&self) -> &str
The additional order value used in recipe ordering.
pub fn type(&self) -> &str
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.