LuaInserterControlBehavior

Struct LuaInserterControlBehavior 

pub struct LuaInserterControlBehavior;
Control behavior for inserters.

Implementations

Source

impl LuaInserterControlBehavior

pub fn entity(&self) -> LuaEntity

The entity this control behavior belongs to.

pub fn input_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to read signals from. Defaults to both wire colors.

nil if this control behavior does not allow selecting the input networks.

pub fn output_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to send signals to. Defaults to both wire colors.

nil if this control behavior does not allow selecting the output networks.

pub fn type(&self) -> &str

The concrete type of this control behavior.

pub fn circuit_condition(&self) -> CircuitConditionDefinition

The circuit condition. Writing nil clears the circuit condition.

pub fn circuit_enable_disable(&self) -> bool

true if this entity enable/disable state is controlled by circuit condition

pub fn connect_to_logistic_network(&self) -> bool

true if this should connect to the logistic network.

pub fn disabled(&self) -> bool

If the entity is currently disabled because of the control behavior.

pub fn logistic_condition(&self) -> CircuitConditionDefinition

The logistic condition. Writing nil clears the logistic condition.

pub fn circuit_hand_read_mode(&self) -> &str

The hand read mode for the inserter.

pub fn circuit_read_hand_contents(&self) -> bool

true if the contents of the inserter hand should be sent to the circuit network

pub fn circuit_set_filters(&self) -> bool

true if filters are set from circuit network

pub fn circuit_set_stack_size(&self) -> bool

If the stack size of the inserter is set through the circuit network or not.

pub fn circuit_stack_control_signal(&self) -> SignalID

The signal used to set the stack size of the inserter.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>