pub struct LuaItemCommonBuildBlueprintParams {
pub build_mode: String,
pub by_player: LuaAny,
pub direction: String,
pub force: LuaAny,
pub position: MapPosition,
pub raise_built: bool,
pub skip_fog_of_war: bool,
pub surface: LuaAny,
}Expand description
Build this blueprint at the given location.
Built entities can be come invalid between the building of the blueprint and the function returning if by_player or raise_built is used and one of those events invalidates the entity.
Fields
build_mode: StringIf normal, blueprint will not be built if any one thing can’t be built. If forced, anything that can be built is built and obstructing nature entities will be deconstructed. If superforced, all obstructions will be deconstructed and the blueprint will be built.
by_player: LuaAnyThe player to use if any. If provided defines.events.on_built_entity will be fired for new entities and defines.events.on_blueprint_settings_pasted will be fired for existing entities that are updated.
direction: StringThe direction to use when building
force: LuaAnyForce to use for the building
position: MapPositionThe position to build at
raise_built: boolIf true; defines.events.script_raised_built will be fired for new entities and defines.events.on_blueprint_settings_pasted will be fired for existing entities that are updated. Note: this is ignored if by_player is provided.
skip_fog_of_war: boolIf chunks covered by fog-of-war are skipped.
surface: LuaAnySurface to build on