LuaItemCommonCreateBlueprintParams

Struct LuaItemCommonCreateBlueprintParams 

pub struct LuaItemCommonCreateBlueprintParams {
    pub always_include_tiles: bool,
    pub area: BoundingBox,
    pub force: ForceID,
    pub include_entities: bool,
    pub include_fuel: bool,
    pub include_modules: bool,
    pub include_station_names: bool,
    pub include_trains: bool,
    pub surface: SurfaceIdentification,
}
Sets up this blueprint using the found blueprintable entities/tiles on the surface.

Fields

always_include_tiles: bool

When true, blueprintable tiles are always included in the blueprint. When false they’re only included if no entities exist in the setup area. Defaults to false.

area: BoundingBox

The bounding box

force: ForceID

Force to use for the creation

include_entities: bool

When true, entities are included in the blueprint. Defaults to true.

include_fuel: bool

When true, train fuel is included in the blueprint, Defaults to true.

include_modules: bool

When true, modules are included in the blueprint. Defaults to true.

include_station_names: bool

When true, station names are included in the blueprint. Defaults to false.

include_trains: bool

When true, trains are included in the blueprint. Defaults to false.

surface: SurfaceIdentification

Surface to create from