pub struct LuaLabControlBehavior;Expand description
Control behavior for lab.
Implementations
Sourceimpl LuaLabControlBehavior
impl LuaLabControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn set_input_networks(&self, value: CircuitNetworkSelection)
pub fn set_input_networks(&self, value: CircuitNetworkSelection)
Set the input_networks attribute (Lua: self.input_networks = value).
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn set_output_networks(&self, value: CircuitNetworkSelection)
pub fn set_output_networks(&self, value: CircuitNetworkSelection)
Set the output_networks attribute (Lua: self.output_networks = value).
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn object_name(&self) -> &'static str
pub fn object_name(&self) -> &'static str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
pub fn read_contents(&self) -> bool
Sourcepub fn set_read_contents(&self, value: bool)
pub fn set_read_contents(&self, value: bool)
Set the read_contents attribute (Lua: self.read_contents = value).
Sourcepub fn set_read_fuel(&self, value: bool)
pub fn set_read_fuel(&self, value: bool)
Set the read_fuel attribute (Lua: self.read_fuel = value).
true if the fuel (content of energy source) should be read.
pub fn read_research_cost(&self) -> bool
Sourcepub fn set_read_research_cost(&self, value: bool)
pub fn set_read_research_cost(&self, value: bool)
Set the read_research_cost attribute (Lua: self.read_research_cost = value).
pub fn read_technology_level(&self) -> bool
Sourcepub fn set_read_technology_level(&self, value: bool)
pub fn set_read_technology_level(&self, value: bool)
Set the read_technology_level attribute (Lua: self.read_technology_level = value).
pub fn research_conditions(&self) -> Vec<ResearchCondition>
Sourcepub fn set_research_conditions(&self, value: Vec<ResearchCondition>)
pub fn set_research_conditions(&self, value: Vec<ResearchCondition>)
Set the research_conditions attribute (Lua: self.research_conditions = value).
pub fn set_research(&self) -> bool
Sourcepub fn set_set_research(&self, value: bool)
pub fn set_set_research(&self, value: bool)
Set the set_research attribute (Lua: self.set_research = value).
pub fn technology_level_signal(&self) -> SignalID
Sourcepub fn set_technology_level_signal(&self, value: SignalID)
pub fn set_technology_level_signal(&self, value: SignalID)
Set the technology_level_signal attribute (Lua: self.technology_level_signal = value).
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &'static str, ) -> Option<LuaCircuitNetwork>