pub struct LuaLogisticContainerControlBehavior;Expand description
Control behavior for logistic chests.
Implementations
Sourceimpl LuaLogisticContainerControlBehavior
impl LuaLogisticContainerControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn circuit_condition(&self) -> CircuitConditionDefinition
pub fn circuit_condition(&self) -> CircuitConditionDefinition
The circuit condition for the logistic container.
Sourcepub fn circuit_condition_enabled(&self) -> bool
pub fn circuit_condition_enabled(&self) -> bool
Whether the circuit condition is in effect.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn read_contents(&self) -> bool
pub fn read_contents(&self) -> bool
true if this logistic container is sending its content to a circuit network.
Sourcepub fn set_requests(&self) -> bool
pub fn set_requests(&self) -> bool
true if this logistic container has its requests set by a circuit network.
Can only be set to true on containers whose logistic_mode or override_logistic_mode is set to "requester" or "buffer".
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>