LuaLogisticNetwork

Struct LuaLogisticNetwork 

pub struct LuaLogisticNetwork;
A single logistic network of a given force on a given surface.

Implementations

Source

impl LuaLogisticNetwork

pub fn active_provider_points(&self) -> Vec<LuaLogisticPoint>

All active provider points in this network.

pub fn all_construction_robots(&self) -> u32

The total number of construction robots in the network (idle and active + in roboports).

pub fn all_logistic_robots(&self) -> u32

The total number of logistic robots in the network (idle and active + in roboports).

pub fn available_construction_robots(&self) -> u32

Number of construction robots available for a job.

pub fn available_logistic_robots(&self) -> u32

Number of logistic robots available for a job.

pub fn cells(&self) -> Vec<LuaLogisticCell>

All cells in this network.

pub fn construction_robots(&self) -> Vec<LuaEntity>

All currently deployed construction robots in this logistic network.

pub fn custom_name(&self) -> &str

The custom logistic network name set by the player or by script, if any.

pub fn empty_provider_points(&self) -> Vec<LuaLogisticPoint>

All things that have empty provider points in this network.

pub fn empty_providers(&self) -> Vec<LuaEntity>

All entities that have empty logistic provider points in this network.

pub fn force(&self) -> LuaForce

The force this logistic network belongs to.

pub fn logistic_members(&self) -> Vec<LuaEntity>

All other entities that have logistic points in this network (inserters mostly).

pub fn logistic_robots(&self) -> Vec<LuaEntity>

All currently deployed logistic robots in this logistic network.

pub fn network_id(&self) -> u32

The unique logistic network ID.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn passive_provider_points(&self) -> Vec<LuaLogisticPoint>

All passive provider points in this network.

pub fn provider_points(&self) -> Vec<LuaLogisticPoint>

All things that have provider points in this network.

pub fn providers(&self) -> Vec<LuaEntity>

All entities that have logistic provider points in this network.

pub fn requester_points(&self) -> Vec<LuaLogisticPoint>

All things that have requester points in this network.

pub fn requesters(&self) -> Vec<LuaEntity>

All entities that have logistic requester points in this network.

pub fn robot_limit(&self) -> u32

Maximum number of robots the network can work with. Currently only used for the personal roboport.

pub fn robots(&self) -> Vec<LuaEntity>

All currently deployed robots in this logistic network.

pub fn storage_points(&self) -> Vec<LuaLogisticPoint>

All things that have storage points in this network.

pub fn storages(&self) -> Vec<LuaEntity>

All entities that have logistic storage points in this network.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn can_satisfy_request( &self, count: Option<u32>, include_buffers: Option<bool>, item: LuaAny, ) -> bool

Can the network satisfy a request for a given item and count.

pub fn find_cell_closest_to( &self, position: MapPosition, ) -> Option<LuaLogisticCell>

Find logistic cell closest to a given position.

pub fn get_contents( &self, member: Option<LuaLogisticNetworkMember>, ) -> Vec<ItemWithQualityCount>

Get item counts for the entire network, similar to how LuaInventory::get_contents does.

pub fn get_item_count( &self, item: Option<LuaAny>, member: Option<LuaLogisticNetworkMember>, ) -> i32

Count given or all items in the network or given members.

pub fn get_supply_counts(&self, item: LuaAny) -> LogisticsNetworkSupplyCounts

Get the amount of items of the given type indexed by the storage member.

pub fn get_supply_points(&self, item: LuaAny) -> LogisticsNetworkSupplyPoints

Gets the logistic points with of the given type indexed by the storage member.

pub fn insert( &self, item: LuaAny, members: Option<LuaLogisticNetworkMembers>, ) -> u32

Insert items into the logistic network. This will actually insert the items into some logistic chests.

pub fn remove_item( &self, item: LuaAny, members: Option<LuaLogisticNetworkMembers2>, ) -> u32

Remove items from the logistic network. This will actually remove the items from some logistic chests.

pub fn select_drop_point( &self, params: LuaLogisticNetworkSelectDropPointParams, ) -> Option<LuaLogisticPoint>

Find a logistic point to drop the specific item stack.

pub fn select_pickup_point( &self, params: LuaLogisticNetworkSelectPickupPointParams, ) -> Option<LuaLogisticPoint>

Find the ‘best’ logistic point with this item ID and from the given position or from given chest type.