pub struct LuaLogisticNetworkSelectDropPointParams {
pub members: LuaLogisticNetworkMembers,
pub stack: LuaAny,
}Expand description
Find a logistic point to drop the specific item stack.
Fields
members: LuaLogisticNetworkMembersWhen given, it will find from only the specific type of member. If not specified, selects with normal priorities.
stack: LuaAnyName of the item to drop off.