LuaLogisticNetworkSelectPickupPointParams

Struct LuaLogisticNetworkSelectPickupPointParams 

pub struct LuaLogisticNetworkSelectPickupPointParams {
    pub include_buffers: bool,
    pub members: LuaLogisticNetworkMembers2,
    pub name: ItemWithQualityID,
    pub position: MapPosition,
}
Find the ‘best’ logistic point with this item ID and from the given position or from given chest type.

Fields

include_buffers: bool

Whether to consider buffer chests or not. Defaults to false. Only considered if selecting with position.

members: LuaLogisticNetworkMembers2

When given, it will find from only the specific type of member. If not specified, selects with normal priorities. Not considered if position is specified.

name: ItemWithQualityID

Name of the item to pick up.

position: MapPosition

When given, it will find the storage ‘best’ storage point from this position.