LuaLogisticPoint

Struct LuaLogisticPoint 

pub struct LuaLogisticPoint;
Logistic point of a particular LuaEntity. A “Logistic point” is the name given for settings and properties used by requester, provider, and storage points in a given logistic network. These “points” don’t have to be a logistic container but often are. One other entity that can own several points is the “character” character type entity.

Implementations

Source

impl LuaLogisticPoint

pub fn enabled(&self) -> bool

Whether this logistic point is active, related to disabling logistics on player/spidertron.

When the logistic point is disabled it won’t request and auto trash will do nothing.

pub fn exact(&self) -> bool

If this logistic point is using the exact mode. In exact mode robots never over-deliver requests.

pub fn filters(&self) -> Vec<CompiledLogisticFilter>

The logistic filters for this logistic point, if this uses any.

The returned array will always have an entry for each filter and will be indexed in sequence when not nil.

pub fn force(&self) -> LuaForce

The force of this logistic point.

This will always be the same as the LuaLogisticPoint::owner force.

pub fn logistic_member_index(&self) -> &str

The Logistic member index of this logistic point.

pub fn logistic_network(&self) -> LuaLogisticNetwork

pub fn mode(&self) -> &str

The logistic mode.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn owner(&self) -> LuaEntity

The LuaEntity owner of this LuaLogisticPoint.

pub fn sections(&self) -> Vec<LuaLogisticSection>

All logistic sections of this logistic point.

pub fn sections_count(&self) -> u32

Amount of logistic sections this logistic point has.

pub fn targeted_items_deliver(&self) -> Vec<ItemWithQualityCount>

Items targeted to be dropped off into this logistic point by robots or cargo pods.

pub fn targeted_items_pickup(&self) -> Vec<ItemWithQualityCount>

Items targeted to be picked up from this logistic point by robots.

pub fn trash_not_requested(&self) -> bool

Whether this logistic point is set to trash unrequested items.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn add_section(&self, group: Option<&str>) -> Option<LuaLogisticSection>

Adds a new logistic section to this logistic point if possible.

pub fn get_section(&self, section_index: u32) -> LuaLogisticSection

Gets section on the selected index, if it exists

pub fn remove_section(&self, section_index: u32) -> bool

Removes the given logistic section if possible. Removal may fail if the section index is out of range or the section is not manual.