pub struct LuaModSettingPrototype;Expand description
Prototype of a mod setting.
Implementations
Sourceimpl LuaModSettingPrototype
impl LuaModSettingPrototype
Sourcepub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
Extra description items in the tooltip and Factoriopedia.
Sourcepub fn factoriopedia_description(&self) -> &str
pub fn factoriopedia_description(&self) -> &str
Provides additional description used in factoriopedia.
pub fn localised_description(&self) -> &str
pub fn localised_name(&self) -> &str
Sourcepub fn order(&self) -> &str
pub fn order(&self) -> &str
The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.
pub fn parameter(&self) -> bool
Sourcepub fn allow_blank(&self) -> bool
pub fn allow_blank(&self) -> bool
Whether this string setting allows blank values. nil if not a string setting.
Sourcepub fn allowed_values(&self) -> LuaAny
pub fn allowed_values(&self) -> LuaAny
The allowed values for this setting. nil if this setting doesn’t use the a fixed set of values.
Sourcepub fn auto_trim(&self) -> bool
pub fn auto_trim(&self) -> bool
Whether this string setting auto-trims values. nil if not a string setting
Sourcepub fn default_value(&self) -> LuaAny
pub fn default_value(&self) -> LuaAny
The default value of this setting.
Sourcepub fn maximum_value(&self) -> LuaAny
pub fn maximum_value(&self) -> LuaAny
The maximum value for this setting. nil if this setting type doesn’t support a maximum.
Sourcepub fn minimum_value(&self) -> LuaAny
pub fn minimum_value(&self) -> LuaAny
The minimum value for this setting. nil if this setting type doesn’t support a minimum.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
pub fn setting_type(&self) -> LuaModSettingPrototypeSettingType
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.