pub struct LuaParticlePrototype;Expand description
Prototype of an optimized particle.
Implementations
Sourceimpl LuaParticlePrototype
impl LuaParticlePrototype
Sourcepub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
Extra description items in the tooltip and Factoriopedia.
Sourcepub fn factoriopedia_description(&self) -> &str
pub fn factoriopedia_description(&self) -> &str
Provides additional description used in factoriopedia.
pub fn localised_description(&self) -> &str
pub fn localised_name(&self) -> &str
Sourcepub fn order(&self) -> &str
pub fn order(&self) -> &str
The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.
pub fn parameter(&self) -> bool
pub fn ended_in_water_trigger_effect(&self) -> TriggerEffectItem
pub fn ended_on_ground_trigger_effect(&self) -> TriggerEffectItem
pub fn fade_out_time(&self) -> u32
pub fn life_time(&self) -> u32
pub fn mining_particle_frame_speed(&self) -> f32
pub fn movement_modifier(&self) -> f32
pub fn movement_modifier_when_on_ground(&self) -> f32
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
pub fn regular_trigger_effect(&self) -> TriggerEffectItem
pub fn regular_trigger_effect_frequency(&self) -> u32
pub fn render_layer(&self) -> LuaAny
pub fn render_layer_when_on_ground(&self) -> LuaAny
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn vertical_acceleration(&self) -> f32