LuaPermissionGroup

Struct LuaPermissionGroup 

pub struct LuaPermissionGroup;
A permission group that defines what players in this group are allowed to do.

Implementations

Source

impl LuaPermissionGroup

pub fn group_id(&self) -> u32

The group ID

pub fn name(&self) -> &'static str

The name of this group. Setting the name to nil or an empty string sets the name to the default value.

pub fn object_name(&self) -> &'static str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn players(&self) -> Vec<LuaPlayer>

The players in this group.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn add_player(&self, player: PlayerIdentification) -> bool

Adds the given player to this group.

pub fn allows_action(&self, action: &'static str) -> bool

Whether this group allows the given action.

pub fn destroy(&self) -> bool

Destroys this group.

pub fn remove_player(&self, player: PlayerIdentification) -> bool

Removes the given player from this group.

pub fn set_allows_action( &self, action: &'static str, allow_action: bool, ) -> bool

Sets whether this group allows the performance the given action.