pub struct LuaPermissionGroups;Expand description
All permission groups.
Implementations
Sourceimpl LuaPermissionGroups
impl LuaPermissionGroups
Sourcepub fn groups(&self) -> Vec<LuaPermissionGroup>
pub fn groups(&self) -> Vec<LuaPermissionGroup>
All of the permission groups.
Sourcepub fn object_name(&self) -> &'static str
pub fn object_name(&self) -> &'static str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
Sourcepub fn create_group(
&self,
name: Option<&'static str>,
) -> Option<LuaPermissionGroup>
pub fn create_group( &self, name: Option<&'static str>, ) -> Option<LuaPermissionGroup>
Creates a new permission group.
Sourcepub fn get_group(&self, group: IndexOrName) -> Option<LuaPermissionGroup>
pub fn get_group(&self, group: IndexOrName) -> Option<LuaPermissionGroup>
Gets the permission group with the given name or group ID.