pub struct LuaPlayerAddPinParams {
pub always_visible: Option<bool>,
pub chart_tag: Option<LuaCustomChartTag>,
pub entity: Option<LuaEntity>,
pub label: Option<String>,
pub player: Option<PlayerIdentification>,
pub position: Option<MapPosition>,
pub preview_distance: Option<u16>,
pub resource: Option<EntityID>,
pub surface: Option<SurfaceIdentification>,
}Expand description
Adds a pin to this player for the given pin specification. Either entity, player, or surface and position must be defined.
Fields
always_visible: Option<bool>Defaults to true.
chart_tag: Option<LuaCustomChartTag>The tag to pin.
entity: Option<LuaEntity>The entity to pin.
label: Option<String>player: Option<PlayerIdentification>The player to pin.
position: Option<MapPosition>Where to create the pin. Required when surface is defined or resource is defined.
preview_distance: Option<u16>Defaults to 16.
resource: Option<EntityID>The resource prototype to add an entire resource patch with.
surface: Option<SurfaceIdentification>The surface to create the pin on. Required when resource is defined.