pub struct LuaPlayerBuildFromCursorParams {
pub build_mode: Option<String>,
pub direction: Option<String>,
pub flip_horizontal: Option<bool>,
pub flip_vertical: Option<bool>,
pub mirror: Option<bool>,
pub position: MapPosition,
pub skip_fog_of_war: Option<bool>,
pub terrain_building_size: Option<u32>,
}Expand description
Builds whatever is in the cursor on the surface the player is on. The cursor stack will automatically be reduced as if the player built normally.
Fields
build_mode: Option<String>Which build mode should be used instead of normal build. Defaults to defines.build_mode.normal.
direction: Option<String>Direction the entity would be placed
flip_horizontal: Option<bool>Whether to flip the blueprint horizontally. Defaults to false.
flip_vertical: Option<bool>Whether to flip the blueprint vertically. Defaults to false.
mirror: Option<bool>Whether to mirror the entity
position: MapPositionWhere the entity would be placed
skip_fog_of_war: Option<bool>If chunks covered by fog-of-war are skipped. Defaults to false.
terrain_building_size: Option<u32>The size for building terrain if building terrain. Defaults to 2.