LuaPlayerCanBuildFromCursorParams

Struct LuaPlayerCanBuildFromCursorParams 

pub struct LuaPlayerCanBuildFromCursorParams {
    pub build_mode: String,
    pub direction: String,
    pub flip_horizontal: bool,
    pub flip_vertical: bool,
    pub position: MapPosition,
    pub skip_fog_of_war: bool,
    pub terrain_building_size: u32,
}
Checks if this player can build what ever is in the cursor on the surface the player is on.

Fields

build_mode: String

Which build mode should be used instead of normal build. Defaults to defines.build_mode.normal.

direction: String

Direction the entity would be placed

flip_horizontal: bool

Whether to flip the blueprint horizontally. Defaults to false.

flip_vertical: bool

Whether to flip the blueprint vertically. Defaults to false.

position: MapPosition

Where the entity would be placed

skip_fog_of_war: bool

If chunks covered by fog-of-war are skipped. Defaults to false.

terrain_building_size: u32

The size for building terrain if building terrain. Defaults to 2.