LuaPlayerConnectToServerParams

Struct LuaPlayerConnectToServerParams 

pub struct LuaPlayerConnectToServerParams {
    pub address: String,
    pub description: String,
    pub name: String,
    pub password: String,
}
Asks the player if they would like to connect to the given server.

If the “auto-accept-connect-to-server” interface setting is enabled, the prompt is skipped.

This only does anything when used on a multiplayer peer. Single player and server hosts will ignore the prompt.

Fields

address: String

The server (address:port) if port is not given the default Factorio port is used.

description: Stringname: String

The name of the server.

password: String

The password if different from the one used to join this game. Note, if the current password is not empty but the one required to join the new server is an empty string should be given for this field.