LuaQualityPrototype

Struct LuaQualityPrototype 

pub struct LuaQualityPrototype;
Prototype of a quality.

Implementations

Source

impl LuaQualityPrototype

pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>

Extra description items in the tooltip and Factoriopedia.

pub fn factoriopedia_description(&self) -> &str

Provides additional description used in factoriopedia.

pub fn group(&self) -> LuaGroup

Group of this prototype.

pub fn hidden(&self) -> bool

pub fn hidden_in_factoriopedia(&self) -> bool

pub fn localised_description(&self) -> &str

pub fn localised_name(&self) -> &str

pub fn name(&self) -> &str

Name of this prototype.

pub fn order(&self) -> &str

The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.

pub fn parameter(&self) -> bool

pub fn subgroup(&self) -> LuaGroup

Subgroup of this prototype.

pub fn type(&self) -> &str

Type of this prototype.

pub fn accumulator_capacity_multiplier(&self) -> f64

pub fn asteroid_collector_collection_radius_bonus(&self) -> u32

pub fn beacon_module_slots_bonus(&self) -> u16

pub fn beacon_power_usage_multiplier(&self) -> f32

pub fn beacon_supply_area_distance_bonus(&self) -> f32

pub fn cargo_wagon_inventory_size_multiplier(&self) -> f64

pub fn chain_probability(&self) -> f64

Probability of additional quality increase happening after quality was increased to reach this quality in the same crafting/mining operation.

pub fn color(&self) -> Color

The color of the prototype

pub fn crafting_machine_energy_usage_multiplier(&self) -> f64

pub fn crafting_machine_module_slots_bonus(&self) -> u16

pub fn crafting_machine_speed_multiplier(&self) -> f64

pub fn default_multiplier(&self) -> f64

pub fn draw_sprite_by_default(&self) -> bool

pub fn electric_pole_supply_area_distance_bonus(&self) -> f32

pub fn electric_pole_wire_reach_bonus(&self) -> f32

pub fn equipment_grid_height_bonus(&self) -> i16

pub fn equipment_grid_width_bonus(&self) -> i16

pub fn fluid_wagon_capacity_multiplier(&self) -> f64

pub fn flying_robot_max_energy_multiplier(&self) -> f64

pub fn inserter_speed_multiplier(&self) -> f64

pub fn inventory_size_multiplier(&self) -> f64

pub fn lab_module_slots_bonus(&self) -> u16

pub fn lab_research_speed_multiplier(&self) -> f64

pub fn level(&self) -> u32

Level basically specifies the stat-increasing value of this quality level.

pub fn locomotive_power_multiplier(&self) -> f64

pub fn logistic_cell_charging_energy_multiplier(&self) -> f64

pub fn logistic_cell_charging_station_count_bonus(&self) -> u32

pub fn mining_drill_mining_radius_bonus(&self) -> f32

pub fn mining_drill_module_slots_bonus(&self) -> u16

pub fn mining_drill_resource_drain_multiplier(&self) -> f32

pub fn module_consumption_multiplier(&self) -> f32

pub fn module_pollution_multiplier(&self) -> f32

pub fn module_productivity_multiplier(&self) -> f32

pub fn module_quality_multiplier(&self) -> f32

pub fn module_speed_multiplier(&self) -> f32

pub fn next(&self) -> LuaQualityPrototype

The next higher level of the quality

pub fn next_probability(&self) -> f64

The probability multiplier of getting the next level of quality.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn previous(&self) -> LuaQualityPrototype

pub fn previous_chain_probability(&self) -> f64

Probability of additional quality decrease happening after quality was decreased to reach this quality in the same crafting/mining operation.

pub fn previous_probability(&self) -> f64

The probability multiplier of getting the previous level of quality.

pub fn range_multiplier(&self) -> f64

pub fn rolling_stock_max_speed_multiplier(&self) -> f64

pub fn science_pack_drain_multiplier(&self) -> f32

pub fn spoil_ticks_multiplier(&self) -> f32

pub fn tool_durability_multiplier(&self) -> f64

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.