pub struct LuaRCON;Expand description
An interface to send messages to the calling RCON interface through the global object named rcon.
Implementations
Sourceimpl LuaRCON
impl LuaRCON
Sourcepub fn object_name(&self) -> &'static str
pub fn object_name(&self) -> &'static str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn print(&self, message: impl Into<LocalisedString>)
pub fn print(&self, message: impl Into<LocalisedString>)
Print text to the calling RCON interface if any.