LuaRadarControlBehavior

Struct LuaRadarControlBehavior 

pub struct LuaRadarControlBehavior;
Control behavior for radars

Implementations

Source

impl LuaRadarControlBehavior

pub fn entity(&self) -> LuaEntity

The entity this control behavior belongs to.

pub fn input_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to read signals from. Defaults to both wire colors.

nil if this control behavior does not allow selecting the input networks.

pub fn output_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to send signals to. Defaults to both wire colors.

nil if this control behavior does not allow selecting the output networks.

pub fn type(&self) -> &str

The concrete type of this control behavior.

pub fn mode(&self) -> &str

Whether this radar is in universe (channel) or surface mode.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn universe_channel(&self) -> SignalID

The channel that is used in universe mode. Radars on the same force with the same channel in universe mode are connected to each other with hidden radar wires.

If the channel is empty or a parameter, the radar will be disconnected.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>