LuaRailPath

Struct LuaRailPath 

pub struct LuaRailPath;
A rail path.

Implementations

Source

impl LuaRailPath

pub fn current(&self) -> u32

The current rail index.

pub fn is_front(&self) -> bool

If the path goes from the front of the train

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn rails(&self) -> LuaAny

Array of the rails that this path travels over.

pub fn size(&self) -> u32

The total number of rails in this path.

pub fn total_distance(&self) -> f64

The total path distance.

pub fn travelled_distance(&self) -> f64

The total distance traveled.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.