LuaReactorControlBehavior

Struct LuaReactorControlBehavior 

pub struct LuaReactorControlBehavior;
Control behavior for Reactor

Implementations

Source

impl LuaReactorControlBehavior

pub fn entity(&self) -> LuaEntity

The entity this control behavior belongs to.

pub fn input_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to read signals from. Defaults to both wire colors.

nil if this control behavior does not allow selecting the input networks.

pub fn output_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to send signals to. Defaults to both wire colors.

nil if this control behavior does not allow selecting the output networks.

pub fn type(&self) -> &str

The concrete type of this control behavior.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn read_fuel(&self) -> bool

If this will read fuel inventory and currently burning fuel

pub fn read_temperature(&self) -> bool

If this will read temperature of the reactor

pub fn temperature_signal(&self) -> SignalID

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>