LuaRecipe

Struct LuaRecipe 

pub struct LuaRecipe;
A crafting recipe. Recipes belong to forces (see LuaForce) because some recipes are unlocked by research, and researches are per-force.

Implementations

Source

impl LuaRecipe

pub fn categories(&self) -> Vec<&str>

Categories of the recipe.

pub fn enabled(&self) -> bool

Can the recipe be used?

pub fn energy(&self) -> f64

Energy required to execute this recipe. This directly affects the crafting time: Recipe’s energy is exactly its crafting time in seconds, when crafted in an assembling machine with crafting speed exactly equal to one.

pub fn force(&self) -> LuaForce

The force that owns this recipe.

pub fn group(&self) -> LuaGroup

Group of this recipe.

pub fn hidden(&self) -> bool

Is the recipe hidden? Hidden recipes don’t show up in the crafting menu.

pub fn hidden_from_flow_stats(&self) -> bool

Is the recipe hidden from flow statistics?

pub fn ingredients(&self) -> Vec<Ingredient>

The ingredients to this recipe.

pub fn localised_description(&self) -> &str

pub fn localised_name(&self) -> &str

Localised name of the recipe.

pub fn name(&self) -> &str

Name of the recipe. This can be different than the name of the result items as there could be more recipes to make the same item.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn order(&self) -> &str

The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.

pub fn productivity_bonus(&self) -> f32

The productivity bonus for this recipe.

pub fn products(&self) -> Vec<LuaAny>

The results/products of this recipe.

pub fn prototype(&self) -> LuaRecipePrototype

The prototype for this recipe.

pub fn subgroup(&self) -> LuaGroup

Subgroup of this recipe.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn has_category(&self, category: LuaAny) -> bool

Checks if recipe has given category

pub fn reload(&self)

Reload the recipe from the prototype.