LuaRecord

Struct LuaRecord 

pub struct LuaRecord;
A reference to a record in the blueprint library. Records in the “my blueprints” shelf are read-only, but records in the “game blueprints” shelf are read/write.

Implementations

Source

impl LuaRecord

pub fn blueprint_absolute_snapping(&self) -> bool

If absolute snapping is enabled on this blueprint.

pub fn blueprint_description(&self) -> &str

The description for this blueprint or blueprint book.

pub fn blueprint_position_relative_to_grid(&self) -> TilePosition

The offset from the absolute grid. nil if absolute snapping is not enabled.

pub fn blueprint_snap_to_grid(&self) -> TilePosition

The snapping grid size in this blueprint. nil if snapping is not enabled.

pub fn contents(&self) -> LuaAny

The contents of this BlueprintBookRecord. This is sparse array - it may have gaps, so using # will not be reliable. Use LuaRecord::contents_size or pairs() to iterate this table.

pub fn contents_size(&self) -> u16

The highest populated index in the contents of this BlueprintBookRecord.

pub fn cost_to_build(&self) -> Vec<ItemWithQualityCount>

List of raw materials required to build this blueprint.

pub fn default_icons(&self) -> Vec<BlueprintSignalIcon>

The default icons for a blueprint blueprint.

pub fn entity_filter_count(&self) -> u32

The number of entity filters this deconstruction planner has.

pub fn entity_filter_mode(&self) -> &str

The blacklist/whitelist entity filter mode for this deconstruction planner.

pub fn entity_filters(&self) -> Vec<ItemFilter>

The entity filters for this deconstruction planner. The attribute is a sparse array with the keys representing the index of the filter. All prototypes in this array must not have the "not-deconstructable" flag set and are either a cliff or marked as minable.

pub fn is_preview(&self) -> bool

Checks if this record is in a preview state.

pub fn label(&self) -> &str

The current label for this record, if any.

pub fn mapper_count(&self) -> u32

The current count of mappers in the upgrade item.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn planner_description(&self) -> &str

The description for this deconstruction planner or upgrade planner.

pub fn preview_icons(&self) -> Vec<BlueprintSignalIcon>

The preview icons for this record.

pub fn tile_filter_count(&self) -> u32

The number of tile filters this deconstruction planner has.

pub fn tile_filter_mode(&self) -> &str

The blacklist/whitelist tile filter mode for this deconstruction planner.

pub fn tile_filters(&self) -> Vec<LuaAny>

The tile filters for this deconstruction planner. The attribute is a sparse array with the keys representing the index of the filter. Reading filters always returns an array of strings which are the tile prototype names.

pub fn tile_selection_mode(&self) -> &str

The tile selection mode for this deconstruction planner.

pub fn trees_and_rocks_only(&self) -> bool

If this deconstruction planner, is set to allow trees and rocks only.

pub fn type(&self) -> LuaRecordType

The type of this blueprint record.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn valid_for_write(&self) -> bool

Is this record valid for writing? A record is invalid for write if it is a BlueprintRecord preview or if it is in the “My blueprints” shelf.

pub fn build_blueprint( &self, params: LuaRecordBuildBlueprintParams, ) -> Vec<LuaEntity>

Build this blueprint at the given location.

Built entities can be come invalid between the building of the blueprint and the function returning if by_player or raise_built is used and one of those events invalidates the entity.

pub fn cancel_deconstruct_area( &self, params: LuaRecordCancelDeconstructAreaParams, )

Cancel deconstruct the given area with this deconstruction planner.

pub fn clear_blueprint(&self)

Clears this blueprint.

pub fn clear_deconstruction_data(&self)

Clears all settings/filters on this deconstruction planner, resetting it to default values.

pub fn clear_upgrade_data(&self)

Clears all settings/filters on this upgrade planner, resetting it to default values.

pub fn create_blueprint(&self, params: LuaRecordCreateBlueprintParams) -> LuaAny

Sets up this blueprint using the found blueprintable entities/tiles on the surface.

pub fn deconstruct_area(&self, params: LuaRecordDeconstructAreaParams)

Deconstruct the given area with this deconstruction planner.

pub fn export_record(&self) -> &str

Exports this record to a string.

pub fn get_active_index(&self, player: LuaAny) -> u32

The active index of this BlueprintBookRecord. For records in “my blueprints”, the result will be the same regardless of the player, but records in “game blueprints” may have different active indices per player.

pub fn get_blueprint_entities(&self) -> Option<Vec<BlueprintEntity>>

The entities in this blueprint.

pub fn get_blueprint_entity_count(&self) -> u32

Gets the number of entities in this blueprint blueprint.

pub fn get_blueprint_entity_tag(&self, index: u32, tag: &str) -> Option<LuaAny>

Gets the given tag on the given blueprint entity index in this blueprint.

pub fn get_blueprint_entity_tags(&self, index: u32) -> LuaAny

Gets the tags for the given blueprint entity index in this blueprint.

pub fn get_blueprint_tiles(&self) -> Option<Vec<Tile>>

A list of the tiles in this blueprint.

pub fn get_entity_filter(&self, index: u32) -> Option<ItemFilter>

Gets the entity filter at the given index for this deconstruction planner.

pub fn get_mapper(&self, index: u32, type: LuaItemCommonType) -> LuaAny

Gets the filter at the given index for this upgrade item. Note that sources ("from" type) that are undefined will read as {type = "item"}, while destinations ("to" type) that are undefined will read as nil.

In contrast to LuaRecord::set_mapper, indices past the upgrade item’s current size are considered to be out of bounds.

pub fn get_selected_record(&self, player: LuaAny) -> Option<LuaRecord>

Gets the currently selected record of the book for the given player.

Note: this will return a record even if the book is in a preview state.

pub fn get_tile_filter(&self, index: u32) -> Option<&str>

Gets the tile filter at the given index for this deconstruction planner.

pub fn is_blueprint_setup(&self) -> bool

Is this blueprint setup? I.e. is it a non-empty blueprint?

pub fn set_blueprint_entities(&self, entities: Vec<BlueprintEntity>)

Set new entities to be a part of this blueprint.

pub fn set_blueprint_entity_tag(&self, index: u32, tag: &str, value: LuaAny)

Sets the given tag on the given blueprint entity index in this blueprint.

pub fn set_blueprint_entity_tags(&self, index: u32, tags: LuaAny)

Sets the tags on the given blueprint entity index in this blueprint.

pub fn set_blueprint_tiles(&self, tiles: Vec<Tile>)

Set specific tiles in this blueprint.

pub fn set_entity_filter(&self, filter: Option<ItemFilter>, index: u32) -> bool

Sets the entity filter at the given index for this deconstruction planner.

pub fn set_mapper(&self, index: u32, mapper: LuaAny, type: LuaItemCommonType)

Sets the module filter at the given index for this upgrade item.

In contrast to LuaRecord::get_mapper, indices past the upgrade item’s current size are valid and expand the list of mappings accordingly, if within reasonable bounds.

pub fn set_tile_filter(&self, filter: LuaAny, index: u32) -> bool

Sets the tile filter at the given index for this deconstruction planner.