LuaRecordBuildBlueprintParams

Struct LuaRecordBuildBlueprintParams 

pub struct LuaRecordBuildBlueprintParams {
    pub build_mode: String,
    pub by_player: LuaAny,
    pub direction: String,
    pub force: LuaAny,
    pub position: MapPosition,
    pub raise_built: bool,
    pub skip_fog_of_war: bool,
    pub surface: LuaAny,
}
Build this blueprint at the given location.

Built entities can be come invalid between the building of the blueprint and the function returning if by_player or raise_built is used and one of those events invalidates the entity.

Fields

build_mode: String

If normal, blueprint will not be built if any one thing can’t be built. If forced, anything that can be built is built and obstructing nature entities will be deconstructed. If superforced, all obstructions will be deconstructed and the blueprint will be built.

by_player: LuaAny

The player to use if any. If provided defines.events.on_built_entity will be fired for new entities and defines.events.on_blueprint_settings_pasted will be fired for existing entities that are updated.

direction: String

The direction to use when building

force: LuaAny

Force to use for the building

position: MapPosition

The position to build at

raise_built: bool

If true; defines.events.script_raised_built will be fired for new entities and defines.events.on_blueprint_settings_pasted will be fired for existing entities that are updated. Note: this is ignored if by_player is provided.

skip_fog_of_war: bool

If chunks covered by fog-of-war are skipped.

surface: LuaAny

Surface to build on