pub struct LuaRecordCreateBlueprintParams {
pub always_include_tiles: Option<bool>,
pub area: BoundingBox,
pub force: ForceID,
pub include_entities: Option<bool>,
pub include_fuel: Option<bool>,
pub include_modules: Option<bool>,
pub include_station_names: Option<bool>,
pub include_trains: Option<bool>,
pub surface: SurfaceIdentification,
}Expand description
Sets up this blueprint using the found blueprintable entities/tiles on the surface.
Fields
always_include_tiles: Option<bool>When true, blueprintable tiles are always included in the blueprint. When false they’re only included if no entities exist in the setup area. Defaults to false.
area: BoundingBoxThe bounding box
force: ForceIDForce to use for the creation
include_entities: Option<bool>When true, entities are included in the blueprint. Defaults to true.
include_fuel: Option<bool>When true, train fuel is included in the blueprint, Defaults to true.
include_modules: Option<bool>When true, modules are included in the blueprint. Defaults to true.
include_station_names: Option<bool>When true, station names are included in the blueprint. Defaults to false.
include_trains: Option<bool>When true, trains are included in the blueprint. Defaults to false.
surface: SurfaceIdentificationSurface to create from