pub struct LuaRenderingDrawAnimationParams {Show 21 fields
pub animation: String,
pub animation_offset: f64,
pub animation_speed: f64,
pub blink_interval: u16,
pub forces: ForceSet,
pub light_mode: ScriptSpriteLightMode,
pub only_in_alt_mode: bool,
pub orientation: RealOrientation,
pub orientation_target: ScriptRenderTarget,
pub oriented_offset: Vector,
pub players: Vec<PlayerIdentification>,
pub render_layer: LuaAny,
pub render_mode: ScriptRenderMode,
pub surface: SurfaceIdentification,
pub target: ScriptRenderTarget,
pub time_to_live: u32,
pub tint: Color,
pub use_target_orientation: bool,
pub visible: bool,
pub x_scale: f64,
pub y_scale: f64,
}Expand description
Create an animation.
Fields
animation: StringName of an AnimationPrototype.
animation_offset: f64Offset of the animation in frames. Default is 0.
animation_speed: f64How many frames the animation goes forward per tick. Default is 1.
blink_interval: u16In ticks. Defaults to 0 (no blinking). Game alerts use 30.
forces: ForceSetThe forces that this object is rendered to. Passing nil or an empty table will render it to all forces.
light_mode: ScriptSpriteLightModeWhether this object should be rendered as a sprite, light or both at once. Defaults to “occluder”.
only_in_alt_mode: boolIf this should only be rendered in alt mode. Defaults to false.
orientation: RealOrientationThe orientation of the animation. Default is 0.
orientation_target: ScriptRenderTargetIf given, the animation rotates so that it faces this target. Note that orientation is still applied to the animation.
oriented_offset: VectorOffsets the center of the animation if orientation_target is given. This offset will rotate together with the animation.
players: Vec<PlayerIdentification>The players that this object is rendered to. Passing nil or an empty table will render it to all players.
render_layer: LuaAnyRender layer of the animation. Defaults to "arrow".
render_mode: ScriptRenderModeMode which this object should render in. Defaults to “game”.
surface: SurfaceIdentificationtarget: ScriptRenderTargetCenter of the animation.
time_to_live: u32In ticks. Defaults to living forever.
tint: Coloruse_target_orientation: boolOnly used if orientation_target is a LuaEntity.
visible: boolIf this is rendered to anyone at all. Defaults to true.
x_scale: f64Horizontal scale of the animation. Default is 1.
y_scale: f64Vertical scale of the animation. Default is 1.