LuaRenderingDrawArcParams

Struct LuaRenderingDrawArcParams 

pub struct LuaRenderingDrawArcParams {
Show 15 fields pub angle: f32, pub blink_interval: u16, pub color: Color, pub draw_on_ground: bool, pub forces: LuaAny, pub max_radius: f64, pub min_radius: f64, pub only_in_alt_mode: bool, pub players: Vec<LuaAny>, pub render_mode: ScriptRenderMode, pub start_angle: f32, pub surface: LuaAny, pub target: LuaAny, pub time_to_live: u32, pub visible: bool,
}
Create an arc.

Fields

angle: f32

The angle of the arc, in radian.

blink_interval: u16

In ticks. Defaults to 0 (no blinking). Game alerts use 30.

color: Colordraw_on_ground: bool

If this should be drawn below sprites and entities. Defaults to false.

forces: LuaAny

The forces that this object is rendered to. Passing nil or an empty table will render it to all forces.

max_radius: f64

The radius of the outer edge of the arc, in tiles.

min_radius: f64

The radius of the inner edge of the arc, in tiles.

only_in_alt_mode: bool

If this should only be rendered in alt mode. Defaults to false.

players: Vec<LuaAny>

The players that this object is rendered to. Passing nil or an empty table will render it to all players.

render_mode: ScriptRenderMode

Mode which this object should render in. Defaults to “game”.

start_angle: f32

Where the arc starts, in radian.

surface: LuaAnytarget: LuaAnytime_to_live: u32

In ticks. Defaults to living forever.

visible: bool

If this is rendered to anyone at all. Defaults to true.