pub struct LuaRenderingDrawCircleParams {Show 14 fields
pub blink_interval: u16,
pub color: Color,
pub draw_on_ground: bool,
pub filled: bool,
pub forces: LuaAny,
pub only_in_alt_mode: bool,
pub players: Vec<LuaAny>,
pub radius: f64,
pub render_mode: ScriptRenderMode,
pub surface: LuaAny,
pub target: LuaAny,
pub time_to_live: u32,
pub visible: bool,
pub width: f32,
}Expand description
Create a circle.
Fields
blink_interval: u16In ticks. Defaults to 0 (no blinking). Game alerts use 30.
color: Colordraw_on_ground: boolIf this should be drawn below sprites and entities. Defaults to false.
filled: boolIf the circle should be filled. Defaults to false.
forces: LuaAnyThe forces that this object is rendered to. Passing nil or an empty table will render it to all forces.
only_in_alt_mode: boolIf this should only be rendered in alt mode. Defaults to false.
players: Vec<LuaAny>The players that this object is rendered to. Passing nil or an empty table will render it to all players.
radius: f64In tiles.
render_mode: ScriptRenderModeMode which this object should render in. Defaults to “game”.
surface: LuaAnytarget: LuaAnytime_to_live: u32In ticks. Defaults to living forever.
visible: boolIf this is rendered to anyone at all. Defaults to true.
width: f32Width of the outline, used only if filled = false. Value is in pixels (32 per tile). Defaults to 1.