LuaRenderingDrawLightParams

Struct LuaRenderingDrawLightParams 

pub struct LuaRenderingDrawLightParams {
Show 16 fields pub blink_interval: u16, pub color: Color, pub forces: ForceSet, pub intensity: f32, pub minimum_darkness: f32, pub only_in_alt_mode: bool, pub orientation: RealOrientation, pub oriented: bool, pub players: Vec<PlayerIdentification>, pub render_mode: ScriptRenderMode, pub scale: f32, pub sprite: SpritePath, pub surface: SurfaceIdentification, pub target: ScriptRenderTarget, pub time_to_live: u32, pub visible: bool,
}
Create a gradient light which is not occluded by any sprites. It is rendered at lower resolution, so it takes less GPU power. The same technique is used for lights drawn by LightDefinition.

The base game uses the utility sprites light_medium and light_small for lights.

Fields

blink_interval: u16

In ticks. Defaults to 0 (no blinking). Game alerts use 30.

color: Color

Defaults to white (no tint).

forces: ForceSet

The forces that this object is rendered to. Passing nil or an empty table will render it to all forces.

intensity: f32

Default is 1.

minimum_darkness: f32

The minimum darkness at which this light is rendered. Default is 0.

only_in_alt_mode: bool

If this should only be rendered in alt mode. Defaults to false.

orientation: RealOrientation

The orientation of the light. Default is 0.

oriented: bool

If this light has the same orientation as the entity target, default is false. Note that orientation is still applied to the sprite.

players: Vec<PlayerIdentification>

The players that this object is rendered to. Passing nil or an empty table will render it to all players.

render_mode: ScriptRenderMode

Mode which this object should render in. Defaults to “game”.

scale: f32

Default is 1.

sprite: SpritePathsurface: SurfaceIdentificationtarget: ScriptRenderTarget

Center of the light.

time_to_live: u32

In ticks. Defaults to living forever.

visible: bool

If this is rendered to anyone at all. Defaults to true.