pub struct LuaRenderingDrawLineParams {Show 16 fields
pub blink_interval: Option<u16>,
pub color: Color,
pub dash_length: Option<f64>,
pub dash_offset: Option<f64>,
pub draw_on_ground: Option<bool>,
pub forces: Option<ForceSet>,
pub from: ScriptRenderTarget,
pub gap_length: Option<f64>,
pub only_in_alt_mode: Option<bool>,
pub players: Option<Vec<PlayerIdentification>>,
pub render_mode: Option<ScriptRenderMode>,
pub surface: SurfaceIdentification,
pub time_to_live: Option<u32>,
pub to: ScriptRenderTarget,
pub visible: Option<bool>,
pub width: f32,
}Expand description
Create a line.
Fields
blink_interval: Option<u16>In ticks. Defaults to 0 (no blinking). Game alerts use 30.
color: Colordash_length: Option<f64>Length of the dashes that this line has. Used only if gap_length > 0. Default is 0.
dash_offset: Option<f64>Starting offset to apply to dashes. Cannot be greater than dash_length + gap_length. Default is 0.
draw_on_ground: Option<bool>If this should be drawn below sprites and entities. Defaults to false.
forces: Option<ForceSet>The forces that this object is rendered to. Passing nil or an empty table will render it to all forces.
from: ScriptRenderTargetgap_length: Option<f64>Length of the gaps that this line has, in tiles. Default is 0.
only_in_alt_mode: Option<bool>If this should only be rendered in alt mode. Defaults to false.
players: Option<Vec<PlayerIdentification>>The players that this object is rendered to. Passing nil or an empty table will render it to all players.
render_mode: Option<ScriptRenderMode>Mode which this object should render in. Defaults to “game”.
surface: SurfaceIdentificationtime_to_live: Option<u32>In ticks. Defaults to living forever.
to: ScriptRenderTargetvisible: Option<bool>If this is rendered to anyone at all. Defaults to true.
width: f32In pixels (32 per tile).