pub struct LuaRenderingDrawPolygonParams {Show 15 fields
pub blink_interval: Option<u16>,
pub color: Color,
pub draw_on_ground: Option<bool>,
pub forces: Option<ForceSet>,
pub only_in_alt_mode: Option<bool>,
pub orientation: Option<RealOrientation>,
pub orientation_target: Option<ScriptRenderTarget>,
pub players: Option<Vec<PlayerIdentification>>,
pub render_mode: Option<ScriptRenderMode>,
pub surface: SurfaceIdentification,
pub target: Option<ScriptRenderTarget>,
pub time_to_live: Option<u32>,
pub use_target_orientation: Option<bool>,
pub vertices: Vec<ScriptRenderTarget>,
pub visible: Option<bool>,
}Expand description
Create a triangle mesh defined by a triangle strip.
Fields
blink_interval: Option<u16>In ticks. Defaults to 0 (no blinking). Game alerts use 30.
color: Colordraw_on_ground: Option<bool>If this should be drawn below sprites and entities. Defaults to false.
forces: Option<ForceSet>The forces that this object is rendered to. Passing nil or an empty table will render it to all forces.
only_in_alt_mode: Option<bool>If this should only be rendered in alt mode. Defaults to false.
orientation: Option<RealOrientation>The orientation applied to all vertices. Default is 0.
orientation_target: Option<ScriptRenderTarget>If given, the vertices (that are not set to an entity) rotate so that it faces this target. Note that orientation is still applied.
players: Option<Vec<PlayerIdentification>>The players that this object is rendered to. Passing nil or an empty table will render it to all players.
render_mode: Option<ScriptRenderMode>Mode which this object should render in. Defaults to “game”.
surface: SurfaceIdentificationtarget: Option<ScriptRenderTarget>Acts like an offset applied to all vertices that are not set to an entity.
time_to_live: Option<u32>In ticks. Defaults to living forever.
use_target_orientation: Option<bool>Only used if orientation_target is a LuaEntity.
vertices: Vec<ScriptRenderTarget>visible: Option<bool>If this is rendered to anyone at all. Defaults to true.