pub struct LuaRenderingDrawSpriteParams {Show 19 fields
pub blink_interval: Option<u16>,
pub forces: Option<ForceSet>,
pub light_mode: Option<ScriptSpriteLightMode>,
pub only_in_alt_mode: Option<bool>,
pub orientation: Option<RealOrientation>,
pub orientation_target: Option<ScriptRenderTarget>,
pub oriented_offset: Option<Vector>,
pub players: Option<Vec<PlayerIdentification>>,
pub render_layer: Option<LuaAny>,
pub render_mode: Option<ScriptRenderMode>,
pub sprite: SpritePath,
pub surface: SurfaceIdentification,
pub target: ScriptRenderTarget,
pub time_to_live: Option<u32>,
pub tint: Option<Color>,
pub use_target_orientation: Option<bool>,
pub visible: Option<bool>,
pub x_scale: Option<f64>,
pub y_scale: Option<f64>,
}Expand description
Create a sprite.
Fields
blink_interval: Option<u16>In ticks. Defaults to 0 (no blinking). Game alerts use 30.
forces: Option<ForceSet>The forces that this object is rendered to. Passing nil or an empty table will render it to all forces.
light_mode: Option<ScriptSpriteLightMode>Whether this object should be rendered as a sprite, light or both at once. Defaults to “occluder”.
only_in_alt_mode: Option<bool>If this should only be rendered in alt mode. Defaults to false.
orientation: Option<RealOrientation>The orientation of the sprite. Default is 0.
orientation_target: Option<ScriptRenderTarget>If given, the sprite rotates so that it faces this target. Note that orientation is still applied to the sprite.
oriented_offset: Option<Vector>Offsets the center of the sprite if orientation_target is given. This offset will rotate together with the sprite.
players: Option<Vec<PlayerIdentification>>The players that this object is rendered to. Passing nil or an empty table will render it to all players.
render_layer: Option<LuaAny>Render layer of the sprite. Defaults to "arrow".
render_mode: Option<ScriptRenderMode>Mode which this object should render in. Defaults to “game”.
sprite: SpritePathsurface: SurfaceIdentificationtarget: ScriptRenderTargetCenter of the sprite.
time_to_live: Option<u32>In ticks. Defaults to living forever.
tint: Option<Color>use_target_orientation: Option<bool>Only used if orientation_target is a LuaEntity.
visible: Option<bool>If this is rendered to anyone at all. Defaults to true.
x_scale: Option<f64>Horizontal scale of the sprite. Default is 1.
y_scale: Option<f64>Vertical scale of the sprite. Default is 1.