pub struct LuaSegmentedUnitCloneParams {
pub force: ForceID,
pub position: MapPosition,
pub surface: LuaSurface,
pub territory: LuaTerritory,
}Expand description
Clones this unit.
Fields
force: ForceIDThe new unit’s force.
position: MapPositionThe destination position of the head segment. The rest of the body nodes will be copied relative to this.
surface: LuaSurfaceThe destination surface. If different from this unit’s surface, then the clone will not copy the original unit’s territory.
territory: LuaTerritoryThe territory that the clone should guard. Must be on the same surface as the destination surface.