pub struct LuaSelectorCombinatorControlBehavior;Expand description
Control behavior for selector combinators.
Implementations
Sourceimpl LuaSelectorCombinatorControlBehavior
impl LuaSelectorCombinatorControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn signals_last_tick(&self) -> Vec<Signal>
pub fn signals_last_tick(&self) -> Vec<Signal>
The circuit network signals sent by this combinator last tick.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn parameters(&self) -> SelectorCombinatorParameters
pub fn parameters(&self) -> SelectorCombinatorParameters
The selector combinator parameters. parameters may be nil in order to clear the parameters.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>
Sourcepub fn get_signal_last_tick(&self, signal: SignalID) -> Option<i32>
pub fn get_signal_last_tick(&self, signal: SignalID) -> Option<i32>
Gets the value of a specific signal sent by this combinator behavior last tick or nil if the signal didn’t exist.