LuaSettings

Struct LuaSettings 

pub struct LuaSettings;
Object containing the three different types of mod settings: startup settings, global runtime settings and per-player runtime settings. An instance of LuaSettings is available through the global object named settings.

Implementations

Source

impl LuaSettings

pub fn global(&self) -> HashMap<String, ModSetting>

The current global mod settings, indexed by prototype name.

Even though this attribute is marked as read-only, individual settings can be changed by overwriting their ModSetting table. Mods can only change their own settings. Using the in-game console, all player settings can be changed.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn player_default(&self) -> HashMap<String, ModSetting>

The default player mod settings for this map, indexed by prototype name. Changing these settings only affects the default settings for future players joining the game.

Individual settings can be changed by overwriting their ModSetting table. Mods can only change their own settings. Using the in-game console, all player settings can be changed.

pub fn startup(&self) -> HashMap<String, ModSetting>

The startup mod settings, indexed by prototype name.

pub fn get_player_settings(&self, player: LuaAny) -> HashMap<String, ModSetting>

Gets the current per-player settings for the given player, indexed by prototype name. Returns the same structure as LuaPlayer::mod_settings. This table becomes invalid if its associated player does.

Even though this attribute is a getter, individual settings can be changed by overwriting their ModSetting table. Mods can only change their own settings. Using the in-game console, all player settings can be changed.