pub struct LuaSimulationControlPressParams {
pub control: String,
pub notify: bool,
}Expand description
Send a control down and up event at the current cursor position. This is equivalent to calling LuaSimulation::control_down, then LuaSimulation::control_up.
Fields
control: StringThe name of the control input to press and release.
notify: boolWhether to show flying text of the activated control.