pub struct LuaSingleFluidBoxControlBehavior;Expand description
Control behavior for entities with a single fluid box (i.e. pipe, pipe-to-ground, storage-tank).
Implementations
Sourceimpl LuaSingleFluidBoxControlBehavior
impl LuaSingleFluidBoxControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn set_input_networks(&self, value: CircuitNetworkSelection)
pub fn set_input_networks(&self, value: CircuitNetworkSelection)
Set the input_networks attribute (Lua: self.input_networks = value).
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn set_output_networks(&self, value: CircuitNetworkSelection)
pub fn set_output_networks(&self, value: CircuitNetworkSelection)
Set the output_networks attribute (Lua: self.output_networks = value).
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
pub fn circuit_exclusive_mode_of_operation(&self) -> &'static str
Sourcepub fn set_circuit_exclusive_mode_of_operation(&self, value: &'static str)
pub fn set_circuit_exclusive_mode_of_operation(&self, value: &'static str)
Set the circuit_exclusive_mode_of_operation attribute (Lua: self.circuit_exclusive_mode_of_operation = value).
Sourcepub fn object_name(&self) -> &'static str
pub fn object_name(&self) -> &'static str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn read_temperature(&self) -> bool
pub fn read_temperature(&self) -> bool
If this will read the temperature of the fluid.
Sourcepub fn set_read_temperature(&self, value: bool)
pub fn set_read_temperature(&self, value: bool)
Set the read_temperature attribute (Lua: self.read_temperature = value).
If this will read the temperature of the fluid.
pub fn temperature_signal(&self) -> SignalID
Sourcepub fn set_temperature_signal(&self, value: SignalID)
pub fn set_temperature_signal(&self, value: SignalID)
Set the temperature_signal attribute (Lua: self.temperature_signal = value).
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &'static str, ) -> Option<LuaCircuitNetwork>