pub struct LuaSpaceLocationPrototype;Expand description
Prototype of a space location, such as a planet.
Implementations
Sourceimpl LuaSpaceLocationPrototype
impl LuaSpaceLocationPrototype
Sourcepub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
Extra description items in the tooltip and Factoriopedia.
Sourcepub fn factoriopedia_description(&self) -> &str
pub fn factoriopedia_description(&self) -> &str
Provides additional description used in factoriopedia.
pub fn localised_description(&self) -> &str
pub fn localised_name(&self) -> &str
Sourcepub fn order(&self) -> &str
pub fn order(&self) -> &str
The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.
pub fn parameter(&self) -> bool
pub fn asteroid_spawn_definitions( &self, ) -> Vec<SpaceLocationAsteroidSpawnDefinition>
pub fn asteroid_spawn_influence(&self) -> f64
pub fn distance(&self) -> f64
pub fn draw_orbit(&self) -> bool
pub fn entities_require_heating(&self) -> bool
Sourcepub fn factoriopedia_alternative(&self) -> LuaSpaceLocationPrototype
pub fn factoriopedia_alternative(&self) -> LuaSpaceLocationPrototype
An alternative prototype that will be used to display info about this prototype in Factoriopedia.
pub fn fly_condition(&self) -> bool
pub fn gravity_pull(&self) -> f64
pub fn label_orientation(&self) -> LuaAny
pub fn magnitude(&self) -> f64
pub fn map_gen_settings(&self) -> MapGenSettings
pub fn map_seed_offset(&self) -> u32
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
pub fn orientation(&self) -> LuaAny
pub fn parked_platforms_orientation(&self) -> LuaAny
pub fn parked_platforms_position(&self) -> MapPosition
pub fn player_effects(&self) -> Vec<TriggerItem>
pub fn pollutant_type(&self) -> LuaAirbornePollutantPrototype
pub fn position(&self) -> MapPosition
pub fn solar_power_in_space(&self) -> f64
pub fn starmap_icon_orientation(&self) -> LuaAny
Sourcepub fn surface_properties(&self) -> HashMap<String, f64>
pub fn surface_properties(&self) -> HashMap<String, f64>
A mapping of the surface property name to the value.
pub fn ticks_between_player_effects(&self) -> u32
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.