pub struct LuaSpacePlatformDamageTileParams {
pub cause: LuaEntity,
pub damage: f32,
pub position: TilePosition,
}Expand description
Damages the given tile if it exists, the chunk is generated, and it is a platform foundation tile.
Fields
cause: LuaEntitydamage: f32position: TilePositionTrait Implementations
Sourceimpl Clone for LuaSpacePlatformDamageTileParams
impl Clone for LuaSpacePlatformDamageTileParams
Sourcefn clone(&self) -> LuaSpacePlatformDamageTileParams
fn clone(&self) -> LuaSpacePlatformDamageTileParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for LuaSpacePlatformDamageTileParams
impl Default for LuaSpacePlatformDamageTileParams
Sourcefn default() -> LuaSpacePlatformDamageTileParams
fn default() -> LuaSpacePlatformDamageTileParams
Returns the “default value” for a type. Read more