pub struct LuaSpacePlatformHubControlBehavior;Expand description
Control behavior for space platform hubs
Implementations
Sourceimpl LuaSpacePlatformHubControlBehavior
impl LuaSpacePlatformHubControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn set_input_networks(&self, value: CircuitNetworkSelection)
pub fn set_input_networks(&self, value: CircuitNetworkSelection)
Set the input_networks attribute (Lua: self.input_networks = value).
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn set_output_networks(&self, value: CircuitNetworkSelection)
pub fn set_output_networks(&self, value: CircuitNetworkSelection)
Set the output_networks attribute (Lua: self.output_networks = value).
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn damage_taken_signal(&self) -> SignalID
pub fn damage_taken_signal(&self) -> SignalID
Signal to be transmitted with platform’s damage taken value.
Sourcepub fn set_damage_taken_signal(&self, value: SignalID)
pub fn set_damage_taken_signal(&self, value: SignalID)
Set the damage_taken_signal attribute (Lua: self.damage_taken_signal = value).
Signal to be transmitted with platform’s damage taken value.
Sourcepub fn object_name(&self) -> &'static str
pub fn object_name(&self) -> &'static str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn read_contents(&self) -> bool
pub fn read_contents(&self) -> bool
true if this hub is sending its content to a circuit network
Sourcepub fn set_read_contents(&self, value: bool)
pub fn set_read_contents(&self, value: bool)
Set the read_contents attribute (Lua: self.read_contents = value).
true if this hub is sending its content to a circuit network
Sourcepub fn read_damage_taken(&self) -> bool
pub fn read_damage_taken(&self) -> bool
Whether damage taken by the space platform is sent to circuit network.
Sourcepub fn set_read_damage_taken(&self, value: bool)
pub fn set_read_damage_taken(&self, value: bool)
Set the read_damage_taken attribute (Lua: self.read_damage_taken = value).
Whether damage taken by the space platform is sent to circuit network.
Sourcepub fn read_moving_from(&self) -> bool
pub fn read_moving_from(&self) -> bool
Whether current connection “from” end is sent to circuit network.
Sourcepub fn set_read_moving_from(&self, value: bool)
pub fn set_read_moving_from(&self, value: bool)
Set the read_moving_from attribute (Lua: self.read_moving_from = value).
Whether current connection “from” end is sent to circuit network.
Sourcepub fn read_moving_to(&self) -> bool
pub fn read_moving_to(&self) -> bool
Whether current connection “to” end is sent to circuit network.
Sourcepub fn set_read_moving_to(&self, value: bool)
pub fn set_read_moving_to(&self, value: bool)
Set the read_moving_to attribute (Lua: self.read_moving_to = value).
Whether current connection “to” end is sent to circuit network.
Sourcepub fn read_speed(&self) -> bool
pub fn read_speed(&self) -> bool
Whether current speed of space platform is sent to circuit network.
Sourcepub fn set_read_speed(&self, value: bool)
pub fn set_read_speed(&self, value: bool)
Set the read_speed attribute (Lua: self.read_speed = value).
Whether current speed of space platform is sent to circuit network.
Sourcepub fn send_to_platform(&self) -> bool
pub fn send_to_platform(&self) -> bool
Whether the signals are used for circuit conditions in the platform’s schedule
Sourcepub fn set_send_to_platform(&self, value: bool)
pub fn set_send_to_platform(&self, value: bool)
Set the send_to_platform attribute (Lua: self.send_to_platform = value).
Whether the signals are used for circuit conditions in the platform’s schedule
pub fn set_requests(&self) -> bool
Sourcepub fn set_set_requests(&self, value: bool)
pub fn set_set_requests(&self, value: bool)
Set the set_requests attribute (Lua: self.set_requests = value).
Sourcepub fn speed_signal(&self) -> SignalID
pub fn speed_signal(&self) -> SignalID
Signal to be transmitted with platform’s current speed.
Sourcepub fn set_speed_signal(&self, value: SignalID)
pub fn set_speed_signal(&self, value: SignalID)
Set the speed_signal attribute (Lua: self.speed_signal = value).
Signal to be transmitted with platform’s current speed.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &'static str, ) -> Option<LuaCircuitNetwork>