pub struct LuaSplitterControlBehavior;Expand description
Control behavior for splitter.
Implementations
Sourceimpl LuaSplitterControlBehavior
impl LuaSplitterControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn set_input_networks(&self, value: CircuitNetworkSelection)
pub fn set_input_networks(&self, value: CircuitNetworkSelection)
Set the input_networks attribute (Lua: self.input_networks = value).
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn set_output_networks(&self, value: CircuitNetworkSelection)
pub fn set_output_networks(&self, value: CircuitNetworkSelection)
Set the output_networks attribute (Lua: self.output_networks = value).
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
pub fn input_left_condition(&self) -> CircuitConditionDefinition
Sourcepub fn set_input_left_condition(&self, value: CircuitConditionDefinition)
pub fn set_input_left_condition(&self, value: CircuitConditionDefinition)
Set the input_left_condition attribute (Lua: self.input_left_condition = value).
pub fn input_right_condition(&self) -> CircuitConditionDefinition
Sourcepub fn set_input_right_condition(&self, value: CircuitConditionDefinition)
pub fn set_input_right_condition(&self, value: CircuitConditionDefinition)
Set the input_right_condition attribute (Lua: self.input_right_condition = value).
Sourcepub fn object_name(&self) -> &'static str
pub fn object_name(&self) -> &'static str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
pub fn output_left_condition(&self) -> CircuitConditionDefinition
Sourcepub fn set_output_left_condition(&self, value: CircuitConditionDefinition)
pub fn set_output_left_condition(&self, value: CircuitConditionDefinition)
Set the output_left_condition attribute (Lua: self.output_left_condition = value).
pub fn output_right_condition(&self) -> CircuitConditionDefinition
Sourcepub fn set_output_right_condition(&self, value: CircuitConditionDefinition)
pub fn set_output_right_condition(&self, value: CircuitConditionDefinition)
Set the output_right_condition attribute (Lua: self.output_right_condition = value).
pub fn set_filter(&self) -> bool
Sourcepub fn set_set_filter(&self, value: bool)
pub fn set_set_filter(&self, value: bool)
Set the set_filter attribute (Lua: self.set_filter = value).
pub fn set_input_side(&self) -> bool
Sourcepub fn set_set_input_side(&self, value: bool)
pub fn set_set_input_side(&self, value: bool)
Set the set_input_side attribute (Lua: self.set_input_side = value).
pub fn set_output_side(&self) -> bool
Sourcepub fn set_set_output_side(&self, value: bool)
pub fn set_set_output_side(&self, value: bool)
Set the set_output_side attribute (Lua: self.set_output_side = value).
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &'static str, ) -> Option<LuaCircuitNetwork>