pub struct LuaSurfaceCanPlaceEntityParams {
pub build_check_type: String,
pub direction: String,
pub force: LuaAny,
pub forced: bool,
pub inner_name: String,
pub name: LuaAny,
pub position: MapPosition,
}Expand description
Check for collisions with terrain or other entities.
Fields
build_check_type: StringWhich type of check should be carried out. Defaults to ghost_revive.
direction: StringDirection of the placed entity. Defaults to north.
force: LuaAnyThe force that would place the entity. Defaults to the "neutral" force.
forced: boolIf true, entities that can be marked for deconstruction are ignored. Only used if build_check_type is either manual_ghost, script_ghost or blueprint_ghost. Defaults to false.
inner_name: StringThe prototype name of the entity contained in the ghost. Only used if name is entity-ghost.
name: LuaAnyName of the entity prototype to check.
position: MapPositionWhere the entity would be placed.