pub struct LuaSurfaceCancelDeconstructAreaParams {
pub area: BoundingBox,
pub force: LuaAny,
pub item: LuaItemStack,
pub player: LuaAny,
pub skip_fog_of_war: bool,
pub super_forced: bool,
pub undo_index: u32,
}Expand description
Cancel a deconstruction order.
Fields
area: BoundingBoxThe area to cancel deconstruction orders in.
force: LuaAnyThe force whose deconstruction orders to cancel.
item: LuaItemStackThe deconstruction item to use if any.
player: LuaAnyThe player to set the last_user to, if any. Also the player whose undo queue this action should be added to.
skip_fog_of_war: boolIf chunks covered by fog-of-war are skipped. Defaults to false.
super_forced: boolIf the cancel deconstruction is super-forced. Defaults to false.
undo_index: u32The index of the undo item to add this action to. An index of 0 creates a new undo item for it. Defaults to putting it into the appropriate undo item automatically if not specified.