LuaSurfaceCloneAreaParams

Struct LuaSurfaceCloneAreaParams 

pub struct LuaSurfaceCloneAreaParams {
    pub clear_destination_decoratives: bool,
    pub clear_destination_entities: bool,
    pub clone_decoratives: bool,
    pub clone_entities: bool,
    pub clone_tiles: bool,
    pub create_build_effect_smoke: bool,
    pub destination_area: BoundingBox,
    pub destination_force: LuaAny,
    pub destination_surface: LuaAny,
    pub expand_map: bool,
    pub source_area: BoundingBox,
}
Clones the given area.

Entities are cloned in an order such that they can always be created, eg rails before trains.

Fields

clear_destination_decoratives: bool

If the destination decoratives should be cleared

clear_destination_entities: bool

If the destination entities should be cleared

clone_decoratives: bool

If decoratives should be cloned

clone_entities: bool

If entities should be cloned

clone_tiles: bool

If tiles should be cloned

create_build_effect_smoke: bool

If true, the building effect smoke will be shown around the new entities. Defaults to false.

destination_area: BoundingBoxdestination_force: LuaAnydestination_surface: LuaAnyexpand_map: bool

If the destination surface should be expanded when destination_area is outside current bounds. Defaults to false.

source_area: BoundingBox