pub struct LuaSurfaceCloneEntitiesParams {
pub create_build_effect_smoke: bool,
pub destination_force: LuaAny,
pub destination_offset: Vector,
pub destination_surface: LuaAny,
pub entities: Vec<LuaEntity>,
pub snap_to_grid: bool,
}Expand description
Clones the given entities.
Entities are cloned in an order such that they can always be created, eg rails before trains.
Fields
create_build_effect_smoke: boolIf true, the building effect smoke will be shown around the new entities.
destination_force: LuaAnydestination_offset: Vectordestination_surface: LuaAnyentities: Vec<LuaEntity>snap_to_grid: boolTrait Implementations
Sourceimpl Clone for LuaSurfaceCloneEntitiesParams
impl Clone for LuaSurfaceCloneEntitiesParams
Sourcefn clone(&self) -> LuaSurfaceCloneEntitiesParams
fn clone(&self) -> LuaSurfaceCloneEntitiesParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for LuaSurfaceCloneEntitiesParams
impl Default for LuaSurfaceCloneEntitiesParams
Sourcefn default() -> LuaSurfaceCloneEntitiesParams
fn default() -> LuaSurfaceCloneEntitiesParams
Returns the “default value” for a type. Read more