pub struct LuaSurfaceCreateTerritoryParams {
pub chunks: Vec<ChunkPosition>,
pub patrol_path: Vec<MapPosition>,
}Expand description
Create a territory on the surface.
Fields
chunks: Vec<ChunkPosition>The chunks to assign to the new territory. Must contain at least one generated chunk. Any chunks already assigned to existing territories will be removed from those territories. Any territories left with no generated chunks will be deleted from the surface as a result.
patrol_path: Vec<MapPosition>The path that patrolling units will follow. If nil or empty, one will be generated for the new territory based on chunks.