pub struct LuaSurfacePropertyPrototype;Expand description
Prototype of a surface property.
Implementations
Sourceimpl LuaSurfacePropertyPrototype
impl LuaSurfacePropertyPrototype
Sourcepub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
Extra description items in the tooltip and Factoriopedia.
Sourcepub fn factoriopedia_description(&self) -> &'static str
pub fn factoriopedia_description(&self) -> &'static str
Provides additional description used in factoriopedia.
pub fn localised_description(&self) -> &'static str
pub fn localised_name(&self) -> &'static str
Sourcepub fn order(&self) -> &'static str
pub fn order(&self) -> &'static str
The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.
pub fn parameter(&self) -> bool
pub fn default_value(&self) -> f64
pub fn is_time(&self) -> bool
pub fn localised_unit_key(&self) -> &'static str
Sourcepub fn object_name(&self) -> &'static str
pub fn object_name(&self) -> &'static str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.