LuaSurfaceSetMultiCommandParams

Struct LuaSurfaceSetMultiCommandParams 

pub struct LuaSurfaceSetMultiCommandParams {
    pub command: Command,
    pub force: LuaAny,
    pub unit_count: u32,
    pub unit_search_distance: u32,
}
Give a command to multiple units. This will automatically select suitable units for the task.

Fields

command: Commandforce: LuaAny

Force of the units this command is to be given to. If not specified, uses the enemy force.

unit_count: u32

Number of units to give the command to.

unit_search_distance: u32

Radius to search for units. The search area is centered on the destination of the command. If not specified uses default value of 150.