LuaSurfaceSpillInventoryParams

Struct LuaSurfaceSpillInventoryParams 

pub struct LuaSurfaceSpillInventoryParams {
    pub allow_belts: bool,
    pub drop_full_stack: bool,
    pub enable_looted: bool,
    pub force: LuaAny,
    pub inventory: LuaInventory,
    pub max_radius: f64,
    pub position: MapPosition,
    pub use_start_position_on_failure: bool,
}
Spill inventory on the ground centered at a given location.

Fields

allow_belts: bool

Whether items can be spilled onto belts. Defaults to true.

drop_full_stack: bool

If item on ground should be made out of an entire provided stack. Defaults to false.

enable_looted: bool

When true, each created item will be flagged with the LuaEntity::to_be_looted flag. Defaults to false.

force: LuaAny

When provided (and not nil) the items will be marked for deconstruction by this force.

inventory: LuaInventory

Inventory to spill

max_radius: f64

Max radius from the specified position to spill items.

position: MapPosition

Center of the spillage

use_start_position_on_failure: bool

Allow spilling items at position if no non-colliding position is found. Note: Setting to false might cause some items not to be spilled. Defaults to true.