pub struct LuaSurfaceSpillItemStackParams {
pub allow_belts: bool,
pub drop_full_stack: bool,
pub enable_looted: bool,
pub force: ForceID,
pub max_radius: f64,
pub position: MapPosition,
pub stack: ItemStackIdentification,
pub use_start_position_on_failure: bool,
}Expand description
Spill items on the ground centered at a given location.
Fields
allow_belts: boolWhether items can be spilled onto belts. Defaults to true.
drop_full_stack: boolIf item on ground should be made out of an entire provided stack. Defaults to false.
enable_looted: boolWhen true, each created item will be flagged with the LuaEntity::to_be_looted flag. Defaults to false.
force: ForceIDWhen provided (and not nil) the items will be marked for deconstruction by this force.
max_radius: f64Max radius from the specified position to spill items.
position: MapPositionCenter of the spillage
stack: ItemStackIdentificationStack of items to spill
use_start_position_on_failure: boolAllow spilling items at position if no non-colliding position is found. Note: Setting to false might cause some items not to be spilled. Defaults to true.