LuaTechnology

Struct LuaTechnology 

pub struct LuaTechnology;
One research item.

Implementations

Source

impl LuaTechnology

pub fn enabled(&self) -> bool

Can this technology be researched?

pub fn force(&self) -> LuaForce

The force this technology belongs to.

pub fn level(&self) -> u32

The current level of this technology. For level-based technology writing to this is the same as researching the technology to the previous level. Writing the level will set LuaTechnology::enabled to true.

pub fn localised_description(&self) -> &str

pub fn localised_name(&self) -> &str

Localised name of this technology.

pub fn name(&self) -> &str

Name of this technology.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn order(&self) -> &str

The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.

pub fn prerequisites(&self) -> HashMap<String, Box<LuaTechnology>>

Prerequisites of this technology. The result maps technology name to the LuaTechnology object.

pub fn prototype(&self) -> LuaTechnologyPrototype

The prototype of this technology.

pub fn research_unit_count(&self) -> u32

The number of research units required for this technology.

This is multiplied by the current research cost multiplier, unless LuaTechnologyPrototype::ignore_tech_cost_multiplier is true.

pub fn research_unit_count_formula(&self) -> MathExpression

The count formula, if this research has any. See TechnologyUnit::count_formula for details.

pub fn research_unit_energy(&self) -> f64

Amount of energy required to finish a unit of research.

pub fn research_unit_ingredients(&self) -> Vec<ResearchIngredient>

The types of ingredients that labs will require to research this technology.

pub fn researched(&self) -> bool

Has this technology been researched? Switching from false to true will trigger the technology advancement perks; switching from true to false will reverse them.

pub fn saved_progress(&self) -> f64

Saved technology progress fraction as a value in range [0, 1). 0 means there is no saved progress.

pub fn successors(&self) -> HashMap<String, Box<LuaTechnology>>

Successors of this technology, i.e. technologies which have this technology as a prerequisite.

pub fn upgrade(&self) -> bool

Is this an upgrade-type research?

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn visible_when_disabled(&self) -> bool

If this technology will be visible in the research GUI even though it is disabled.

pub fn reload(&self)

Reload this technology from its prototype.

pub fn research_recursive(&self)

Research this technology and all of its prerequisites recursively.