pub struct LuaTechnologyPrototype;Expand description
A Technology prototype.
Implementations
Sourceimpl LuaTechnologyPrototype
impl LuaTechnologyPrototype
Sourcepub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
Extra description items in the tooltip and Factoriopedia.
Sourcepub fn factoriopedia_description(&self) -> &str
pub fn factoriopedia_description(&self) -> &str
Provides additional description used in factoriopedia.
pub fn localised_description(&self) -> &str
pub fn localised_name(&self) -> &str
Sourcepub fn order(&self) -> &str
pub fn order(&self) -> &str
The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.
pub fn parameter(&self) -> bool
pub fn allows_productivity(&self) -> bool
Sourcepub fn effects(&self) -> Vec<TechnologyModifier>
pub fn effects(&self) -> Vec<TechnologyModifier>
Effects applied when this technology is researched.
Sourcepub fn enabled(&self) -> bool
pub fn enabled(&self) -> bool
If this technology prototype is enabled by default (enabled at the beginning of a game).
Sourcepub fn essential(&self) -> bool
pub fn essential(&self) -> bool
If this technology prototype is essential, meaning it is shown in the condensed technology graph.
Sourcepub fn factoriopedia_alternative(&self) -> LuaTechnologyPrototype
pub fn factoriopedia_alternative(&self) -> LuaTechnologyPrototype
An alternative prototype that will be used to display info about this prototype in Factoriopedia.
Sourcepub fn ignore_tech_cost_multiplier(&self) -> bool
pub fn ignore_tech_cost_multiplier(&self) -> bool
If this technology ignores the technology cost multiplier setting.
LuaTechnologyPrototype::research_unit_count will already take this setting into account.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn prerequisites(&self) -> HashMap<String, Box<LuaTechnologyPrototype>>
pub fn prerequisites(&self) -> HashMap<String, Box<LuaTechnologyPrototype>>
Prerequisites of this technology. The result maps technology name to the LuaTechnologyPrototype object.
Sourcepub fn research_trigger(&self) -> ResearchTrigger
pub fn research_trigger(&self) -> ResearchTrigger
The trigger that will research this technology if any.
Sourcepub fn research_unit_count(&self) -> u32
pub fn research_unit_count(&self) -> u32
The number of research units required for this technology.
This is multiplied by the current research cost multiplier, unless LuaTechnologyPrototype::ignore_tech_cost_multiplier is true.
Sourcepub fn research_unit_count_formula(&self) -> MathExpression
pub fn research_unit_count_formula(&self) -> MathExpression
The count formula, if this research has any. See TechnologyUnit::count_formula for details.
Sourcepub fn research_unit_energy(&self) -> f64
pub fn research_unit_energy(&self) -> f64
Amount of energy required to finish a unit of research.
Sourcepub fn research_unit_ingredients(&self) -> Vec<ResearchIngredient>
pub fn research_unit_ingredients(&self) -> Vec<ResearchIngredient>
The types of ingredients that labs will require to research this technology.
Sourcepub fn successors(&self) -> HashMap<String, Box<LuaTechnologyPrototype>>
pub fn successors(&self) -> HashMap<String, Box<LuaTechnologyPrototype>>
Successors of this technology, i.e. technologies which have this technology as a prerequisite.
Sourcepub fn upgrade(&self) -> bool
pub fn upgrade(&self) -> bool
If the is technology prototype is an upgrade to some other technology.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
Sourcepub fn visible_when_disabled(&self) -> bool
pub fn visible_when_disabled(&self) -> bool
If this technology will be visible in the research GUI even though it is disabled.