LuaTile

Struct LuaTile 

pub struct LuaTile;
A single “square” on the map.

Implementations

Source

impl LuaTile

pub fn double_hidden_tile(&self) -> &str

The name of the LuaTilePrototype double hidden under this tile or nil if there is no double hidden tile.

During normal gameplay, only non-mineable tiles can become double hidden. This can however be circumvented with LuaSurface::set_double_hidden_tile.

pub fn hidden_tile(&self) -> &str

The name of the LuaTilePrototype hidden under this tile, if any.

During normal gameplay, only non-mineable or foundation tiles can become hidden. This can however be circumvented with LuaSurface::set_hidden_tile.

pub fn name(&self) -> &str

Prototype name of this tile. E.g. "sand-3" or "grass-2".

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn position(&self) -> TilePosition

The position this tile references.

pub fn prototype(&self) -> LuaTilePrototype

pub fn surface(&self) -> LuaSurface

The surface this tile is on.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn cancel_deconstruction(&self, force: LuaAny, player: Option<LuaAny>)

Cancels deconstruction if it is scheduled, does nothing otherwise.

pub fn collides_with(&self, layer: CollisionLayerID) -> bool

What type of things can collide with this tile?

pub fn get_tile_ghosts(&self, force: Option<LuaAny>) -> Vec<LuaEntity>

Gets all tile ghosts on this tile.

pub fn has_tile_ghost(&self, force: Option<LuaAny>) -> bool

Does this tile have any tile ghosts on it.

pub fn order_deconstruction( &self, force: LuaAny, player: Option<LuaAny>, ) -> Option<LuaEntity>

Orders deconstruction of this tile by the given force.

pub fn to_be_deconstructed(&self, force: Option<LuaAny>) -> bool

Is this tile marked for deconstruction?