LuaTilePrototype

Struct LuaTilePrototype 

pub struct LuaTilePrototype;
Prototype of a tile.

Implementations

Source

impl LuaTilePrototype

pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>

Extra description items in the tooltip and Factoriopedia.

pub fn factoriopedia_description(&self) -> &str

Provides additional description used in factoriopedia.

pub fn group(&self) -> LuaGroup

Group of this prototype.

pub fn hidden(&self) -> bool

pub fn hidden_in_factoriopedia(&self) -> bool

pub fn localised_description(&self) -> &str

pub fn localised_name(&self) -> &str

pub fn name(&self) -> &str

Name of this prototype.

pub fn order(&self) -> &str

The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.

pub fn parameter(&self) -> bool

pub fn subgroup(&self) -> LuaGroup

Subgroup of this prototype.

pub fn type(&self) -> &str

Type of this prototype.

pub fn absorptions_per_second(&self) -> HashMap<String, f64>

A table of pollution emissions per second this tile will absorb, indexed by the name of each absorbed pollution type.

pub fn allowed_neighbors(&self) -> HashMap<String, Box<LuaTilePrototype>>

pub fn allows_being_covered(&self) -> bool

True if this tile can be hidden or replaced by another tile through player actions.

pub fn ambient_sounds_group(&self) -> LuaTilePrototype

pub fn automatic_neighbors(&self) -> bool

pub fn autoplace_specification(&self) -> AutoplaceSpecification

Autoplace specification for this prototype, if any.

pub fn bound_decoratives(&self) -> Vec<LuaDecorativePrototype>

pub fn can_be_part_of_blueprint(&self) -> bool

False if this tile is not allowed in blueprints regardless of the ability to build it.

pub fn check_collision_with_entities(&self) -> bool

True if building this tile should check for colliding entities above and prevent building if such are found. Also during mining tiles above this tile checks for entities colliding with this tile and prevents mining if such are found.

pub fn collision_mask(&self) -> TileCollisionMask

The collision mask this tile uses

pub fn decorative_removal_probability(&self) -> f32

The probability that decorative entities will be removed from on top of this tile when this tile is generated.

pub fn default_cover_tile(&self) -> LuaTilePrototype

pub fn default_destroyed_dropped_item_trigger(&self) -> Vec<TriggerItem>

pub fn destroys_dropped_items(&self) -> bool

pub fn factoriopedia_alternative(&self) -> LuaTilePrototype

An alternative prototype that will be used to display info about this prototype in Factoriopedia.

pub fn fluid(&self) -> LuaFluidPrototype

The fluid offshore pump produces on this tile, if any.

pub fn frozen_variant(&self) -> LuaTilePrototype

pub fn is_foundation(&self) -> bool

True if this tile can be used as a foundation for other tiles, false otherwise. Foundation tiles can be hidden.

pub fn items_to_place_this(&self) -> Vec<ItemToPlace>

Items that when placed will produce this tile, if any. Construction bots will choose the first item in the list to build this tile.

pub fn layer(&self) -> u32

pub fn map_color(&self) -> Color

pub fn max_health(&self) -> f32

pub fn mineable_properties(&self) -> LuaTilePrototypeMineableProperties

pub fn needs_correction(&self) -> bool

If this tile needs correction logic applied when it’s generated in the world.

pub fn next_direction(&self) -> LuaTilePrototype

The next direction of this tile, if any. Used when a tile has multiple directions (such as hazard concrete)

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn scorch_mark_color(&self) -> Color

pub fn thawed_variant(&self) -> LuaTilePrototype

pub fn trigger_effect(&self) -> Vec<TriggerEffectItem>

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn vehicle_friction_modifier(&self) -> f32

pub fn walking_speed_modifier(&self) -> f32

pub fn weight(&self) -> LuaAny