LuaTrainManager

Struct LuaTrainManager 

pub struct LuaTrainManager;
The train manager manages all the train in the game. LuaTrainManager allows to perform some direct queries to the train manager.

There is always exactly one train manager instance in a game, it can be obtained from LuaGameScript::train_manager. This object is always valid and is equal to any other instance of LuaTrainManager from this game.

Implementations

Source

impl LuaTrainManager

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn get_train_by_id(&self, train_id: u32) -> Option<LuaTrain>

Searches for a train with given ID.

pub fn get_train_stops(&self, filter: TrainStopFilter) -> Vec<LuaEntity>

Gets all train stops that pass given filter

pub fn get_trains(&self, filter: TrainFilter) -> Vec<LuaTrain>

Gets all trains that pass given filter

pub fn request_train_path( &self, params: LuaTrainManagerRequestTrainPathParams, ) -> LuaAny

Direct access to train pathfinder. Allows to search rail paths or querying which stops are accessible