LuaTrivialSmokePrototype

Struct LuaTrivialSmokePrototype 

pub struct LuaTrivialSmokePrototype;
Prototype of a trivial smoke.

Implementations

Source

impl LuaTrivialSmokePrototype

pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>

Extra description items in the tooltip and Factoriopedia.

pub fn factoriopedia_description(&self) -> &str

Provides additional description used in factoriopedia.

pub fn group(&self) -> LuaGroup

Group of this prototype.

pub fn hidden(&self) -> bool

pub fn hidden_in_factoriopedia(&self) -> bool

pub fn localised_description(&self) -> &str

pub fn localised_name(&self) -> &str

pub fn name(&self) -> &str

Name of this prototype.

pub fn order(&self) -> &str

The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.

pub fn parameter(&self) -> bool

pub fn subgroup(&self) -> LuaGroup

Subgroup of this prototype.

pub fn type(&self) -> &str

Type of this prototype.

pub fn affected_by_wind(&self) -> bool

pub fn color(&self) -> Color

pub fn cyclic(&self) -> bool

pub fn duration(&self) -> u32

pub fn end_scale(&self) -> f64

pub fn fade_away_duration(&self) -> u32

pub fn fade_in_duration(&self) -> u32

pub fn glow_animation(&self) -> bool

pub fn glow_fade_away_duration(&self) -> u32

pub fn movement_slow_down_factor(&self) -> f64

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn render_layer(&self) -> LuaAny

pub fn show_when_smoke_off(&self) -> bool

pub fn spread_duration(&self) -> u32

pub fn start_scale(&self) -> f64

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.