LuaUndoRedoStack

Struct LuaUndoRedoStack 

pub struct LuaUndoRedoStack;
The undo queue for a player. The term item_index refers to the index of an undo item in the queue, while action_index refers to the index of one of the individual actions that make up an undo item.

Items are added to the undo queue through player actions and Lua methods that emulate player actions like LuaEntity::order_upgrade.

Implementations

Source

impl LuaUndoRedoStack

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn player_index(&self) -> u32

The index of the player to whom this stack belongs to.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn get_redo_item(&self, index: u32) -> Vec<UndoRedoAction>

Gets an undo item from the redo stack.

pub fn get_redo_item_count(&self) -> u32

The number of undo items in the redo stack.

pub fn get_redo_tag( &self, action_index: u32, item_index: u32, tag_name: &str, ) -> LuaAny

Gets the tag with the given name from a specific redo item action, or nil if it doesn’t exist.

pub fn get_redo_tags(&self, action_index: u32, item_index: u32) -> LuaAny

Gets all tags for the given redo action.

pub fn get_undo_item(&self, index: u32) -> Vec<UndoRedoAction>

Gets an undo item from the undo stack.

pub fn get_undo_item_count(&self) -> u32

The number undo items in the undo stack.

pub fn get_undo_tag( &self, action_index: u32, item_index: u32, tag_name: &str, ) -> LuaAny

Gets the tag with the given name from a specific undo item action, or nil if it doesn’t exist.

pub fn get_undo_tags(&self, action_index: u32, item_index: u32) -> LuaAny

Gets all tags for the given undo action.

pub fn remove_redo_action(&self, action_index: u32, item_index: u32)

Removes an undo action from the specified undo item on the redo stack.

pub fn remove_redo_item(&self, index: u32)

Removes an undo item from the redo stack.

pub fn remove_redo_tag( &self, action_index: u32, item_index: u32, tag: &str, ) -> bool

Removes a tag with the given name from the specified redo item.

pub fn remove_undo_action(&self, action_index: u32, item_index: u32)

Removes an undo action from the specified undo item on the undo stack.

pub fn remove_undo_item(&self, index: u32)

Removes an undo item from the undo stack.

pub fn remove_undo_tag( &self, action_index: u32, item_index: u32, tag: &str, ) -> bool

Removes a tag with the given name from the specified undo item.

pub fn set_redo_tag( &self, action_index: u32, item_index: u32, tag: LuaAny, tag_name: &str, )

Sets a new tag with the given name and value on the specified redo item action.

pub fn set_undo_tag( &self, action_index: u32, item_index: u32, tag: LuaAny, tag_name: &str, )

Sets a new tag with the given name and value on the specified undo item action.