BoundingBox

Struct BoundingBox 

pub struct BoundingBox {
    pub left_top: LuaAny,
    pub orientation: LuaAny,
    pub right_bottom: LuaAny,
}
Two positions, specifying the top-left and bottom-right corner of the box respectively. Like with MapPosition, the names of the members may be omitted. When read from the game, the third member orientation is present if it is non-zero.

Fields

left_top: LuaAnyorientation: LuaAnyright_bottom: LuaAny