EnemyExpansionMapSettings

Struct EnemyExpansionMapSettings 

pub struct EnemyExpansionMapSettings {
Show 14 fields pub building_coefficient: f64, pub enabled: bool, pub enemy_building_influence_radius: u32, pub friendly_base_influence_radius: u32, pub max_colliding_tiles_coefficient: f64, pub max_expansion_cooldown: u32, pub max_expansion_distance: u32, pub min_expansion_cooldown: u32, pub min_expansion_distance: u32, pub neighbouring_base_chunk_coefficient: f64, pub neighbouring_chunk_coefficient: f64, pub other_base_coefficient: f64, pub settler_group_max_size: u32, pub settler_group_min_size: u32,
}
Candidate chunks are given scores to determine which one of them should be expanded into. This score takes into account various settings noted below. The iteration is over a square region centered around the chunk for which the calculation is done, and includes the central chunk as well. Distances are calculated as Euclidean distance.

The pseudocode algorithm to determine a chunk’s score is as follows:


player = 0
for neighbour in all chunks within enemy_building_influence_radius from chunk :
  if neighbour has player buildings :
    player += neighbouring_chunk_coefficient ^ distance(chunk, neighbour)
      * building_coefficient
base = 0
for neighbour in all chunks within friendly_base_influence_radius from chunk :
  if neighbour has enemy bases :
    base += neighbouring_base_chunk_coefficient ^ distance(chunk, neighbour)
      * other_base_coefficient
score(chunk) = 1 / (1 + player + base)
```text

Fields

building_coefficient: f64enabled: boolenemy_building_influence_radius: u32friendly_base_influence_radius: u32max_colliding_tiles_coefficient: f64max_expansion_cooldown: u32max_expansion_distance: u32min_expansion_cooldown: u32min_expansion_distance: u32neighbouring_base_chunk_coefficient: f64neighbouring_chunk_coefficient: f64other_base_coefficient: f64settler_group_max_size: u32settler_group_min_size: u32