pub struct EntityPrototypeFlags {
pub flags: &'static [&'static str],
}Expand description
A set of flags. Active flags are in the dictionary as true, while inactive flags aren’t present at all.
By default, none of these flags are set.
Factorio flag set: active keys present as true in a Lua table.
Construct with flags: &["left", "right"]. Lowers to
{ ["left"] = true, ["right"] = true }.
Fields
flags: &'static [&'static str]Trait Implementations
Sourceimpl Clone for EntityPrototypeFlags
impl Clone for EntityPrototypeFlags
Sourcefn clone(&self) -> EntityPrototypeFlags
fn clone(&self) -> EntityPrototypeFlags
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for EntityPrototypeFlags
Sourceimpl Debug for EntityPrototypeFlags
impl Debug for EntityPrototypeFlags
Sourceimpl Default for EntityPrototypeFlags
impl Default for EntityPrototypeFlags
Sourcefn default() -> EntityPrototypeFlags
fn default() -> EntityPrototypeFlags
Returns the “default value” for a type. Read more
impl Eq for EntityPrototypeFlags
Sourceimpl PartialEq for EntityPrototypeFlags
impl PartialEq for EntityPrototypeFlags
impl StructuralPartialEq for EntityPrototypeFlags