pub struct EventData {
pub mod_name: &'static str,
pub name: &'static str,
pub tick: u32,
}Expand description
Information about the event that has been raised. The table can also contain other fields depending on the type of event. See the list of Factorio events for more information on these.
Fields
mod_name: &'static strname: &'static strtick: u32Trait Implementations
impl Copy for EventData
impl StructuralPartialEq for EventData