pub struct GameViewSettings {Show 18 fields
pub hide_tall_entities: bool,
pub show_alert_gui: bool,
pub show_controller_gui: bool,
pub show_crafting_queue: bool,
pub show_entity_info: bool,
pub show_entity_tooltip: bool,
pub show_hotkey_suggestions: bool,
pub show_map_view_options: bool,
pub show_minimap: bool,
pub show_pins_gui: bool,
pub show_quickbar: bool,
pub show_rail_block_visualisation: bool,
pub show_research_info: bool,
pub show_shortcut_bar: bool,
pub show_side_menu: bool,
pub show_surface_list: bool,
pub show_tool_bar: bool,
pub update_entity_selection: bool,
}Expand description
Parameters that affect the look and control of the game. Updating any of the member attributes here will immediately take effect in the game engine.
Fields
hide_tall_entities: boolshow_alert_gui: boolshow_controller_gui: boolshow_crafting_queue: boolshow_entity_info: boolshow_entity_tooltip: boolshow_hotkey_suggestions: boolshow_map_view_options: boolshow_minimap: boolshow_pins_gui: boolshow_quickbar: boolshow_rail_block_visualisation: boolshow_research_info: boolshow_shortcut_bar: boolshow_surface_list: boolshow_tool_bar: boolupdate_entity_selection: boolTrait Implementations
Sourceimpl Clone for GameViewSettings
impl Clone for GameViewSettings
Sourcefn clone(&self) -> GameViewSettings
fn clone(&self) -> GameViewSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for GameViewSettings
Sourceimpl Debug for GameViewSettings
impl Debug for GameViewSettings
Sourceimpl Default for GameViewSettings
impl Default for GameViewSettings
Sourcefn default() -> GameViewSettings
fn default() -> GameViewSettings
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for GameViewSettings
impl PartialEq for GameViewSettings
impl StructuralPartialEq for GameViewSettings