pub struct ItemPrototypeFlags {
pub flags: &'static [&'static str],
}Expand description
A set of flags. Active flags are in the dictionary as true, while inactive flags aren’t present at all.
By default, none of these flags are set.
Factorio flag set: active keys present as true in a Lua table.
Construct with flags: &["left", "right"]. Lowers to
{ ["left"] = true, ["right"] = true }.
Fields
flags: &'static [&'static str]Trait Implementations
Sourceimpl Clone for ItemPrototypeFlags
impl Clone for ItemPrototypeFlags
Sourcefn clone(&self) -> ItemPrototypeFlags
fn clone(&self) -> ItemPrototypeFlags
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ItemPrototypeFlags
Sourceimpl Debug for ItemPrototypeFlags
impl Debug for ItemPrototypeFlags
Sourceimpl Default for ItemPrototypeFlags
impl Default for ItemPrototypeFlags
Sourcefn default() -> ItemPrototypeFlags
fn default() -> ItemPrototypeFlags
Returns the “default value” for a type. Read more
impl Eq for ItemPrototypeFlags
Sourceimpl PartialEq for ItemPrototypeFlags
impl PartialEq for ItemPrototypeFlags
impl StructuralPartialEq for ItemPrototypeFlags