pub struct PropertyExpressionNamesPair {
pub key: &'static str,
pub value: &'static str,
}Expand description
All other MapGenSettings feed into named noise expressions, and therefore placement can be overridden by including the name of a property in this dictionary. The probability and richness functions for placing specific tiles, entities, and decoratives can be overridden by including an entry named {tile|entity|decorative}:(prototype name):{probability|richness}.
Fields
key: &'static strvalue: &'static strTrait Implementations
Sourceimpl Clone for PropertyExpressionNamesPair
impl Clone for PropertyExpressionNamesPair
Sourcefn clone(&self) -> PropertyExpressionNamesPair
fn clone(&self) -> PropertyExpressionNamesPair
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PropertyExpressionNamesPair
Sourceimpl Debug for PropertyExpressionNamesPair
impl Debug for PropertyExpressionNamesPair
Sourceimpl Default for PropertyExpressionNamesPair
impl Default for PropertyExpressionNamesPair
Sourcefn default() -> PropertyExpressionNamesPair
fn default() -> PropertyExpressionNamesPair
Returns the “default value” for a type. Read more
impl Eq for PropertyExpressionNamesPair
impl StructuralPartialEq for PropertyExpressionNamesPair