ScriptRenderTargetTable

Struct ScriptRenderTargetTable 

pub struct ScriptRenderTargetTable {
    pub entity: LuaEntity,
    pub offset: LuaAny,
    pub position: LuaAny,
    pub type: ScriptRenderTargetTableType,
}
If an entity target of an object (except its orientation_target) is destroyed or changes surface, then the object is also destroyed.

Targets of type "cursor" draw at the position of the player’s cursor.

Targets of type "build-cursor" draw at the position of the player’s build cursor, including snapping to the build position. The offset is rotated by the entity’s direction and mirrored if the entity to be built is mirrored. Recommended to be combined with ScriptRenderMode::build-cursor.

Fields

entity: LuaEntityoffset: LuaAnyposition: LuaAnytype: ScriptRenderTargetTableType