pub struct SelectionModeFlags {
pub flags: &'static [&'static str],
}Expand description
A set of flags on a selection tool that define how entities and tiles are selected. Active flags are in the dictionary as true, while inactive flags aren’t present at all.
Factorio flag set: active keys present as true in a Lua table.
Construct with flags: &["left", "right"]. Lowers to
{ ["left"] = true, ["right"] = true }.
Fields
flags: &'static [&'static str]Trait Implementations
Sourceimpl Clone for SelectionModeFlags
impl Clone for SelectionModeFlags
Sourcefn clone(&self) -> SelectionModeFlags
fn clone(&self) -> SelectionModeFlags
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SelectionModeFlags
Sourceimpl Debug for SelectionModeFlags
impl Debug for SelectionModeFlags
Sourceimpl Default for SelectionModeFlags
impl Default for SelectionModeFlags
Sourcefn default() -> SelectionModeFlags
fn default() -> SelectionModeFlags
Returns the “default value” for a type. Read more
impl Eq for SelectionModeFlags
Sourceimpl PartialEq for SelectionModeFlags
impl PartialEq for SelectionModeFlags
impl StructuralPartialEq for SelectionModeFlags