pub struct UtilityConstants {Show 199 fields
pub agricultural_range_visualization_color: LuaAny,
pub artillery_range_visualization_color: LuaAny,
pub asteroid_collector_blockage_update_tile_distance: u32,
pub asteroid_collector_max_nurbs_control_point_separation: f64,
pub asteroid_collector_navmesh_refresh_tick_interval: u32,
pub asteroid_collector_static_head_swing_segment_count: u32,
pub asteroid_collector_static_head_swing_strength_scale: f32,
pub asteroid_fading_range: f32,
pub asteroid_position_offset_to_speed_coefficient: f64,
pub asteroid_spawning_offset: LuaAny,
pub asteroid_spawning_with_random_orientation_max_speed: f64,
pub blueprint_big_slots_per_row: u8,
pub blueprint_small_slots_per_row: u8,
pub bonus_gui_ordering: LuaAny,
pub building_buildable_tint: LuaAny,
pub building_buildable_too_far_tint: LuaAny,
pub building_collision_mask: LuaAny,
pub building_ignorable_tint: LuaAny,
pub building_no_tint: LuaAny,
pub building_not_buildable_tint: LuaAny,
pub capsule_range_visualization_color: LuaAny,
pub capture_water_mask_at_layer: u8,
pub chart: LuaAny,
pub chart_search_highlight: LuaAny,
pub checkerboard_black: LuaAny,
pub checkerboard_white: LuaAny,
pub clear_cursor_volume_modifier: f32,
pub clipboard_history_size: u32,
pub color_filters: &'static [LuaAny],
pub construction_robots_use_busy_robots_queue: bool,
pub count_button_size: i32,
pub crafting_queue_slots_per_row: u8,
pub daytime_color_lookup: LuaAny,
pub deconstruct_mark_tint: LuaAny,
pub default_alert_icon_scale: f32,
pub default_alert_icon_scale_by_type: LuaAny,
pub default_alert_icon_shift_by_type: LuaAny,
pub default_collision_masks: LuaAny,
pub default_enemy_force_color: LuaAny,
pub default_item_weight: LuaAny,
pub default_other_force_color: LuaAny,
pub default_pipeline_extent: f64,
pub default_planet_procession_set: LuaAny,
pub default_platform_procession_set: LuaAny,
pub default_platform_surface_render_parameters: LuaAny,
pub default_player_force_color: LuaAny,
pub default_rocket_lift_weight: LuaAny,
pub default_scorch_mark_color: LuaAny,
pub default_trigger_target_mask_by_type: LuaAny,
pub disabled_recipe_slot_background_tint: LuaAny,
pub disabled_recipe_slot_tint: LuaAny,
pub drop_item_radius: f64,
pub dynamic_recipe_overload_factor: f64,
pub ejected_item_direction_variation: f64,
pub ejected_item_friction: f64,
pub ejected_item_lifetime: u32,
pub ejected_item_speed: f64,
pub enabled_recipe_slot_tint: LuaAny,
pub enemies_in_simulation_volume_modifier: f32,
pub entity_button_background_color: LuaAny,
pub entity_renderer_search_box_limits: LuaAny,
pub environment_sounds_transition_fade_in_ticks: u32,
pub equipment_default_background_border_color: LuaAny,
pub equipment_default_background_color: LuaAny,
pub equipment_default_grabbed_background_color: LuaAny,
pub equipment_disabled_background_tint: LuaAny,
pub equipment_disabled_tint: LuaAny,
pub explosions_in_simulation_volume_modifier: f32,
pub factoriopedia_recycling_recipe_categories: &'static [LuaAny],
pub far_away_chunk_generation_radius: u8,
pub feedback_screenshot_file_name: &'static str,
pub feedback_screenshot_subfolder_name: &'static str,
pub filter_outline_color: LuaAny,
pub flying_text_ttl: i32,
pub forced_enabled_recipe_slot_background_tint: LuaAny,
pub freezing_temperature: f64,
pub frozen_color_lookup: LuaAny,
pub ghost_layer: LuaAny,
pub ghost_product_count_tint: LuaAny,
pub ghost_shader_tint: LuaAny,
pub ghost_shaderless_tint: LuaAny,
pub ghost_shimmer_settings: LuaAny,
pub gui_remark_color: LuaAny,
pub gui_search_match_background_color: LuaAny,
pub gui_search_match_foreground_color: LuaAny,
pub huge_area_size: f32,
pub huge_platform_animation_sound_area: f32,
pub icon_shadow_color: LuaAny,
pub icon_shadow_inset: f32,
pub icon_shadow_radius: f32,
pub icon_shadow_sharpness: f32,
pub inserter_hand_stack_items_per_sprite: u32,
pub inserter_hand_stack_max_sprites: u32,
pub inventory_width: u8,
pub item_ammo_magazine_left_bar_color: LuaAny,
pub item_default_random_tint_strength: LuaAny,
pub item_health_bar_colors: &'static [LuaAny],
pub item_outline_color: LuaAny,
pub item_outline_inset: f32,
pub item_outline_radius: f32,
pub item_outline_sharpness: f32,
pub item_tool_durability_bar_color: LuaAny,
pub landing_area_clear_zone_radius: f32,
pub landing_area_max_radius: f32,
pub landing_squash_immunity: u32,
pub large_area_size: f32,
pub large_blueprint_area_size: f32,
pub light_renderer_search_distance_limit: u8,
pub lightning_attractor_collection_range_color: LuaAny,
pub lightning_attractor_protection_range_color: LuaAny,
pub logistic_gui_selected_network_highlight_tint: LuaAny,
pub logistic_gui_unselected_network_highlight_tint: LuaAny,
pub logistic_robots_use_busy_robots_queue: bool,
pub logistic_slots_per_row: u8,
pub low_energy_robot_estimate_multiplier: f64,
pub main_menu_background_image_location: &'static str,
pub main_menu_background_vignette_intensity: f32,
pub main_menu_background_vignette_sharpness: f32,
pub main_menu_simulations: LuaAny,
pub manual_rail_building_reach_modifier: f64,
pub map_editor: LuaAny,
pub max_belt_stack_size: u8,
pub max_logistic_filter_count: LuaAny,
pub max_terrain_building_size: u8,
pub maximum_quality_jump: u8,
pub maximum_recipe_overload_multiplier: u32,
pub medium_area_size: f32,
pub medium_blueprint_area_size: f32,
pub merge_bonus_gui_production_bonuses: bool,
pub minimum_recipe_overload_multiplier: u32,
pub missing_preview_sprite_location: &'static str,
pub module_inventory_width: u8,
pub moving_sound_count_reduction_rate: f32,
pub player_colors: &'static [LuaAny],
pub probability_product_count_tint: LuaAny,
pub quality_selector_dropdown_threshold: u8,
pub rail_planner_count_button_color: LuaAny,
pub rail_segment_colors: &'static [LuaAny],
pub recipe_step_limit: u32,
pub remote_view_LPF_max_cutoff_frequency: f32,
pub remote_view_LPF_min_cutoff_frequency: f32,
pub script_command_console_chat_color: LuaAny,
pub select_group_row_count: u8,
pub select_slot_row_count: u8,
pub selected_chart_search_highlight: LuaAny,
pub server_command_console_chat_color: LuaAny,
pub show_chunk_components_collision_mask: LuaAny,
pub small_area_size: f32,
pub small_blueprint_area_size: f32,
pub sound_fade_ticks: u32,
pub space_LPF_max_cutoff_frequency: f32,
pub space_LPF_min_cutoff_frequency: f32,
pub space_platform_acceleration_expression: LuaAny,
pub space_platform_asteroid_chunk_trajectory_updates_per_tick: u32,
pub space_platform_dump_cooldown: u32,
pub space_platform_manual_dump_cooldown: u32,
pub space_platform_max_relative_speed_deviation_for_asteroid_chunks_update: f32,
pub space_platform_max_size: LuaAny,
pub space_platform_relative_speed_factor: f64,
pub space_platform_starfield_movement_vector: LuaAny,
pub spawner_evolution_factor_health_modifier: f32,
pub starmap_orbit_clicked_color: LuaAny,
pub starmap_orbit_default_color: LuaAny,
pub starmap_orbit_disabled_color: LuaAny,
pub starmap_orbit_hovered_color: LuaAny,
pub tall_entity_smoke_tint: LuaAny,
pub tall_entity_tint: LuaAny,
pub time_to_show_full_health_bar: u32,
pub tooltip_monitor_edge_border: i32,
pub train_inactivity_wait_condition_default: u32,
pub train_on_elevated_rail_shadow_shift_multiplier: LuaAny,
pub train_path_finding: LuaAny,
pub train_pushed_by_player_ignores_friction: bool,
pub train_pushed_by_player_max_acceleration: f64,
pub train_pushed_by_player_max_speed: f64,
pub train_temporary_stop_wait_time: u32,
pub train_time_wait_condition_default: u32,
pub train_visualization: LuaAny,
pub trash_inventory_width: u8,
pub tree_leaf_distortion_distortion_far: LuaAny,
pub tree_leaf_distortion_distortion_near: LuaAny,
pub tree_leaf_distortion_speed_far: LuaAny,
pub tree_leaf_distortion_speed_near: LuaAny,
pub tree_leaf_distortion_strength_far: LuaAny,
pub tree_leaf_distortion_strength_near: LuaAny,
pub tree_shadow_roughness: f32,
pub tree_shadow_speed: f32,
pub turret_range_visualization_color: LuaAny,
pub underground_belt_max_distance_tint: LuaAny,
pub underground_pipe_max_distance_tint: LuaAny,
pub unit_group_max_pursue_distance: f64,
pub unit_group_pathfind_resolution: i8,
pub walking_sound_count_reduction_rate: f32,
pub water_collision_mask: LuaAny,
pub weapons_in_simulation_volume_modifier: f32,
pub zero_count_value_tint: LuaAny,
pub zoom_to_world_can_use_nightvision: bool,
pub zoom_to_world_daytime_color_lookup: LuaAny,
pub zoom_to_world_effect_strength: f32,
}Expand description
Constants used by the game that are not specific to certain prototypes. See utility-constants.lua for the values used by the base game.
Note that this is actually implemented as a LuaCustomTable, not a regular table.
Fields
agricultural_range_visualization_color: LuaAnyartillery_range_visualization_color: LuaAnyasteroid_collector_blockage_update_tile_distance: u32asteroid_collector_max_nurbs_control_point_separation: f64asteroid_collector_static_head_swing_segment_count: u32asteroid_collector_static_head_swing_strength_scale: f32asteroid_fading_range: f32asteroid_position_offset_to_speed_coefficient: f64asteroid_spawning_offset: LuaAnyasteroid_spawning_with_random_orientation_max_speed: f64blueprint_big_slots_per_row: u8blueprint_small_slots_per_row: u8bonus_gui_ordering: LuaAnybuilding_buildable_tint: LuaAnybuilding_buildable_too_far_tint: LuaAnybuilding_collision_mask: LuaAnybuilding_ignorable_tint: LuaAnybuilding_no_tint: LuaAnybuilding_not_buildable_tint: LuaAnycapsule_range_visualization_color: LuaAnycapture_water_mask_at_layer: u8chart: LuaAnychart_search_highlight: LuaAnycheckerboard_black: LuaAnycheckerboard_white: LuaAnyclear_cursor_volume_modifier: f32clipboard_history_size: u32color_filters: &'static [LuaAny]construction_robots_use_busy_robots_queue: boolcrafting_queue_slots_per_row: u8daytime_color_lookup: LuaAnydeconstruct_mark_tint: LuaAnydefault_alert_icon_scale: f32default_alert_icon_scale_by_type: LuaAnydefault_alert_icon_shift_by_type: LuaAnydefault_collision_masks: LuaAnydefault_enemy_force_color: LuaAnydefault_item_weight: LuaAnydefault_other_force_color: LuaAnydefault_pipeline_extent: f64default_planet_procession_set: LuaAnydefault_platform_procession_set: LuaAnydefault_platform_surface_render_parameters: LuaAnydefault_player_force_color: LuaAnydefault_rocket_lift_weight: LuaAnydefault_scorch_mark_color: LuaAnydefault_trigger_target_mask_by_type: LuaAnydisabled_recipe_slot_background_tint: LuaAnydisabled_recipe_slot_tint: LuaAnydrop_item_radius: f64dynamic_recipe_overload_factor: f64ejected_item_direction_variation: f64ejected_item_friction: f64ejected_item_lifetime: u32ejected_item_speed: f64enabled_recipe_slot_tint: LuaAnyenemies_in_simulation_volume_modifier: f32entity_renderer_search_box_limits: LuaAnyenvironment_sounds_transition_fade_in_ticks: u32equipment_default_background_border_color: LuaAnyequipment_default_background_color: LuaAnyequipment_default_grabbed_background_color: LuaAnyequipment_disabled_background_tint: LuaAnyequipment_disabled_tint: LuaAnyexplosions_in_simulation_volume_modifier: f32factoriopedia_recycling_recipe_categories: &'static [LuaAny]far_away_chunk_generation_radius: u8feedback_screenshot_file_name: &'static strfeedback_screenshot_subfolder_name: &'static strfilter_outline_color: LuaAnyflying_text_ttl: i32forced_enabled_recipe_slot_background_tint: LuaAnyfreezing_temperature: f64frozen_color_lookup: LuaAnyghost_layer: LuaAnyghost_product_count_tint: LuaAnyghost_shader_tint: LuaAnyghost_shaderless_tint: LuaAnyghost_shimmer_settings: LuaAnygui_remark_color: LuaAnygui_search_match_background_color: LuaAnygui_search_match_foreground_color: LuaAnyhuge_area_size: f32huge_platform_animation_sound_area: f32icon_shadow_color: LuaAnyicon_shadow_inset: f32icon_shadow_radius: f32icon_shadow_sharpness: f32inserter_hand_stack_items_per_sprite: u32inserter_hand_stack_max_sprites: u32inventory_width: u8item_ammo_magazine_left_bar_color: LuaAnyitem_default_random_tint_strength: LuaAnyitem_health_bar_colors: &'static [LuaAny]item_outline_color: LuaAnyitem_outline_inset: f32item_outline_radius: f32item_outline_sharpness: f32item_tool_durability_bar_color: LuaAnylanding_area_clear_zone_radius: f32landing_area_max_radius: f32landing_squash_immunity: u32large_area_size: f32large_blueprint_area_size: f32light_renderer_search_distance_limit: u8lightning_attractor_collection_range_color: LuaAnylightning_attractor_protection_range_color: LuaAnylogistic_gui_selected_network_highlight_tint: LuaAnylogistic_gui_unselected_network_highlight_tint: LuaAnylogistic_robots_use_busy_robots_queue: boollogistic_slots_per_row: u8low_energy_robot_estimate_multiplier: f64manual_rail_building_reach_modifier: f64map_editor: LuaAnymax_belt_stack_size: u8max_logistic_filter_count: LuaAnymax_terrain_building_size: u8maximum_quality_jump: u8maximum_recipe_overload_multiplier: u32medium_area_size: f32medium_blueprint_area_size: f32merge_bonus_gui_production_bonuses: boolminimum_recipe_overload_multiplier: u32missing_preview_sprite_location: &'static strmodule_inventory_width: u8moving_sound_count_reduction_rate: f32player_colors: &'static [LuaAny]probability_product_count_tint: LuaAnyquality_selector_dropdown_threshold: u8rail_segment_colors: &'static [LuaAny]recipe_step_limit: u32remote_view_LPF_max_cutoff_frequency: f32remote_view_LPF_min_cutoff_frequency: f32script_command_console_chat_color: LuaAnyselect_group_row_count: u8select_slot_row_count: u8selected_chart_search_highlight: LuaAnyserver_command_console_chat_color: LuaAnyshow_chunk_components_collision_mask: LuaAnysmall_area_size: f32small_blueprint_area_size: f32sound_fade_ticks: u32space_LPF_max_cutoff_frequency: f32space_LPF_min_cutoff_frequency: f32space_platform_acceleration_expression: LuaAnyspace_platform_asteroid_chunk_trajectory_updates_per_tick: u32space_platform_dump_cooldown: u32space_platform_manual_dump_cooldown: u32space_platform_max_relative_speed_deviation_for_asteroid_chunks_update: f32space_platform_max_size: LuaAnyspace_platform_relative_speed_factor: f64space_platform_starfield_movement_vector: LuaAnyspawner_evolution_factor_health_modifier: f32starmap_orbit_clicked_color: LuaAnystarmap_orbit_default_color: LuaAnystarmap_orbit_disabled_color: LuaAnystarmap_orbit_hovered_color: LuaAnytall_entity_smoke_tint: LuaAnytall_entity_tint: LuaAnytime_to_show_full_health_bar: u32tooltip_monitor_edge_border: i32train_inactivity_wait_condition_default: u32train_on_elevated_rail_shadow_shift_multiplier: LuaAnytrain_path_finding: LuaAnytrain_pushed_by_player_ignores_friction: booltrain_pushed_by_player_max_acceleration: f64train_pushed_by_player_max_speed: f64train_temporary_stop_wait_time: u32train_time_wait_condition_default: u32train_visualization: LuaAnytrash_inventory_width: u8tree_leaf_distortion_distortion_far: LuaAnytree_leaf_distortion_distortion_near: LuaAnytree_leaf_distortion_speed_far: LuaAnytree_leaf_distortion_speed_near: LuaAnytree_leaf_distortion_strength_far: LuaAnytree_leaf_distortion_strength_near: LuaAnytree_shadow_roughness: f32tree_shadow_speed: f32turret_range_visualization_color: LuaAnyunderground_belt_max_distance_tint: LuaAnyunderground_pipe_max_distance_tint: LuaAnyunit_group_max_pursue_distance: f64unit_group_pathfind_resolution: i8walking_sound_count_reduction_rate: f32water_collision_mask: LuaAnyweapons_in_simulation_volume_modifier: f32zero_count_value_tint: LuaAnyzoom_to_world_can_use_nightvision: boolzoom_to_world_daytime_color_lookup: LuaAnyzoom_to_world_effect_strength: f32Trait Implementations
Sourceimpl Clone for UtilityConstants
impl Clone for UtilityConstants
Sourcefn clone(&self) -> UtilityConstants
fn clone(&self) -> UtilityConstants
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UtilityConstants
Sourceimpl Debug for UtilityConstants
impl Debug for UtilityConstants
Sourceimpl Default for UtilityConstants
impl Default for UtilityConstants
Sourcefn default() -> UtilityConstants
fn default() -> UtilityConstants
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UtilityConstants
impl PartialEq for UtilityConstants
impl StructuralPartialEq for UtilityConstants