pub struct Vector3D {
pub x: f32,
pub y: f32,
pub z: f32,
}Expand description
Reading this always returns the table with the named keys.
If this is specified as a three-element array then the array items are x, y and z, in that order.
Fields
x: f32y: f32z: f32Trait Implementations
impl Copy for Vector3D
impl StructuralPartialEq for Vector3D