pub type SoundPath = &'static str;Expand description
It can be either the name of a SoundPrototype defined in the data stage, or a path in the form "type/name". The latter option can be sorted into four categories.
The validity of a SoundPath can be verified at runtime using LuaHelpers::is_valid_sound_path.