Module defines

Module defines 

Modules

alert_type
behavior_result
AI command exit status, see LuaCommandable::set_command
build_check_type
build_mode
cargo_destination
chain_signal_state
State of a chain signal.
chunk_generated_status
command
Command given to units describing what they should do.
compound_command
How commands are joined together in a compound command (see defines.command.compound).
constant
control_behavior
controllers
deconstruction_item
difficulty
direction
disconnect_reason
distraction
electric_interface_mode
entity_status
entity_status_diode
events
See the events page for more info on what events contain and when they get raised.
flow_precision_index
game_controller_interaction
group_state
gui_type
input_action
input_method
inventory
inventory_actions
logistic_group_type
logistic_member_index
logistic_mode
logistic_section_type
mouse_button_type
moving_state
print_skip
print_sound
prototypes
This define describes all top-level prototypes and their associated subtypes. It is organized as a lookup table, meaning the values of all the defines is 0. As an example, defines.prototypes['entity'] looks like {furnace=0, inserter=0, container=0, ...}.
rail_connection_direction
rail_direction
rail_layer
relative_gui_position
relative_gui_type
render_mode
rich_text_setting
riding
robot_order_type
rocket_silo_status
The various parts of the launch sequence of the rocket silo.
segmented_unit_activity_mode
segmented_unit_ai_state
segmented_unit_created_cause
selection_mode
shooting
signal_state
State of an ordinary rail signal.
space_platform_state
target_type
territory_created_cause
train_state
transport_line
wire_connector_id
wire_origin
wire_type