Module cargo_destination

Module cargo_destination 

Constants

INVALID
The default destination type of a cargo pod when created runtime. Setting its destination to any other type will instantly launch it.
ORBIT
Cargo pods with orbit destination are destroyed when ascent is completed.
SPACE_PLATFORM
Only used for sending a space platform starter pack to a platform that is waiting for one. Regular deliveries to space platform hubs use station destination type instead.
STATION
Any cargo landing pad or space platform hub.
SURFACE
Cargo pods will switch destination type from surface to station before starting descent if there is a station available and CargoDestination::position has not been specified. Note, setting the destination to “surface” when the surface is the same as the one the pod is on forces it to find and set a landing position.