Module command

Module command 

Command given to units describing what they should do.

Constants

ATTACK
Attack another entity.
ATTACK_AREA
Go to a place and attack what you see.
BUILD_BASE
Go to a position and build a base there.
COMPOUND
Chain commands together, see defines.compound_command.
FLEE
Flee from another entity.
GO_TO_LOCATION
Go to a specific position.
GROUP
Do what your group wants you to do.
STOP
Stop moving and stay where you are.
WANDER
Chill.