Module compound_command

Module compound_command 

How commands are joined together in a compound command (see defines.command.compound).

Constants

LOGICAL_AND
Fail on first failure. Only succeeds if all commands (executed one after another) succeed.
LOGICAL_OR
Succeed on first success. Only fails if all commands (executed one after another) fail.
RETURN_LAST
Execute all commands in sequence and fail or succeed depending on the return status of the last command.