Module controllers

Module controllers 

Constants

CHARACTER
The controller controls a character. This is the default controller in freeplay.
CUTSCENE
The player can’t interact with the world, and the camera pans around in a predefined manner.
EDITOR
The Editor Controller near ultimate power to do almost anything in the game.
GHOST
Can’t interact with the world, can only observe. Used in the multiplayer waiting-to-respawn screen.
GOD
The controller isn’t tied to a character. This is the default controller in sandbox.
REMOTE
Can’t move/change items but can build ghosts/change settings.
SPECTATOR
Can’t change anything in the world but can view anything.