Module entity_status

Module entity_status 

Constants

ARMED
Used by land mines.
BROKEN
Only used if set through ContainerPrototype::default_status.
CANT_DIVIDE_SEGMENTS
Used by rail signals.
CHARGING
Used by accumulators.
CLOSED_BY_CIRCUIT_NETWORK
COMPUTING_NAVIGATION
Used by asteroid collectors.
DESTINATION_STOP_FULL
Used by trains.
DISABLED
Used by constant combinators: Combinator is turned off via switch in GUI. Also used by inserters.
DISABLED_BY_CONTROL_BEHAVIOR
DISABLED_BY_SCRIPT
DISCHARGING
Used by accumulators.
FLUID_INGREDIENT_SHORTAGE
Used by crafting machines.
FROZEN
FULLY_CHARGED
Used by accumulators.
FULL_BURNT_RESULT_OUTPUT
Used by burner energy sources.
FULL_OUTPUT
Used by crafting machines, boilers, burner energy sources, and reactors: Reactor/burner has full burnt result inventory, boiler has full output fluidbox.
GHOST
Used by ghosts.
HATCHES_BLOCKED_BY_ELEVATED_RAIL
Used by cargo bays.
ITEM_INGREDIENT_SHORTAGE
Used by crafting machines.
LAUNCHING_ROCKET
Used by the rocket silo.
LOW_INPUT_FLUID
Used by boilers and fluid turrets: Boiler still has some fluid but is about to run out.
LOW_POWER
LOW_TEMPERATURE
Used by heat energy sources.
MARKED_FOR_DECONSTRUCTION
MISSING_REQUIRED_FLUID
Used by mining drills when the mining fluid is missing.
MISSING_SCIENCE_PACKS
Used by labs.
NETWORKS_CONNECTED
Used by power switches.
NETWORKS_DISCONNECTED
Used by power switches.
NORMAL
NOT_CONNECTED_TO_HUB_OR_PAD
Used by cargo bays.
NOT_CONNECTED_TO_RAIL
Used by rail signals.
NOT_ENOUGH_SPACE_IN_OUTPUT
Used by agricultural towers.
NOT_ENOUGH_THRUST
Used by space platform hubs.
NOT_PLUGGED_IN_ELECTRIC_NETWORK
Used by generators and solar panels.
NO_AMMO
Used by ammo turrets.
NO_FILTER
Used by filter inserters.
NO_FUEL
NO_INGREDIENTS
Used by furnaces.
NO_INPUT_FLUID
Used by boilers, fluid turrets, and fluid energy sources: Boiler has no fluid to work with.
NO_MINABLE_RESOURCES
Used by mining drills.
NO_MODULES_TO_TRANSMIT
Used by beacons.
NO_PATH
Used by trains and space platform hubs.
NO_POWER
NO_RECIPE
Used by assembling machines.
NO_RESEARCH_IN_PROGRESS
Used by labs.
NO_SPOT_SEEDABLE_BY_INPUTS
Used by agricultural towers.
ON_THE_WAY
Used by space platform hubs.
OPENED_BY_CIRCUIT_NETWORK
OUT_OF_LOGISTIC_NETWORK
Used by logistic containers.
PAUSED
Used by space platform hubs.
PIPELINE_OVEREXTENDED
Used by pipes, pipes to ground, and storage tanks.
PREPARING_ROCKET_FOR_LAUNCH
Used by the rocket silo.
RECHARGING_AFTER_POWER_OUTAGE
Used by roboports.
RECIPE_IS_PARAMETER
Used by assembling machines.
RECIPE_NOT_RESEARCHED
Used by assembling machines.
THRUST_NOT_REQUIRED
Used by thrusters.
TOO_FAR_FROM_PAD_TO_UNLOAD
Used by some cargo bays.
TURNED_OFF_DURING_DAYTIME
Used by lamps.
WAITING_AT_STOP
Used by trains.
WAITING_FOR_MORE_ITEMS
Used by inserters when wait_for_full_hand is set.
WAITING_FOR_PLANTS_TO_GROW
Used by agricultural towers.
WAITING_FOR_ROCKETS_TO_ARRIVE
Used by space platform hubs.
WAITING_FOR_SOURCE_ITEMS
Used by inserters.
WAITING_FOR_SPACE_IN_DESTINATION
Used by inserters, mining drills, and crafting machines using vector_to_place_result.
WAITING_FOR_SPACE_IN_PLATFORM_HUB
Used by the rocket silo.
WAITING_FOR_TARGET_TO_BE_BUILT
Used by inserters targeting entity ghosts.
WAITING_FOR_TRAIN
Used by inserters targeting rails.
WAITING_FOR_UPGRADE
Used by trains.
WAITING_IN_ORBIT
Used by space platform hubs.
WAITING_TO_CLEAR_DROP_SLOTS
Used by space platform hubs.
WAITING_TO_LAUNCH_ROCKET
Used by the rocket silo.
WORKING