Module print_skip

Module print_skip 

Constants

IF_REDUNDANT
Print will be skipped if same text was recently printed (within last 60 ticks). Used by most game messages.
IF_VISIBLE
Print will be skipped if same text is still visible (printed within last 1152 ticks). Used by some notifications.
NEVER
Print will not be skipped.