Module rocket_silo_status

Module rocket_silo_status 

The various parts of the launch sequence of the rocket silo.

Constants

ARMS_ADVANCE
The next state is rocket_ready or if the rocket is destroyed in this state then the next state will be lights_blinking_close. The rocket is getting prepared for launch.
ARMS_RETRACT
The next state is rocket_flying or if the rocket is destroyed in this state then the next state will be lights_blinking_close. The rocket is getting launched.
BUILDING_ROCKET
The rocket silo is crafting rocket parts. When there are enough rocket parts, the silo will switch into the create_rocket state.
CREATE_ROCKET
The next state is lights_blinking_open. The rocket silo rocket entity gets created.
DOORS_CLOSING
The next state is building_rocket.
DOORS_OPENED
The next state is rocket_rising or if the rocket is destroyed in this state then the next state will be lights_blinking_close. The rocket is getting prepared for launch.
DOORS_OPENING
The next state is doors_opened. The rocket is getting prepared for launch.
ENGINE_STARTING
The next state is arms_retract or if the rocket is destroyed in this state then the next state will be lights_blinking_close. The rocket is getting launched.
LAUNCH_STARTED
The next state is engine_starting or if the rocket is destroyed in this state then the next state will be lights_blinking_close. The rocket is getting launched.
LAUNCH_STARTING
The next state is launch_started.
LIGHTS_BLINKING_CLOSE
The next state is doors_closing.
LIGHTS_BLINKING_OPEN
The next state is doors_opening. The rocket is getting prepared for launch.
ROCKET_FLYING
The next state is lights_blinking_close. The rocket is getting launched.
ROCKET_READY
The rocket launch can be started by the player. When the launch is started, the silo switches into the launch_starting state.
ROCKET_RISING
The next state is arms_advance or if the rocket is destroyed in this state then the next state will be lights_blinking_close. The rocket is getting prepared for launch.