Module segmented_unit_ai_state

Module segmented_unit_ai_state 

Constants

ATTACKING
The segmented unit is attacking an entity that is trespassing on its territory, but the segmented unit is not using its full strength.
ENRAGED_AT_NOTHING
The segmented unit is angry because it was attacked but it does not have a valid attack target, so it is wandering around trying to find a valid attack target.
ENRAGED_AT_TARGET
The segmented unit is angry because it was attacked and is aggressively attacking an entity with its full strength.
INVESTIGATING
The segmented unit is investigating a location where it detected a disturbance.
PATROLLING
The segmented unit is navigating its territory’s patrol path. If the unit is not assigned to a territory, then it is patrolling around the position it was created.