Module wire_origin
factorio_
api
0.1.1
Module wire_
origin
Module Items
Constants
In factorio_
api::
defines
factorio_api
::
defines
Module
wire_
origin
Constants

PLAYER
These wires can be modified by players, scripts, and the game. They are visible to the player if the entity’s
draw_circuit_wires
prototype property is set to
true
and both ends of it are on the same surface.
RADARS
These wires can only be modified by the game. They are not visible to the player, irrespective of the
draw_circuit_wires
prototype property.
SCRIPT
These wires can be modified by scripts and the game. They are not visible to the player, irrespective of the
draw_circuit_wires
prototype property.