pub struct OnBlueprintSettingsPastedEvent {
pub entity: LuaEntity,
pub mirrored: bool,
pub name: &'static str,
pub player_index: u32,
pub previous_direction: &'static str,
pub tags: LuaAny,
pub tick: u32,
}Expand description
Called when a blueprint entity is pasted over an existing entity or entity ghost.
The entity’s settings, rotation, mirroring, wire connections, etc. may have been updated. This event is raised even if no settings actually changed.
Note this event is not raised when an entity is upgraded or marked for upgrade, when a new entity is created, or when an entity ghost is instantly revived. on_built_entity is raised instead in those cases.
Fields
entity: LuaEntitymirrored: boolname: &'static strplayer_index: u32previous_direction: &'static strtick: u32Trait Implementations
Sourceimpl Clone for OnBlueprintSettingsPastedEvent
impl Clone for OnBlueprintSettingsPastedEvent
Sourcefn clone(&self) -> OnBlueprintSettingsPastedEvent
fn clone(&self) -> OnBlueprintSettingsPastedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnBlueprintSettingsPastedEvent
Sourceimpl Default for OnBlueprintSettingsPastedEvent
impl Default for OnBlueprintSettingsPastedEvent
Sourcefn default() -> OnBlueprintSettingsPastedEvent
fn default() -> OnBlueprintSettingsPastedEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnBlueprintSettingsPastedEvent