pub struct OnCargoPodFinishedDescendingEvent {
pub cargo_pod: LuaEntity,
pub launched_by_rocket: bool,
pub name: &'static str,
pub player_index: u32,
pub tick: u32,
}Expand description
Called when a cargo pods lands on a surface, either at a station or on the ground.
Fields
cargo_pod: LuaEntitylaunched_by_rocket: boolname: &'static strplayer_index: u32tick: u32Trait Implementations
Sourceimpl Clone for OnCargoPodFinishedDescendingEvent
impl Clone for OnCargoPodFinishedDescendingEvent
Sourcefn clone(&self) -> OnCargoPodFinishedDescendingEvent
fn clone(&self) -> OnCargoPodFinishedDescendingEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnCargoPodFinishedDescendingEvent
Sourceimpl Default for OnCargoPodFinishedDescendingEvent
impl Default for OnCargoPodFinishedDescendingEvent
Sourcefn default() -> OnCargoPodFinishedDescendingEvent
fn default() -> OnCargoPodFinishedDescendingEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnCargoPodFinishedDescendingEvent