pub struct OnCargoPodStartedAscendingEvent {
pub cargo_pod: LuaEntity,
pub name: &'static str,
pub player_index: u32,
pub tick: u32,
}Expand description
Called when a cargo pod departs from a space platform hub or by another method not attached to a rocket.
Fields
cargo_pod: LuaEntityname: &'static strplayer_index: u32tick: u32Trait Implementations
Sourceimpl Clone for OnCargoPodStartedAscendingEvent
impl Clone for OnCargoPodStartedAscendingEvent
Sourcefn clone(&self) -> OnCargoPodStartedAscendingEvent
fn clone(&self) -> OnCargoPodStartedAscendingEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnCargoPodStartedAscendingEvent
Sourceimpl Default for OnCargoPodStartedAscendingEvent
impl Default for OnCargoPodStartedAscendingEvent
Sourcefn default() -> OnCargoPodStartedAscendingEvent
fn default() -> OnCargoPodStartedAscendingEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnCargoPodStartedAscendingEvent