pub struct OnCharacterCorpseExpiredEvent {
pub corpse: LuaEntity,
pub name: &'static str,
pub tick: u32,
}Expand description
Called when a character corpse expires due to timeout or all of the items being removed from it.
this is not called if the corpse is mined. See defines.events.on_pre_player_mined_item to detect that.
Fields
corpse: LuaEntityname: &'static strtick: u32Trait Implementations
Sourceimpl Clone for OnCharacterCorpseExpiredEvent
impl Clone for OnCharacterCorpseExpiredEvent
Sourcefn clone(&self) -> OnCharacterCorpseExpiredEvent
fn clone(&self) -> OnCharacterCorpseExpiredEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnCharacterCorpseExpiredEvent
Sourceimpl Default for OnCharacterCorpseExpiredEvent
impl Default for OnCharacterCorpseExpiredEvent
Sourcefn default() -> OnCharacterCorpseExpiredEvent
fn default() -> OnCharacterCorpseExpiredEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnCharacterCorpseExpiredEvent