pub struct OnConsoleChatEvent {
pub message: &'static str,
pub name: &'static str,
pub player_index: u32,
pub tick: u32,
}Expand description
Called when a message is sent to the in-game console, either by a player or through the server interface.
This event only fires for plain messages, not for any commands (including /shout or /whisper).
Fields
message: &'static strname: &'static strplayer_index: u32tick: u32Trait Implementations
Sourceimpl Clone for OnConsoleChatEvent
impl Clone for OnConsoleChatEvent
Sourcefn clone(&self) -> OnConsoleChatEvent
fn clone(&self) -> OnConsoleChatEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnConsoleChatEvent
Sourceimpl Debug for OnConsoleChatEvent
impl Debug for OnConsoleChatEvent
Sourceimpl Default for OnConsoleChatEvent
impl Default for OnConsoleChatEvent
Sourcefn default() -> OnConsoleChatEvent
fn default() -> OnConsoleChatEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnConsoleChatEvent
impl PartialEq for OnConsoleChatEvent
impl StructuralPartialEq for OnConsoleChatEvent