pub struct OnCutsceneWaypointReachedEvent {
pub name: &'static str,
pub player_index: u32,
pub tick: u32,
pub waypoint_index: u32,
}Expand description
Called when a cutscene is playing, each time it reaches a waypoint in that cutscene.
This refers to an index in the table previously passed to set_controller which started the cutscene.
Fields
name: &'static strplayer_index: u32tick: u32waypoint_index: u32Trait Implementations
Sourceimpl Clone for OnCutsceneWaypointReachedEvent
impl Clone for OnCutsceneWaypointReachedEvent
Sourcefn clone(&self) -> OnCutsceneWaypointReachedEvent
fn clone(&self) -> OnCutsceneWaypointReachedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnCutsceneWaypointReachedEvent
Sourceimpl Default for OnCutsceneWaypointReachedEvent
impl Default for OnCutsceneWaypointReachedEvent
Sourcefn default() -> OnCutsceneWaypointReachedEvent
fn default() -> OnCutsceneWaypointReachedEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnCutsceneWaypointReachedEvent