pub struct OnEntityColorChangedEvent {
pub entity: LuaEntity,
pub name: &'static str,
pub tick: u32,
}Expand description
Called after an entity has been recolored either by the player or through script.
Automatic recoloring due to LuaPlayer::color will not raise events, as that is a separate mechanism.
Fields
entity: LuaEntityname: &'static strtick: u32Trait Implementations
Sourceimpl Clone for OnEntityColorChangedEvent
impl Clone for OnEntityColorChangedEvent
Sourcefn clone(&self) -> OnEntityColorChangedEvent
fn clone(&self) -> OnEntityColorChangedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnEntityColorChangedEvent
Sourceimpl Debug for OnEntityColorChangedEvent
impl Debug for OnEntityColorChangedEvent
Sourceimpl Default for OnEntityColorChangedEvent
impl Default for OnEntityColorChangedEvent
Sourcefn default() -> OnEntityColorChangedEvent
fn default() -> OnEntityColorChangedEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnEntityColorChangedEvent