pub struct OnForceCreatedEvent {
pub force: LuaForce,
pub name: &'static str,
pub tick: u32,
}Expand description
Called when a new force is created using game.create_force()
This is not called when the default forces ('player', 'enemy', 'neutral') are created as they will always exist.
Fields
force: LuaForcename: &'static strtick: u32Trait Implementations
Sourceimpl Clone for OnForceCreatedEvent
impl Clone for OnForceCreatedEvent
Sourcefn clone(&self) -> OnForceCreatedEvent
fn clone(&self) -> OnForceCreatedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnForceCreatedEvent
Sourceimpl Debug for OnForceCreatedEvent
impl Debug for OnForceCreatedEvent
Sourceimpl Default for OnForceCreatedEvent
impl Default for OnForceCreatedEvent
Sourcefn default() -> OnForceCreatedEvent
fn default() -> OnForceCreatedEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnForceCreatedEvent
impl PartialEq for OnForceCreatedEvent
impl StructuralPartialEq for OnForceCreatedEvent