pub struct OnForcesMergedEvent {
pub destination: LuaForce,
pub name: &'static str,
pub source_index: u32,
pub source_name: &'static str,
pub tick: u32,
}Expand description
Called after two forces have been merged using game.merge_forces().
The source force is invalidated before this event is called and the name can be re-used in this event if desired.
Fields
destination: LuaForcename: &'static strsource_index: u32source_name: &'static strtick: u32Trait Implementations
Sourceimpl Clone for OnForcesMergedEvent
impl Clone for OnForcesMergedEvent
Sourcefn clone(&self) -> OnForcesMergedEvent
fn clone(&self) -> OnForcesMergedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnForcesMergedEvent
Sourceimpl Debug for OnForcesMergedEvent
impl Debug for OnForcesMergedEvent
Sourceimpl Default for OnForcesMergedEvent
impl Default for OnForcesMergedEvent
Sourcefn default() -> OnForcesMergedEvent
fn default() -> OnForcesMergedEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnForcesMergedEvent
impl PartialEq for OnForcesMergedEvent
impl StructuralPartialEq for OnForcesMergedEvent