pub struct OnGameCreatedFromScenarioEvent {
pub name: &'static str,
pub tick: u32,
}Expand description
Called when a game is created from a scenario. This is fired for every mod, even when the scenario’s save data already includes it. In those cases however, LuaBootstrap::on_init is not fired.
This event is not fired when the scenario is loaded via the map editor.
Fields
name: &'static strtick: u32Trait Implementations
Sourceimpl Clone for OnGameCreatedFromScenarioEvent
impl Clone for OnGameCreatedFromScenarioEvent
Sourcefn clone(&self) -> OnGameCreatedFromScenarioEvent
fn clone(&self) -> OnGameCreatedFromScenarioEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnGameCreatedFromScenarioEvent
Sourceimpl Default for OnGameCreatedFromScenarioEvent
impl Default for OnGameCreatedFromScenarioEvent
Sourcefn default() -> OnGameCreatedFromScenarioEvent
fn default() -> OnGameCreatedFromScenarioEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnGameCreatedFromScenarioEvent