pub struct OnGuiClosedEvent {
pub element: LuaGuiElement,
pub entity: LuaEntity,
pub equipment: LuaEquipment,
pub gui_type: &'static str,
pub inventory: LuaInventory,
pub item: LuaItemStack,
pub name: &'static str,
pub other_player: LuaPlayer,
pub player_index: u32,
pub surface_index: u32,
pub tick: u32,
pub tile_position: TilePosition,
}Expand description
Called when the player closes the GUI they have open.
This can only be raised when the GUI’s player controller is still valid. If a GUI is thus closed due to the player disconnecting, dying, or becoming a spectator in other ways, it won’t cause this event to be raised.
It’s not advised to open any other GUI during this event because if this is run as a request to open a different GUI the game will force close the new opened GUI without notice to ensure the original requested GUI is opened.
Fields
element: LuaGuiElemententity: LuaEntityequipment: LuaEquipmentgui_type: &'static strinventory: LuaInventoryitem: LuaItemStackname: &'static strother_player: LuaPlayerplayer_index: u32surface_index: u32tick: u32tile_position: TilePositionTrait Implementations
Sourceimpl Clone for OnGuiClosedEvent
impl Clone for OnGuiClosedEvent
Sourcefn clone(&self) -> OnGuiClosedEvent
fn clone(&self) -> OnGuiClosedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnGuiClosedEvent
Sourceimpl Debug for OnGuiClosedEvent
impl Debug for OnGuiClosedEvent
Sourceimpl Default for OnGuiClosedEvent
impl Default for OnGuiClosedEvent
Sourcefn default() -> OnGuiClosedEvent
fn default() -> OnGuiClosedEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnGuiClosedEvent
impl PartialEq for OnGuiClosedEvent
impl StructuralPartialEq for OnGuiClosedEvent