pub struct OnMultiplayerInitEvent {
pub name: &'static str,
pub tick: u32,
}Expand description
Called when LuaGameScript::is_multiplayer changes to true. May also be raised when it was already true but a game was loaded from a save file and with hosting.
Fields
name: &'static strtick: u32Trait Implementations
Sourceimpl Clone for OnMultiplayerInitEvent
impl Clone for OnMultiplayerInitEvent
Sourcefn clone(&self) -> OnMultiplayerInitEvent
fn clone(&self) -> OnMultiplayerInitEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnMultiplayerInitEvent
Sourceimpl Debug for OnMultiplayerInitEvent
impl Debug for OnMultiplayerInitEvent
Sourceimpl Default for OnMultiplayerInitEvent
impl Default for OnMultiplayerInitEvent
Sourcefn default() -> OnMultiplayerInitEvent
fn default() -> OnMultiplayerInitEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnMultiplayerInitEvent
impl PartialEq for OnMultiplayerInitEvent
impl StructuralPartialEq for OnMultiplayerInitEvent