pub struct OnObjectDestroyedEvent {
pub name: &'static str,
pub registration_number: u64,
pub tick: u32,
pub type: &'static str,
pub useful_id: u64,
}Expand description
Called after an object is destroyed which was registered with LuaBootstrap::register_on_object_destroyed previously.
Depending on when a given object is destroyed, this event will be fired at the end of the current tick or at the end of the next tick. The event’s timing is independent of the in-world object being destroyed.
Fields
name: &'static strregistration_number: u64tick: u32type: &'static struseful_id: u64Trait Implementations
Sourceimpl Clone for OnObjectDestroyedEvent
impl Clone for OnObjectDestroyedEvent
Sourcefn clone(&self) -> OnObjectDestroyedEvent
fn clone(&self) -> OnObjectDestroyedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnObjectDestroyedEvent
Sourceimpl Debug for OnObjectDestroyedEvent
impl Debug for OnObjectDestroyedEvent
Sourceimpl Default for OnObjectDestroyedEvent
impl Default for OnObjectDestroyedEvent
Sourcefn default() -> OnObjectDestroyedEvent
fn default() -> OnObjectDestroyedEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnObjectDestroyedEvent
impl PartialEq for OnObjectDestroyedEvent
impl StructuralPartialEq for OnObjectDestroyedEvent