OnPlayerCraftedItemEvent

Struct OnPlayerCraftedItemEvent 

pub struct OnPlayerCraftedItemEvent {
    pub item_stack: LuaItemStack,
    pub name: &'static str,
    pub player_index: u32,
    pub recipe: LuaRecipe,
    pub tick: u32,
}
Called when the player finishes crafting an item. This event fires just before the results are inserted into the player’s inventory, not when the crafting is queued (see on_pre_player_crafted_item).

Fields

item_stack: LuaItemStackname: &'static strplayer_index: u32recipe: LuaRecipetick: u32