pub struct OnPlayerDisplayDensityScaleChangedEvent {
pub name: &'static str,
pub old_scale: f64,
pub player_index: u32,
pub tick: u32,
}Expand description
Called when the display density scale changes for a given player. The display density scale is the scale value automatically applied based on the player’s display DPI. This is only relevant on platforms that support high-density displays.
Fields
name: &'static strold_scale: f64player_index: u32tick: u32Trait Implementations
Sourceimpl Clone for OnPlayerDisplayDensityScaleChangedEvent
impl Clone for OnPlayerDisplayDensityScaleChangedEvent
Sourcefn clone(&self) -> OnPlayerDisplayDensityScaleChangedEvent
fn clone(&self) -> OnPlayerDisplayDensityScaleChangedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnPlayerDisplayDensityScaleChangedEvent
Sourceimpl Default for OnPlayerDisplayDensityScaleChangedEvent
impl Default for OnPlayerDisplayDensityScaleChangedEvent
Sourcefn default() -> OnPlayerDisplayDensityScaleChangedEvent
fn default() -> OnPlayerDisplayDensityScaleChangedEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnPlayerDisplayDensityScaleChangedEvent