pub struct OnPlayerDrivingChangedStateEvent {
pub entity: LuaEntity,
pub name: &'static str,
pub player_index: u32,
pub tick: u32,
}Expand description
Called when the player’s driving state has changed, meaning a player has either entered or left a vehicle.
This event is not raised when the player is ejected from a vehicle due to it being destroyed.
Fields
entity: LuaEntityname: &'static strplayer_index: u32tick: u32Trait Implementations
Sourceimpl Clone for OnPlayerDrivingChangedStateEvent
impl Clone for OnPlayerDrivingChangedStateEvent
Sourcefn clone(&self) -> OnPlayerDrivingChangedStateEvent
fn clone(&self) -> OnPlayerDrivingChangedStateEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnPlayerDrivingChangedStateEvent
Sourceimpl Default for OnPlayerDrivingChangedStateEvent
impl Default for OnPlayerDrivingChangedStateEvent
Sourcefn default() -> OnPlayerDrivingChangedStateEvent
fn default() -> OnPlayerDrivingChangedStateEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnPlayerDrivingChangedStateEvent