OnPlayerFlippedEntityEvent

Struct OnPlayerFlippedEntityEvent 

pub struct OnPlayerFlippedEntityEvent {
    pub entity: LuaEntity,
    pub horizontal: bool,
    pub name: &'static str,
    pub player_index: u32,
    pub tick: u32,
}
Called when the player flips an entity. This event is only fired when the entity actually changes its orientation or mirroring, so it won’t be triggered when pressing the flip keys on an entity that can’t be flipped.

This event reflects a change in the LuaEntity::mirroring property.

Fields

entity: LuaEntityhorizontal: boolname: &'static strplayer_index: u32tick: u32