pub struct OnPlayerJoinedGameEvent {
pub name: &'static str,
pub player_index: u32,
pub tick: u32,
}Expand description
Called after a player joins the game. This is not called when loading a save file in singleplayer, as the player doesn’t actually leave the game, and the save is just on pause until they rejoin.
Fields
name: &'static strplayer_index: u32tick: u32Trait Implementations
Sourceimpl Clone for OnPlayerJoinedGameEvent
impl Clone for OnPlayerJoinedGameEvent
Sourcefn clone(&self) -> OnPlayerJoinedGameEvent
fn clone(&self) -> OnPlayerJoinedGameEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnPlayerJoinedGameEvent
Sourceimpl Debug for OnPlayerJoinedGameEvent
impl Debug for OnPlayerJoinedGameEvent
Sourceimpl Default for OnPlayerJoinedGameEvent
impl Default for OnPlayerJoinedGameEvent
Sourcefn default() -> OnPlayerJoinedGameEvent
fn default() -> OnPlayerJoinedGameEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnPlayerJoinedGameEvent
impl PartialEq for OnPlayerJoinedGameEvent
impl StructuralPartialEq for OnPlayerJoinedGameEvent