pub struct OnPlayerLeftGameEvent {
pub name: &'static str,
pub player_index: u32,
pub reason: &'static str,
pub tick: u32,
}Expand description
Called after a player leaves the game. This is not called when closing a save file in singleplayer, as the player doesn’t actually leave the game, and the save is just on pause until they rejoin.
Fields
name: &'static strplayer_index: u32reason: &'static strtick: u32Trait Implementations
Sourceimpl Clone for OnPlayerLeftGameEvent
impl Clone for OnPlayerLeftGameEvent
Sourcefn clone(&self) -> OnPlayerLeftGameEvent
fn clone(&self) -> OnPlayerLeftGameEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnPlayerLeftGameEvent
Sourceimpl Debug for OnPlayerLeftGameEvent
impl Debug for OnPlayerLeftGameEvent
Sourceimpl Default for OnPlayerLeftGameEvent
impl Default for OnPlayerLeftGameEvent
Sourcefn default() -> OnPlayerLeftGameEvent
fn default() -> OnPlayerLeftGameEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnPlayerLeftGameEvent
impl PartialEq for OnPlayerLeftGameEvent
impl StructuralPartialEq for OnPlayerLeftGameEvent