pub struct OnPlayerMinedEntityEvent {
pub buffer: LuaInventory,
pub entity: LuaEntity,
pub name: &'static str,
pub player_index: u32,
pub tick: u32,
}Expand description
Called after the results of an entity being mined are collected just before the entity is destroyed.
After this event any items in the buffer will be transferred into the player as if they came from mining the entity.
The buffer inventory is special in that it’s only valid during this event and has a dynamic size expanding as more items are transferred into it.
Fields
buffer: LuaInventoryentity: LuaEntityname: &'static strplayer_index: u32tick: u32Trait Implementations
Sourceimpl Clone for OnPlayerMinedEntityEvent
impl Clone for OnPlayerMinedEntityEvent
Sourcefn clone(&self) -> OnPlayerMinedEntityEvent
fn clone(&self) -> OnPlayerMinedEntityEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnPlayerMinedEntityEvent
Sourceimpl Debug for OnPlayerMinedEntityEvent
impl Debug for OnPlayerMinedEntityEvent
Sourceimpl Default for OnPlayerMinedEntityEvent
impl Default for OnPlayerMinedEntityEvent
Sourcefn default() -> OnPlayerMinedEntityEvent
fn default() -> OnPlayerMinedEntityEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnPlayerMinedEntityEvent
impl PartialEq for OnPlayerMinedEntityEvent
impl StructuralPartialEq for OnPlayerMinedEntityEvent