pub struct OnPlayerRemovedEvent {
pub name: &'static str,
pub player_index: u32,
pub tick: u32,
}Expand description
Called when a player is removed (deleted) from the game. This is markedly different from a player temporarily leaving the game, and instead behaves like the player never existed in the save file.
Fields
name: &'static strplayer_index: u32tick: u32Trait Implementations
Sourceimpl Clone for OnPlayerRemovedEvent
impl Clone for OnPlayerRemovedEvent
Sourcefn clone(&self) -> OnPlayerRemovedEvent
fn clone(&self) -> OnPlayerRemovedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnPlayerRemovedEvent
Sourceimpl Debug for OnPlayerRemovedEvent
impl Debug for OnPlayerRemovedEvent
Sourceimpl Default for OnPlayerRemovedEvent
impl Default for OnPlayerRemovedEvent
Sourcefn default() -> OnPlayerRemovedEvent
fn default() -> OnPlayerRemovedEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnPlayerRemovedEvent
impl PartialEq for OnPlayerRemovedEvent
impl StructuralPartialEq for OnPlayerRemovedEvent