pub struct OnPlayerRotatedEntityEvent {
pub entity: LuaEntity,
pub name: &'static str,
pub player_index: u32,
pub previous_direction: &'static str,
pub previous_mirroring: bool,
pub tick: u32,
}Expand description
Called when the player rotates an entity. This event is only fired when the entity actually changes its orientation – pressing the rotate key on an entity that can’t be rotated won’t fire this event.
Entities being flipped will not fire this event, even if the flip involves rotating. See on_player_flipped_entity.
Fields
entity: LuaEntityname: &'static strplayer_index: u32previous_direction: &'static strprevious_mirroring: booltick: u32Trait Implementations
Sourceimpl Clone for OnPlayerRotatedEntityEvent
impl Clone for OnPlayerRotatedEntityEvent
Sourcefn clone(&self) -> OnPlayerRotatedEntityEvent
fn clone(&self) -> OnPlayerRotatedEntityEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnPlayerRotatedEntityEvent
Sourceimpl Debug for OnPlayerRotatedEntityEvent
impl Debug for OnPlayerRotatedEntityEvent
Sourceimpl Default for OnPlayerRotatedEntityEvent
impl Default for OnPlayerRotatedEntityEvent
Sourcefn default() -> OnPlayerRotatedEntityEvent
fn default() -> OnPlayerRotatedEntityEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnPlayerRotatedEntityEvent