pub struct OnPreGhostDeconstructedEvent {
pub ghost: LuaEntity,
pub name: &'static str,
pub player_index: u32,
pub tick: u32,
}Expand description
Called before a ghost entity is destroyed as a result of being marked for deconstruction.
Also called for item request proxies before they are destroyed as a result of being marked for deconstruction.
Fields
ghost: LuaEntityname: &'static strplayer_index: u32tick: u32Trait Implementations
Sourceimpl Clone for OnPreGhostDeconstructedEvent
impl Clone for OnPreGhostDeconstructedEvent
Sourcefn clone(&self) -> OnPreGhostDeconstructedEvent
fn clone(&self) -> OnPreGhostDeconstructedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnPreGhostDeconstructedEvent
Sourceimpl Debug for OnPreGhostDeconstructedEvent
impl Debug for OnPreGhostDeconstructedEvent
Sourceimpl Default for OnPreGhostDeconstructedEvent
impl Default for OnPreGhostDeconstructedEvent
Sourcefn default() -> OnPreGhostDeconstructedEvent
fn default() -> OnPreGhostDeconstructedEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnPreGhostDeconstructedEvent