pub struct OnPrePlayerRemovedEvent {
pub name: &'static str,
pub player_index: u32,
pub tick: u32,
}Expand description
Called before a player is removed (deleted) from the game. This is markedly different from a player temporarily leaving the game, and instead behaves like the player never existed in the save file.
Fields
name: &'static strplayer_index: u32tick: u32Trait Implementations
Sourceimpl Clone for OnPrePlayerRemovedEvent
impl Clone for OnPrePlayerRemovedEvent
Sourcefn clone(&self) -> OnPrePlayerRemovedEvent
fn clone(&self) -> OnPrePlayerRemovedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnPrePlayerRemovedEvent
Sourceimpl Debug for OnPrePlayerRemovedEvent
impl Debug for OnPrePlayerRemovedEvent
Sourceimpl Default for OnPrePlayerRemovedEvent
impl Default for OnPrePlayerRemovedEvent
Sourcefn default() -> OnPrePlayerRemovedEvent
fn default() -> OnPrePlayerRemovedEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnPrePlayerRemovedEvent
impl PartialEq for OnPrePlayerRemovedEvent
impl StructuralPartialEq for OnPrePlayerRemovedEvent