pub struct OnRobotMinedEntityEvent {
pub buffer: LuaInventory,
pub entity: LuaEntity,
pub name: &'static str,
pub robot: LuaEntity,
pub tick: u32,
}Expand description
Called after the results of an entity being mined are collected just before the entity is destroyed.
After this event any items in the buffer will be transferred into the robot as if they came from mining the entity.
The buffer inventory is special in that it’s only valid during this event and has a dynamic size expanding as more items are transferred into it.
Fields
buffer: LuaInventoryentity: LuaEntityname: &'static strrobot: LuaEntitytick: u32Trait Implementations
Sourceimpl Clone for OnRobotMinedEntityEvent
impl Clone for OnRobotMinedEntityEvent
Sourcefn clone(&self) -> OnRobotMinedEntityEvent
fn clone(&self) -> OnRobotMinedEntityEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnRobotMinedEntityEvent
Sourceimpl Debug for OnRobotMinedEntityEvent
impl Debug for OnRobotMinedEntityEvent
Sourceimpl Default for OnRobotMinedEntityEvent
impl Default for OnRobotMinedEntityEvent
Sourcefn default() -> OnRobotMinedEntityEvent
fn default() -> OnRobotMinedEntityEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnRobotMinedEntityEvent
impl PartialEq for OnRobotMinedEntityEvent
impl StructuralPartialEq for OnRobotMinedEntityEvent