pub struct OnSingleplayerInitEvent {
pub name: &'static str,
pub tick: u32,
}Expand description
Called when LuaGameScript::is_multiplayer changes to false. May also be raised when it was already false but a game was loaded from a save file without hosting.
Fields
name: &'static strtick: u32Trait Implementations
Sourceimpl Clone for OnSingleplayerInitEvent
impl Clone for OnSingleplayerInitEvent
Sourcefn clone(&self) -> OnSingleplayerInitEvent
fn clone(&self) -> OnSingleplayerInitEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnSingleplayerInitEvent
Sourceimpl Debug for OnSingleplayerInitEvent
impl Debug for OnSingleplayerInitEvent
Sourceimpl Default for OnSingleplayerInitEvent
impl Default for OnSingleplayerInitEvent
Sourcefn default() -> OnSingleplayerInitEvent
fn default() -> OnSingleplayerInitEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnSingleplayerInitEvent
impl PartialEq for OnSingleplayerInitEvent
impl StructuralPartialEq for OnSingleplayerInitEvent