pub struct OnSpacePlatformMinedEntityEvent {
pub buffer: LuaInventory,
pub entity: LuaEntity,
pub name: &'static str,
pub platform: LuaSpacePlatform,
pub tick: u32,
}Expand description
Called after the results of an entity being mined are collected just before the entity is destroyed.
After this event any items in the buffer will be transferred into the platform as if they came from mining the entity.
The buffer inventory is special in that it’s only valid during this event and has a dynamic size expanding as more items are transferred into it.
Fields
buffer: LuaInventoryentity: LuaEntityname: &'static strplatform: LuaSpacePlatformtick: u32Trait Implementations
Sourceimpl Clone for OnSpacePlatformMinedEntityEvent
impl Clone for OnSpacePlatformMinedEntityEvent
Sourcefn clone(&self) -> OnSpacePlatformMinedEntityEvent
fn clone(&self) -> OnSpacePlatformMinedEntityEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnSpacePlatformMinedEntityEvent
Sourceimpl Default for OnSpacePlatformMinedEntityEvent
impl Default for OnSpacePlatformMinedEntityEvent
Sourcefn default() -> OnSpacePlatformMinedEntityEvent
fn default() -> OnSpacePlatformMinedEntityEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnSpacePlatformMinedEntityEvent