OnTowerMinedPlantEvent

Struct OnTowerMinedPlantEvent 

pub struct OnTowerMinedPlantEvent {
    pub buffer: LuaInventory,
    pub name: &'static str,
    pub plant: LuaEntity,
    pub tick: u32,
    pub tower: LuaEntity,
}
Called after the results of an entity being mined are collected just before the entity is destroyed.

After this event any items in the buffer will be transferred into the tower as if they came from mining the entity.

The buffer inventory is special in that it’s only valid during this event and has a dynamic size expanding as more items are transferred into it.

Fields

buffer: LuaInventoryname: &'static strplant: LuaEntitytick: u32tower: LuaEntity