pub struct OnTrainCreatedEvent {
pub name: &'static str,
pub old_train_id_1: u32,
pub old_train_id_2: u32,
pub tick: u32,
pub train: LuaTrain,
}Expand description
Called when a new train is created either through disconnecting/connecting an existing one or building a new one.
Fields
name: &'static strold_train_id_1: u32old_train_id_2: u32tick: u32train: LuaTrainTrait Implementations
Sourceimpl Clone for OnTrainCreatedEvent
impl Clone for OnTrainCreatedEvent
Sourcefn clone(&self) -> OnTrainCreatedEvent
fn clone(&self) -> OnTrainCreatedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnTrainCreatedEvent
Sourceimpl Debug for OnTrainCreatedEvent
impl Debug for OnTrainCreatedEvent
Sourceimpl Default for OnTrainCreatedEvent
impl Default for OnTrainCreatedEvent
Sourcefn default() -> OnTrainCreatedEvent
fn default() -> OnTrainCreatedEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnTrainCreatedEvent
impl PartialEq for OnTrainCreatedEvent
impl StructuralPartialEq for OnTrainCreatedEvent