pub struct ScriptRaisedDestroyEvent {
pub entity: LuaEntity,
pub name: &'static str,
pub tick: u32,
}Expand description
A static event mods can use to tell other mods they destroyed something by script. This event is only raised if a mod does so with LuaBootstrap::raise_event or LuaBootstrap::raise_script_destroy, or when raise_destroy is passed to LuaEntity::destroy.
Fields
entity: LuaEntityname: &'static strtick: u32Trait Implementations
Sourceimpl Clone for ScriptRaisedDestroyEvent
impl Clone for ScriptRaisedDestroyEvent
Sourcefn clone(&self) -> ScriptRaisedDestroyEvent
fn clone(&self) -> ScriptRaisedDestroyEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ScriptRaisedDestroyEvent
Sourceimpl Debug for ScriptRaisedDestroyEvent
impl Debug for ScriptRaisedDestroyEvent
Sourceimpl Default for ScriptRaisedDestroyEvent
impl Default for ScriptRaisedDestroyEvent
Sourcefn default() -> ScriptRaisedDestroyEvent
fn default() -> ScriptRaisedDestroyEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ScriptRaisedDestroyEvent
impl PartialEq for ScriptRaisedDestroyEvent
impl StructuralPartialEq for ScriptRaisedDestroyEvent