pub struct ScriptRaisedDestroySegmentedUnitEvent {
pub name: &'static str,
pub segmented_unit: LuaSegmentedUnit,
pub tick: u32,
}Expand description
A static event that mods can use to tell other mods they destroyed a segmented unit by script. This event is only raised if a mod does so with LuaBootstrap::raise_event, or LuaBootstrap::raise_script_destroy_segmented_unit, or when raise_destroy is passed to LuaSegmentedUnit::destroy.
Fields
name: &'static strsegmented_unit: LuaSegmentedUnittick: u32Trait Implementations
Sourceimpl Clone for ScriptRaisedDestroySegmentedUnitEvent
impl Clone for ScriptRaisedDestroySegmentedUnitEvent
Sourcefn clone(&self) -> ScriptRaisedDestroySegmentedUnitEvent
fn clone(&self) -> ScriptRaisedDestroySegmentedUnitEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ScriptRaisedDestroySegmentedUnitEvent
Sourceimpl Default for ScriptRaisedDestroySegmentedUnitEvent
impl Default for ScriptRaisedDestroySegmentedUnitEvent
Sourcefn default() -> ScriptRaisedDestroySegmentedUnitEvent
fn default() -> ScriptRaisedDestroySegmentedUnitEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ScriptRaisedDestroySegmentedUnitEvent