pub struct ScriptRaisedSetTilesEvent {
pub name: &'static str,
pub surface_index: u32,
pub tick: u32,
pub tiles: &'static [LuaAny],
}Expand description
A static event mods can use to tell other mods they changed tiles on a surface by script. This event is only raised if a mod does so with LuaBootstrap::raise_event or LuaBootstrap::raise_script_set_tiles, or when raise_event is passed to LuaSurface::set_tiles.
Fields
name: &'static strsurface_index: u32tick: u32tiles: &'static [LuaAny]Trait Implementations
Sourceimpl Clone for ScriptRaisedSetTilesEvent
impl Clone for ScriptRaisedSetTilesEvent
Sourcefn clone(&self) -> ScriptRaisedSetTilesEvent
fn clone(&self) -> ScriptRaisedSetTilesEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ScriptRaisedSetTilesEvent
Sourceimpl Debug for ScriptRaisedSetTilesEvent
impl Debug for ScriptRaisedSetTilesEvent
Sourceimpl Default for ScriptRaisedSetTilesEvent
impl Default for ScriptRaisedSetTilesEvent
Sourcefn default() -> ScriptRaisedSetTilesEvent
fn default() -> ScriptRaisedSetTilesEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ScriptRaisedSetTilesEvent