pub struct ScriptRaisedTeleportedEvent {
pub entity: LuaEntity,
pub name: &'static str,
pub old_position: LuaAny,
pub old_surface_index: u8,
pub tick: u32,
}Expand description
A static event mods can use to tell other mods they teleported something by script. This event is only raised if a mod does so with LuaBootstrap::raise_event or LuaBootstrap::raise_script_teleported, or when raise_teleported is passed to LuaControl::teleport.
Fields
entity: LuaEntityname: &'static strold_position: LuaAnyold_surface_index: u8tick: u32Trait Implementations
Sourceimpl Clone for ScriptRaisedTeleportedEvent
impl Clone for ScriptRaisedTeleportedEvent
Sourcefn clone(&self) -> ScriptRaisedTeleportedEvent
fn clone(&self) -> ScriptRaisedTeleportedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ScriptRaisedTeleportedEvent
Sourceimpl Debug for ScriptRaisedTeleportedEvent
impl Debug for ScriptRaisedTeleportedEvent
Sourceimpl Default for ScriptRaisedTeleportedEvent
impl Default for ScriptRaisedTeleportedEvent
Sourcefn default() -> ScriptRaisedTeleportedEvent
fn default() -> ScriptRaisedTeleportedEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ScriptRaisedTeleportedEvent