OnBiterBaseBuilt

Struct OnBiterBaseBuilt 

pub struct OnBiterBaseBuilt;
Called when a biter migration builds a base.

This will be called multiple times for each migration, once for every biter that is sacrificed to build part of the new base.

Implementations

Source

impl OnBiterBaseBuilt

pub const NAME: &'static str = "on_biter_base_built"