pub struct OnConsoleChat;Expand description
Called when a message is sent to the in-game console, either by a player or through the server interface.
This event only fires for plain messages, not for any commands (including /shout or /whisper).
Implementations