pub struct OnCutsceneWaypointReached;Expand description
Called when a cutscene is playing, each time it reaches a waypoint in that cutscene.
This refers to an index in the table previously passed to set_controller which started the cutscene.
Implementations