pub struct OnEntityColorChanged;Expand description
Called after an entity has been recolored either by the player or through script.
Automatic recoloring due to LuaPlayer::color will not raise events, as that is a separate mechanism.
Implementations