pub struct OnForceCreated;Expand description
Called when a new force is created using game.create_force()
This is not called when the default forces ('player', 'enemy', 'neutral') are created as they will always exist.
Implementations