pub struct OnGameCreatedFromScenario;Expand description
Called when a game is created from a scenario. This is fired for every mod, even when the scenario’s save data already includes it. In those cases however, LuaBootstrap::on_init is not fired.
This event is not fired when the scenario is loaded via the map editor.
Implementations