pub struct OnGuiClosed;Expand description
Called when the player closes the GUI they have open.
This can only be raised when the GUI’s player controller is still valid. If a GUI is thus closed due to the player disconnecting, dying, or becoming a spectator in other ways, it won’t cause this event to be raised.
It’s not advised to open any other GUI during this event because if this is run as a request to open a different GUI the game will force close the new opened GUI without notice to ensure the original requested GUI is opened.
Implementations