pub struct OnPlayerDisplayDensityScaleChanged;Expand description
Called when the display density scale changes for a given player. The display density scale is the scale value automatically applied based on the player’s display DPI. This is only relevant on platforms that support high-density displays.
Implementations