pub struct OnPlayerDrivingChangedState;Expand description
Called when the player’s driving state has changed, meaning a player has either entered or left a vehicle.
This event is not raised when the player is ejected from a vehicle due to it being destroyed.
Implementations