OnPlayerFlippedEntity

Struct OnPlayerFlippedEntity 

pub struct OnPlayerFlippedEntity;
Called when the player flips an entity. This event is only fired when the entity actually changes its orientation or mirroring, so it won’t be triggered when pressing the flip keys on an entity that can’t be flipped.

This event reflects a change in the LuaEntity::mirroring property.

Implementations

Source

impl OnPlayerFlippedEntity

pub const NAME: &'static str = "on_player_flipped_entity"