pub struct OnPlayerJoinedGame;Expand description
Called after a player joins the game. This is not called when loading a save file in singleplayer, as the player doesn’t actually leave the game, and the save is just on pause until they rejoin.
Implementations