pub struct OnPlayerLeftGame;Expand description
Called after a player leaves the game. This is not called when closing a save file in singleplayer, as the player doesn’t actually leave the game, and the save is just on pause until they rejoin.
Implementations