OnPlayerMinedEntity

Struct OnPlayerMinedEntity 

pub struct OnPlayerMinedEntity;
Called after the results of an entity being mined are collected just before the entity is destroyed.

After this event any items in the buffer will be transferred into the player as if they came from mining the entity.

The buffer inventory is special in that it’s only valid during this event and has a dynamic size expanding as more items are transferred into it.

Implementations

Source

impl OnPlayerMinedEntity

pub const NAME: &'static str = "on_player_mined_entity"