pub struct OnPlayerRemoved;Expand description
Called when a player is removed (deleted) from the game. This is markedly different from a player temporarily leaving the game, and instead behaves like the player never existed in the save file.
Implementations