OnPlayerRotatedEntity

Struct OnPlayerRotatedEntity 

pub struct OnPlayerRotatedEntity;
Called when the player rotates an entity. This event is only fired when the entity actually changes its orientation – pressing the rotate key on an entity that can’t be rotated won’t fire this event.

Entities being flipped will not fire this event, even if the flip involves rotating. See on_player_flipped_entity.

Implementations

Source

impl OnPlayerRotatedEntity

pub const NAME: &'static str = "on_player_rotated_entity"