pub struct OnPreGhostDeconstructed;Expand description
Called before a ghost entity is destroyed as a result of being marked for deconstruction.
Also called for item request proxies before they are destroyed as a result of being marked for deconstruction.
Implementations