OnPrePlayerMinedItem

Struct OnPrePlayerMinedItem 

pub struct OnPrePlayerMinedItem;
Called when the player completes a mining action, but before the entity is potentially removed from the map. This is called even if the entity does not end up being removed.

Implementations

Source

impl OnPrePlayerMinedItem

pub const NAME: &'static str = "on_pre_player_mined_item"