pub struct OnSingleplayerInit;Expand description
Called when LuaGameScript::is_multiplayer changes to false. May also be raised when it was already false but a game was loaded from a save file without hosting.
Implementations