OnSpacePlatformMinedEntity

Struct OnSpacePlatformMinedEntity 

pub struct OnSpacePlatformMinedEntity;
Called after the results of an entity being mined are collected just before the entity is destroyed.

After this event any items in the buffer will be transferred into the platform as if they came from mining the entity.

The buffer inventory is special in that it’s only valid during this event and has a dynamic size expanding as more items are transferred into it.

Implementations

Source

impl OnSpacePlatformMinedEntity

pub const NAME: &'static str = "on_space_platform_mined_entity"