pub struct ScriptRaisedDestroySegmentedUnit;Expand description
A static event that mods can use to tell other mods they destroyed a segmented unit by script. This event is only raised if a mod does so with LuaBootstrap::raise_event, or LuaBootstrap::raise_script_destroy_segmented_unit, or when raise_destroy is passed to LuaSegmentedUnit::destroy.
Implementations