pub struct ScriptRaisedRevive;Expand description
A static event mods can use to tell other mods they revived something by script. This event is only raised if a mod does so with LuaBootstrap::raise_event or LuaBootstrap::raise_script_revive, or when raise_revive is passed to LuaEntity::revive.
Implementations