AutoplaceControl

Struct AutoplaceControl 

pub struct AutoplaceControl {
Show 14 fields pub name: &'static str, pub category: &'static str, pub hidden: Option<bool>, pub order: Option<&'static str>, pub subgroup: Option<&'static str>, pub factoriopedia_description: Option<&'static str>, pub hidden_in_factoriopedia: Option<bool>, pub localised_description: Option<&'static str>, pub localised_name: Option<&'static str>, pub parameter: Option<bool>, pub factoriopedia_alternative: Option<&'static str>, pub can_be_disabled: Option<bool>, pub related_to_fight_achievements: Option<bool>, pub richness: Option<bool>,
}
Minimal AutoplaceControl for data.extend.

A setting in the map creation GUI. Used by the autoplace system.

type = "autoplace-control" is injected by the Lua generator.

Fields

name: &'static str

Unique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.

For a list of all names used in vanilla, see data.raw.

category: &'static str

Controls in what tab the autoplace is shown in the map generator GUI.

hidden: Option<bool>

Prototype property hidden.

order: Option<&'static str>

Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.

subgroup: Option<&'static str>

The name of an ItemSubGroup.

factoriopedia_description: Option<&'static str>

Provides additional description used in factoriopedia.

hidden_in_factoriopedia: Option<bool>

Prototype property hidden_in_factoriopedia.

localised_description: Option<&'static str>

Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.

localised_name: Option<&'static str>

Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.

parameter: Option<bool>

Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.

factoriopedia_alternative: Option<&'static str>

The ID type corresponding to the prototype that inherits from this.

For example, if this is an EntityPrototype, this property’s type is EntityID.

can_be_disabled: Option<bool>

Whether there is an “enable” checkbox for the autoplace control in the map generator GUI. If this is false, the autoplace control cannot be disabled from the GUI.

related_to_fight_achievements: Option<bool>

Whether this settings being lower than default disables fight related achievements.

richness: Option<bool>

Sets whether this control’s richness can be changed. The map generator GUI will only show the richness slider when the category is "resource".

If the autoplace control is used to generate ores, you probably want this to be true.