pub struct BurnerUsage {Show 17 fields
pub name: &'static str,
pub accepted_fuel_key: &'static str,
pub burned_in_key: &'static str,
pub empty_slot_caption: &'static str,
pub empty_slot_sprite: LuaAny,
pub icon: LuaAny,
pub hidden: Option<bool>,
pub order: Option<&'static str>,
pub subgroup: Option<&'static str>,
pub factoriopedia_description: Option<&'static str>,
pub hidden_in_factoriopedia: Option<bool>,
pub localised_description: Option<&'static str>,
pub localised_name: Option<&'static str>,
pub parameter: Option<bool>,
pub factoriopedia_alternative: Option<&'static str>,
pub empty_slot_description: Option<&'static str>,
pub no_fuel_status: Option<&'static str>,
}Expand description
Minimal BurnerUsagePrototype for data.extend.
Set of data affecting tooltips, looks of gui slots etc when burner is not supposed to be burning items but eating them.
type = "burner-usage" is injected by the Lua generator.
Fields
name: &'static strUnique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.
For a list of all names used in vanilla, see data.raw.
accepted_fuel_key: &'static strPrototype property accepted_fuel_key.
burned_in_key: &'static strPrototype property burned_in_key.
empty_slot_caption: &'static strPrototype property empty_slot_caption.
empty_slot_sprite: LuaAnyPrototype property empty_slot_sprite.
icon: LuaAnyPrototype property icon.
Prototype property hidden.
order: Option<&'static str>Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.
subgroup: Option<&'static str>The name of an ItemSubGroup.
factoriopedia_description: Option<&'static str>Provides additional description used in factoriopedia.
Prototype property hidden_in_factoriopedia.
localised_description: Option<&'static str>Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.
localised_name: Option<&'static str>Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.
parameter: Option<bool>Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.
factoriopedia_alternative: Option<&'static str>The ID type corresponding to the prototype that inherits from this.
For example, if this is an EntityPrototype, this property’s type is EntityID.
empty_slot_description: Option<&'static str>Prototype property empty_slot_description.
no_fuel_status: Option<&'static str>Prototype property no_fuel_status.