pub struct ChainActiveTrigger {Show 18 fields
pub name: &'static str,
pub hidden: Option<bool>,
pub order: Option<&'static str>,
pub subgroup: Option<&'static str>,
pub factoriopedia_description: Option<&'static str>,
pub hidden_in_factoriopedia: Option<bool>,
pub localised_description: Option<&'static str>,
pub localised_name: Option<&'static str>,
pub parameter: Option<bool>,
pub factoriopedia_alternative: Option<&'static str>,
pub fork_chance: Option<f64>,
pub fork_chance_increase_per_quality_level: Option<f64>,
pub jump_delay_ticks: Option<i64>,
pub max_forks: Option<i64>,
pub max_forks_per_jump: Option<i64>,
pub max_jumps: Option<i64>,
pub max_range: Option<f64>,
pub max_range_per_jump: Option<f64>,
}Expand description
Minimal ChainActiveTriggerPrototype for data.extend.
Jumps between targets and applies a Trigger to them.
type = "chain-active-trigger" is injected by the Lua generator.
Fields
name: &'static strUnique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.
For a list of all names used in vanilla, see data.raw.
Prototype property hidden.
order: Option<&'static str>Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.
subgroup: Option<&'static str>The name of an ItemSubGroup.
factoriopedia_description: Option<&'static str>Provides additional description used in factoriopedia.
Prototype property hidden_in_factoriopedia.
localised_description: Option<&'static str>Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.
localised_name: Option<&'static str>Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.
parameter: Option<bool>Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.
factoriopedia_alternative: Option<&'static str>The ID type corresponding to the prototype that inherits from this.
For example, if this is an EntityPrototype, this property’s type is EntityID.
fork_chance: Option<f64>Chance that a new fork will spawn after each jump. 0 for 0% chance and 1 for 100% chance.
Must be between 0 and 1.
fork_chance_increase_per_quality_level: Option<f64>Prototype property fork_chance_increase_per_quality_level.
jump_delay_ticks: Option<i64>Tick delay between each jump. 0 means that all jumps are instantaneous.
max_forks: Option<i64>Maximum number of forks allowed to spawn for the entire chain.
max_forks_per_jump: Option<i64>Maximum number of forks that can spawn from a single jump.
max_jumps: Option<i64>Max number of jumps per trigger.
max_range: Option<f64>Max distance jumps are allowed to travel away from the original target.
max_range_per_jump: Option<f64>Max length of jumps.