CustomEvent

Struct CustomEvent 

pub struct CustomEvent {
    pub name: &'static str,
    pub hidden: Option<bool>,
    pub order: Option<&'static str>,
    pub subgroup: Option<&'static str>,
    pub factoriopedia_description: Option<&'static str>,
    pub hidden_in_factoriopedia: Option<bool>,
    pub localised_description: Option<&'static str>,
    pub localised_name: Option<&'static str>,
    pub parameter: Option<bool>,
    pub factoriopedia_alternative: Option<&'static str>,
}
Minimal CustomEventPrototype for data.extend.

Custom events share the same namespace as custom inputs and built-in events for subscribing to and raising them.

type = "custom-event" is injected by the Lua generator.

Fields

name: &'static str

Unique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.

For a list of all names used in vanilla, see data.raw.

hidden: Option<bool>

Prototype property hidden.

order: Option<&'static str>

Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.

subgroup: Option<&'static str>

The name of an ItemSubGroup.

factoriopedia_description: Option<&'static str>

Provides additional description used in factoriopedia.

hidden_in_factoriopedia: Option<bool>

Prototype property hidden_in_factoriopedia.

localised_description: Option<&'static str>

Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.

localised_name: Option<&'static str>

Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.

parameter: Option<bool>

Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.

factoriopedia_alternative: Option<&'static str>

The ID type corresponding to the prototype that inherits from this.

For example, if this is an EntityPrototype, this property’s type is EntityID.