pub struct DelayedActiveTrigger {Show 15 fields
pub name: &'static str,
pub delay: i64,
pub action: LuaAny,
pub hidden: Option<bool>,
pub order: Option<&'static str>,
pub subgroup: Option<&'static str>,
pub factoriopedia_description: Option<&'static str>,
pub hidden_in_factoriopedia: Option<bool>,
pub localised_description: Option<&'static str>,
pub localised_name: Option<&'static str>,
pub parameter: Option<bool>,
pub factoriopedia_alternative: Option<&'static str>,
pub cancel_when_source_is_destroyed: Option<bool>,
pub repeat_count: Option<i64>,
pub repeat_delay: Option<i64>,
}Expand description
Minimal DelayedActiveTriggerPrototype for data.extend.
Delays the delivery of triggered effect by some number of ticks.
type = "delayed-active-trigger" is injected by the Lua generator.
Fields
name: &'static strUnique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.
For a list of all names used in vanilla, see data.raw.
delay: i64The number of ticks to delay the delivery of the triggered effect. Must be greater than 0.
action: LuaAnyThe trigger to apply after delay has elapsed.
Prototype property hidden.
order: Option<&'static str>Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.
subgroup: Option<&'static str>The name of an ItemSubGroup.
factoriopedia_description: Option<&'static str>Provides additional description used in factoriopedia.
Prototype property hidden_in_factoriopedia.
localised_description: Option<&'static str>Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.
localised_name: Option<&'static str>Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.
parameter: Option<bool>Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.
factoriopedia_alternative: Option<&'static str>The ID type corresponding to the prototype that inherits from this.
For example, if this is an EntityPrototype, this property’s type is EntityID.
cancel_when_source_is_destroyed: Option<bool>If true, the delayed trigger is cancelled if the source entity is destroyed.
repeat_count: Option<i64>The number of times to repeat the delayed trigger.
repeat_delay: Option<i64>The number of ticks between repeat deliveries of the triggered effect. Must be greater than 0.