EquipmentGrid

Struct EquipmentGrid 

pub struct EquipmentGrid {
Show 14 fields pub name: &'static str, pub equipment_categories: &'static [&'static str], pub height: i64, pub width: i64, pub hidden: Option<bool>, pub order: Option<&'static str>, pub subgroup: Option<&'static str>, pub factoriopedia_description: Option<&'static str>, pub hidden_in_factoriopedia: Option<bool>, pub localised_description: Option<&'static str>, pub localised_name: Option<&'static str>, pub parameter: Option<bool>, pub factoriopedia_alternative: Option<&'static str>, pub locked: Option<bool>,
}
Minimal EquipmentGridPrototype for data.extend.

The prototype of an equipment grid, for example the one used in a power armor.

type = "equipment-grid" is injected by the Lua generator.

Fields

name: &'static str

Unique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.

For a list of all names used in vanilla, see data.raw.

equipment_categories: &'static [&'static str]

Only equipment with at least one of these categories can be inserted into the grid.

height: i64

Prototype property height.

width: i64

Prototype property width.

hidden: Option<bool>

Prototype property hidden.

order: Option<&'static str>

Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.

subgroup: Option<&'static str>

The name of an ItemSubGroup.

factoriopedia_description: Option<&'static str>

Provides additional description used in factoriopedia.

hidden_in_factoriopedia: Option<bool>

Prototype property hidden_in_factoriopedia.

localised_description: Option<&'static str>

Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.

localised_name: Option<&'static str>

Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.

parameter: Option<bool>

Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.

factoriopedia_alternative: Option<&'static str>

The ID type corresponding to the prototype that inherits from this.

For example, if this is an EntityPrototype, this property’s type is EntityID.

locked: Option<bool>

Whether this locked from user interaction which means that the user cannot put equipment into or take equipment from this equipment grid.