pub struct GodController {
pub inventory_size: i64,
pub item_pickup_distance: f64,
pub loot_pickup_distance: f64,
pub mining_speed: f64,
pub movement_speed: f64,
pub name: &'static str,
pub crafting_categories: Option<&'static [&'static str]>,
pub mining_categories: Option<&'static [&'static str]>,
}Expand description
Minimal GodControllerPrototype for data.extend.
Properties of the god controller.
type = "god-controller" is injected by the Lua generator.
Fields
inventory_size: i64Prototype property inventory_size.
item_pickup_distance: f64Prototype property item_pickup_distance.
loot_pickup_distance: f64Prototype property loot_pickup_distance.
mining_speed: f64Prototype property mining_speed.
movement_speed: f64Must be >= 0.34375.
name: &'static strName of the god-controller. Base game uses “default”.
crafting_categories: Option<&'static [&'static str]>Names of the crafting categories the player can craft recipes from.
mining_categories: Option<&'static [&'static str]>Names of the resource categories the player can mine resources from.