pub struct GroupAttackAchievement {Show 16 fields
pub name: &'static str,
pub hidden: Option<bool>,
pub order: Option<&'static str>,
pub subgroup: Option<&'static str>,
pub icon: Option<&'static str>,
pub factoriopedia_description: Option<&'static str>,
pub hidden_in_factoriopedia: Option<bool>,
pub localised_description: Option<&'static str>,
pub localised_name: Option<&'static str>,
pub parameter: Option<bool>,
pub factoriopedia_alternative: Option<&'static str>,
pub allowed_without_fight: Option<bool>,
pub steam_stats_name: Option<&'static str>,
pub amount: Option<i64>,
pub attack_type: Option<&'static str>,
pub entities: Option<&'static [&'static str]>,
}Expand description
Minimal GroupAttackAchievementPrototype for data.extend.
This prototype is used for receiving an achievement when the player gets attacked due to pollution.
type = "group-attack-achievement" is injected by the Lua generator.
Fields
name: &'static strUnique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.
For a list of all names used in vanilla, see data.raw.
Prototype property hidden.
order: Option<&'static str>Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.
subgroup: Option<&'static str>The name of an ItemSubGroup.
icon: Option<&'static str>Path to the icon file.
Only loaded, and mandatory if icons is not defined.
factoriopedia_description: Option<&'static str>Provides additional description used in factoriopedia.
Prototype property hidden_in_factoriopedia.
localised_description: Option<&'static str>Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.
localised_name: Option<&'static str>Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.
parameter: Option<bool>Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.
factoriopedia_alternative: Option<&'static str>The ID type corresponding to the prototype that inherits from this.
For example, if this is an EntityPrototype, this property’s type is EntityID.
allowed_without_fight: Option<bool>If this is set to false, it is not possible to complete the achievement on the peaceful difficulty setting or when the enemy base generation settings have been changed.
steam_stats_name: Option<&'static str>Unusable by mods, as this refers to unlocking the achievement through Steam.
amount: Option<i64>This will trigger the achievement, if the player receives this amount of attacks. Note: The default achievement “it stinks and they don’t like it” uses the amount of 1. (As in getting attacked once.)
attack_type: Option<&'static str>The type of attack that triggers this achievement. “autonomous” attacks are triggered in response to pollution or a territory disturbance. “distraction” attacks are in response to taking damage or seeing a nearby enemy. “scripted” attacks are triggered from mods.
entities: Option<&'static [&'static str]>The achievement is only triggered if the attacking group of enemies contains at least one of the entities listed here.