MovementBonusEquipment

Struct MovementBonusEquipment 

pub struct MovementBonusEquipment {
Show 20 fields pub name: &'static str, pub categories: &'static [&'static str], pub energy_source: EnergySource, pub energy_consumption: &'static str, pub movement_bonus: f64, pub shape: LuaAny, pub sprite: LuaAny, pub hidden: Option<bool>, pub order: Option<&'static str>, pub subgroup: Option<&'static str>, pub factoriopedia_description: Option<&'static str>, pub hidden_in_factoriopedia: Option<bool>, pub localised_description: Option<&'static str>, pub localised_name: Option<&'static str>, pub parameter: Option<bool>, pub factoriopedia_alternative: Option<&'static str>, pub background_border_color: Option<Color>, pub background_color: Option<Color>, pub grabbed_background_color: Option<Color>, pub take_result: Option<&'static str>,
}
Minimal MovementBonusEquipmentPrototype for data.extend.

Used by exoskeleton. Increases max speed of characters or acceleration of vehicles if they have this equipment in their grid.

type = "movement-bonus-equipment" is injected by the Lua generator.

Fields

name: &'static str

Unique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.

For a list of all names used in vanilla, see data.raw.

categories: &'static [&'static str]

Sets the categories of the equipment. It can only be inserted into grids with at least one matching category.

energy_source: EnergySource

Prototype property energy_source.

energy_consumption: &'static str

Prototype property energy_consumption.

movement_bonus: f64

Multiplier of the character speed/vehicle acceleration.

shape: LuaAny

How big this equipment should be in the grid and whether it should be one solid rectangle or of a custom shape.

sprite: LuaAny

The graphics to use when this equipment is shown inside an equipment grid.

hidden: Option<bool>

Prototype property hidden.

order: Option<&'static str>

Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.

subgroup: Option<&'static str>

The name of an ItemSubGroup.

factoriopedia_description: Option<&'static str>

Provides additional description used in factoriopedia.

hidden_in_factoriopedia: Option<bool>

Prototype property hidden_in_factoriopedia.

localised_description: Option<&'static str>

Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.

localised_name: Option<&'static str>

Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.

parameter: Option<bool>

Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.

factoriopedia_alternative: Option<&'static str>

The ID type corresponding to the prototype that inherits from this.

For example, if this is an EntityPrototype, this property’s type is EntityID.

background_border_color: Option<Color>

The color that the border of the background of this equipment should have when shown inside an equipment grid.

background_color: Option<Color>

The color that the background of this equipment should have when shown inside an equipment grid.

grabbed_background_color: Option<Color>

The color that the background of this equipment should have when held in the players hand and hovering over an equipment grid.

take_result: Option<&'static str>

Name of the item prototype that should be returned to the player when they remove this equipment from an equipment grid.