Particle

Struct Particle 

pub struct Particle {
Show 20 fields pub name: &'static str, pub life_time: i64, pub hidden: Option<bool>, pub order: Option<&'static str>, pub subgroup: Option<&'static str>, pub factoriopedia_description: Option<&'static str>, pub hidden_in_factoriopedia: Option<bool>, pub localised_description: Option<&'static str>, pub localised_name: Option<&'static str>, pub parameter: Option<bool>, pub factoriopedia_alternative: Option<&'static str>, pub draw_shadow_when_on_ground: Option<bool>, pub fade_away_duration: Option<i64>, pub mining_particle_frame_speed: Option<f64>, pub movement_modifier: Option<f64>, pub movement_modifier_when_on_ground: Option<f64>, pub regular_trigger_effect_frequency: Option<i64>, pub render_layer: Option<&'static str>, pub render_layer_when_on_ground: Option<&'static str>, pub vertical_acceleration: Option<f64>,
}
Minimal ParticlePrototype for data.extend.

An entity with a limited lifetime that can use trigger effects.

type = "optimized-particle" is injected by the Lua generator.

Fields

name: &'static str

Unique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.

For a list of all names used in vanilla, see data.raw.

life_time: i64

Can’t be 1.

hidden: Option<bool>

Prototype property hidden.

order: Option<&'static str>

Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.

subgroup: Option<&'static str>

The name of an ItemSubGroup.

factoriopedia_description: Option<&'static str>

Provides additional description used in factoriopedia.

hidden_in_factoriopedia: Option<bool>

Prototype property hidden_in_factoriopedia.

localised_description: Option<&'static str>

Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.

localised_name: Option<&'static str>

Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.

parameter: Option<bool>

Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.

factoriopedia_alternative: Option<&'static str>

The ID type corresponding to the prototype that inherits from this.

For example, if this is an EntityPrototype, this property’s type is EntityID.

draw_shadow_when_on_ground: Option<bool>

Prototype property draw_shadow_when_on_ground.

fade_away_duration: Option<i64>

Defaults to life_time / 5, but at most 60. If this is 0, it is silently changed to 1.

mining_particle_frame_speed: Option<f64>

Prototype property mining_particle_frame_speed.

movement_modifier: Option<f64>

Prototype property movement_modifier.

movement_modifier_when_on_ground: Option<f64>

Prototype property movement_modifier_when_on_ground.

regular_trigger_effect_frequency: Option<i64>

Can’t be 1.

render_layer: Option<&'static str>

Prototype property render_layer.

render_layer_when_on_ground: Option<&'static str>

Prototype property render_layer_when_on_ground.

vertical_acceleration: Option<f64>

Has to be >= -0.01 and <= 0.01.