pub struct Planet {Show 28 fields
pub name: &'static str,
pub distance: f64,
pub orientation: f64,
pub hidden: Option<bool>,
pub order: Option<&'static str>,
pub subgroup: Option<&'static str>,
pub icon: Option<&'static str>,
pub factoriopedia_description: Option<&'static str>,
pub hidden_in_factoriopedia: Option<bool>,
pub localised_description: Option<&'static str>,
pub localised_name: Option<&'static str>,
pub parameter: Option<bool>,
pub factoriopedia_alternative: Option<&'static str>,
pub asteroid_spawn_influence: Option<f64>,
pub auto_save_on_first_trip: Option<bool>,
pub draw_orbit: Option<bool>,
pub fly_condition: Option<bool>,
pub gravity_pull: Option<f64>,
pub label_orientation: Option<f64>,
pub magnitude: Option<f64>,
pub parked_platforms_orientation: Option<f64>,
pub solar_power_in_space: Option<f64>,
pub starmap_icon: Option<&'static str>,
pub starmap_icon_orientation: Option<f64>,
pub entities_require_heating: Option<bool>,
pub map_seed_offset: Option<i64>,
pub pollutant_type: Option<&'static str>,
pub ticks_between_player_effects: Option<i64>,
}Expand description
Minimal PlanetPrototype for data.extend.
type = "planet" is injected by the Lua generator.
Fields
name: &'static strUnique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.
For a list of all names used in vanilla, see data.raw.
distance: f64Distance from the sun in map coordinates.
orientation: f64Angle in relation to the sun.
Prototype property hidden.
order: Option<&'static str>Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.
subgroup: Option<&'static str>The name of an ItemSubGroup.
icon: Option<&'static str>Path to the icon file.
Only loaded, and mandatory if icons is not defined.
factoriopedia_description: Option<&'static str>Provides additional description used in factoriopedia.
Prototype property hidden_in_factoriopedia.
localised_description: Option<&'static str>Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.
localised_name: Option<&'static str>Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.
parameter: Option<bool>Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.
factoriopedia_alternative: Option<&'static str>The ID type corresponding to the prototype that inherits from this.
For example, if this is an EntityPrototype, this property’s type is EntityID.
asteroid_spawn_influence: Option<f64>If greater than 0, asteroid_spawn_definitions will be used on space connections of this location, interpolated based on distance. The number specifies the percentage of the route where the location stops spawning its asteroids.
auto_save_on_first_trip: Option<bool>Prototype property auto_save_on_first_trip.
draw_orbit: Option<bool>If false, the orbital ring around the sun will not be drawn for this location.
fly_condition: Option<bool>When set to true, it means that this connection offers fly condition rather than wait condition at the destination
gravity_pull: Option<f64>A value which modifies platform speed; is subtracted when traveling from this location and added when traveling to this location.
label_orientation: Option<f64>The orientation where the location’s name will be drawn.
magnitude: Option<f64>The apparent size of the space location in map coordinates.
parked_platforms_orientation: Option<f64>The orientation where parked space platforms will be drawn.
solar_power_in_space: Option<f64>Prototype property solar_power_in_space.
starmap_icon: Option<&'static str>Path to the icon file.
Only loaded if starmap_icons is not defined.
starmap_icon_orientation: Option<f64>Orientation of the starmap icon, defaults to pointing towards the sun.
entities_require_heating: Option<bool>Prototype property entities_require_heating.
map_seed_offset: Option<i64>Prototype property map_seed_offset.
pollutant_type: Option<&'static str>Prototype property pollutant_type.
ticks_between_player_effects: Option<i64>Prototype property ticks_between_player_effects.