pub struct ProducePerHourAchievement {Show 15 fields
pub name: &'static str,
pub amount: f64,
pub hidden: Option<bool>,
pub order: Option<&'static str>,
pub subgroup: Option<&'static str>,
pub icon: Option<&'static str>,
pub factoriopedia_description: Option<&'static str>,
pub hidden_in_factoriopedia: Option<bool>,
pub localised_description: Option<&'static str>,
pub localised_name: Option<&'static str>,
pub parameter: Option<bool>,
pub factoriopedia_alternative: Option<&'static str>,
pub allowed_without_fight: Option<bool>,
pub steam_stats_name: Option<&'static str>,
pub fluid_product: Option<&'static str>,
}Expand description
Minimal ProducePerHourAchievementPrototype for data.extend.
This prototype is used for receiving an achievement when the player crafts a specified item a certain amount, in an hour.
type = "produce-per-hour-achievement" is injected by the Lua generator.
Fields
name: &'static strUnique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.
For a list of all names used in vanilla, see data.raw.
amount: f64This is how much the player has to craft in an hour, to receive the achievement.
Prototype property hidden.
order: Option<&'static str>Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.
subgroup: Option<&'static str>The name of an ItemSubGroup.
icon: Option<&'static str>Path to the icon file.
Only loaded, and mandatory if icons is not defined.
factoriopedia_description: Option<&'static str>Provides additional description used in factoriopedia.
Prototype property hidden_in_factoriopedia.
localised_description: Option<&'static str>Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.
localised_name: Option<&'static str>Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.
parameter: Option<bool>Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.
factoriopedia_alternative: Option<&'static str>The ID type corresponding to the prototype that inherits from this.
For example, if this is an EntityPrototype, this property’s type is EntityID.
allowed_without_fight: Option<bool>If this is set to false, it is not possible to complete the achievement on the peaceful difficulty setting or when the enemy base generation settings have been changed.
steam_stats_name: Option<&'static str>Unusable by mods, as this refers to unlocking the achievement through Steam.
fluid_product: Option<&'static str>Mandatory if item_product is not defined.
This will tell the achievement what fluid the player needs to craft, to get the achievement.