pub struct RocketSiloRocket {Show 40 fields
pub name: &'static str,
pub cargo_pod_entity: &'static str,
pub effects_fade_in_end_distance: f64,
pub effects_fade_in_start_distance: f64,
pub engine_starting_speed: f64,
pub flying_acceleration: f64,
pub flying_speed: f64,
pub full_render_layer_switch_distance: f64,
pub inventory_size: i64,
pub rising_speed: f64,
pub rocket_flame_left_rotation: f64,
pub rocket_flame_right_rotation: f64,
pub rocket_render_layer_switch_distance: f64,
pub rocket_visible_distance_from_center: f64,
pub shadow_fade_out_end_ratio: f64,
pub shadow_fade_out_start_ratio: f64,
pub rocket_launch_offset: LuaAny,
pub rocket_rise_offset: LuaAny,
pub hidden: Option<bool>,
pub order: Option<&'static str>,
pub subgroup: Option<&'static str>,
pub collision_box: Option<BoundingBox>,
pub flags: Option<&'static [&'static str]>,
pub icon: Option<&'static str>,
pub minable: Option<MinableProperties>,
pub selection_box: Option<BoundingBox>,
pub factoriopedia_description: Option<&'static str>,
pub hidden_in_factoriopedia: Option<bool>,
pub localised_description: Option<&'static str>,
pub localised_name: Option<&'static str>,
pub parameter: Option<bool>,
pub factoriopedia_alternative: Option<&'static str>,
pub additional_pastable_entities: Option<&'static [&'static str]>,
pub alert_icon_scale: Option<f64>,
pub allow_copy_paste: Option<bool>,
pub ambient_sounds_group: Option<&'static str>,
pub build_grid_size: Option<i64>,
pub deconstruction_alternative: Option<&'static str>,
pub draw_stateless_visualisations_in_ghost: Option<bool>,
pub drawing_box_vertical_extension: Option<f64>,
}Expand description
Minimal RocketSiloRocketPrototype for data.extend.
The rocket inside the rocket silo.
type = "rocket-silo-rocket" is injected by the Lua generator.
Fields
name: &'static strUnique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.
For a list of all names used in vanilla, see data.raw.
cargo_pod_entity: &'static strName of a CargoPodPrototype.
effects_fade_in_end_distance: f64Prototype property effects_fade_in_end_distance.
effects_fade_in_start_distance: f64Prototype property effects_fade_in_start_distance.
engine_starting_speed: f64Prototype property engine_starting_speed.
flying_acceleration: f64Prototype property flying_acceleration.
flying_speed: f64Prototype property flying_speed.
full_render_layer_switch_distance: f64Prototype property full_render_layer_switch_distance.
inventory_size: i64Prototype property inventory_size.
rising_speed: f64Prototype property rising_speed.
rocket_flame_left_rotation: f64Prototype property rocket_flame_left_rotation.
rocket_flame_right_rotation: f64Prototype property rocket_flame_right_rotation.
rocket_render_layer_switch_distance: f64Prototype property rocket_render_layer_switch_distance.
rocket_visible_distance_from_center: f64Prototype property rocket_visible_distance_from_center.
shadow_fade_out_end_ratio: f64Prototype property shadow_fade_out_end_ratio.
shadow_fade_out_start_ratio: f64Prototype property shadow_fade_out_start_ratio.
rocket_launch_offset: LuaAnyPrototype property rocket_launch_offset.
rocket_rise_offset: LuaAnyPrototype property rocket_rise_offset.
Prototype property hidden.
order: Option<&'static str>Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.
subgroup: Option<&'static str>The name of an ItemSubGroup.
collision_box: Option<BoundingBox>Specification of the entity collision boundaries. Empty collision box means no collision and is used for smoke, projectiles, particles, explosions etc.
The {0,0} coordinate in the collision box will match the entity position. It should be near the center of the collision box, to keep correct entity drawing order. The bounding box must include the {0,0} coordinate.
Note, that for buildings, it is customary to leave 0.1 wide border between the edge of the tile and the edge of the building, this lets the player move between the building and electric poles/inserters etc.
flags: Option<&'static [&'static str]>Prototype property flags.
icon: Option<&'static str>Path to the icon file.
Either this or icons is mandatory for entities that have at least one of these flags active: "placeable-neutral", "placeable-player“, "placeable-enemy".
Only loaded if icons is not defined.
minable: Option<MinableProperties>The item given to the player when they mine the entity and other properties relevant to mining this entity.
selection_box: Option<BoundingBox>Specification of the entity selection area. When empty the entity will have no selection area (and thus is not selectable).
The selection box is usually a little bit bigger than the collision box. For tileable entities (like buildings) it should match the tile size of the building.
factoriopedia_description: Option<&'static str>Provides additional description used in factoriopedia.
Prototype property hidden_in_factoriopedia.
localised_description: Option<&'static str>Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.
localised_name: Option<&'static str>Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.
parameter: Option<bool>Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.
factoriopedia_alternative: Option<&'static str>The ID type corresponding to the prototype that inherits from this.
For example, if this is an EntityPrototype, this property’s type is EntityID.
additional_pastable_entities: Option<&'static [&'static str]>Names of the entity prototypes this entity prototype can be pasted on to in addition to the standard supported types.
This is used to allow copying between types that aren’t compatible on the C++ code side, by allowing mods to receive the on_entity_settings_pasted event for the given entity and do the setting pasting via script.
alert_icon_scale: Option<f64>Prototype property alert_icon_scale.
allow_copy_paste: Option<bool>Prototype property allow_copy_paste.
ambient_sounds_group: Option<&'static str>Prototype property ambient_sounds_group.
build_grid_size: Option<i64>Supported values are 1 (for 1x1 grid) and 2 (for 2x2 grid, like rails).
Internally forced to be 2 for RailPrototype, RailRemnantsPrototype, TrainStopPrototype, RailSupportPrototype and CargoBayPrototype.
Internally forced to be 256 for SpacePlatformHubPrototype.
deconstruction_alternative: Option<&'static str>Used to merge multiple entities into one entry in the deconstruction planner.
draw_stateless_visualisations_in_ghost: Option<bool>Prototype property draw_stateless_visualisations_in_ghost.
drawing_box_vertical_extension: Option<f64>Specification of extra vertical space needed to see the whole entity in GUIs. This is used to calculate the correct zoom and positioning in the entity info gui, for example in the entity tooltip.