pub struct SolarPanelEquipment {Show 22 fields
pub name: &'static str,
pub categories: &'static [&'static str],
pub energy_source: EnergySource,
pub power: &'static str,
pub shape: LuaAny,
pub sprite: LuaAny,
pub hidden: Option<bool>,
pub order: Option<&'static str>,
pub subgroup: Option<&'static str>,
pub factoriopedia_description: Option<&'static str>,
pub hidden_in_factoriopedia: Option<bool>,
pub localised_description: Option<&'static str>,
pub localised_name: Option<&'static str>,
pub parameter: Option<bool>,
pub factoriopedia_alternative: Option<&'static str>,
pub background_border_color: Option<Color>,
pub background_color: Option<Color>,
pub grabbed_background_color: Option<Color>,
pub take_result: Option<&'static str>,
pub performance_at_day: Option<f64>,
pub performance_at_night: Option<f64>,
pub solar_coefficient_property: Option<&'static str>,
}Expand description
Minimal SolarPanelEquipmentPrototype for data.extend.
type = "solar-panel-equipment" is injected by the Lua generator.
Fields
name: &'static strUnique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.
For a list of all names used in vanilla, see data.raw.
categories: &'static [&'static str]Sets the categories of the equipment. It can only be inserted into grids with at least one matching category.
energy_source: EnergySourcePrototype property energy_source.
power: &'static strHow much power should be provided.
shape: LuaAnyHow big this equipment should be in the grid and whether it should be one solid rectangle or of a custom shape.
sprite: LuaAnyThe graphics to use when this equipment is shown inside an equipment grid.
Prototype property hidden.
order: Option<&'static str>Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.
subgroup: Option<&'static str>The name of an ItemSubGroup.
factoriopedia_description: Option<&'static str>Provides additional description used in factoriopedia.
Prototype property hidden_in_factoriopedia.
localised_description: Option<&'static str>Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.
localised_name: Option<&'static str>Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.
parameter: Option<bool>Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.
factoriopedia_alternative: Option<&'static str>The ID type corresponding to the prototype that inherits from this.
For example, if this is an EntityPrototype, this property’s type is EntityID.
background_border_color: Option<Color>The color that the border of the background of this equipment should have when shown inside an equipment grid.
background_color: Option<Color>The color that the background of this equipment should have when shown inside an equipment grid.
grabbed_background_color: Option<Color>The color that the background of this equipment should have when held in the players hand and hovering over an equipment grid.
take_result: Option<&'static str>Name of the item prototype that should be returned to the player when they remove this equipment from an equipment grid.
performance_at_day: Option<f64>Prototype property performance_at_day.
performance_at_night: Option<f64>Prototype property performance_at_night.
solar_coefficient_property: Option<&'static str>Surface property must have a positive default value. When SolarPanelEquipmentPrototype::solar_coefficient_property is set to point at a different surface property than “solar-power”, then LuaSurface::solar_power_multiplier and SpaceLocationPrototype::solar_power_in_space will be ignored as the solar panel power output will be only affected by value of this surface property set on the surface using PlanetPrototype::surface_properties or LuaSurface::set_property.
Due to equipment grid overall description, when solar_coefficient_property is not solar-power, a different locale will be used to show total energy production of solar panels: description.solar-panel-power-X where X is the surface property name.