pub struct SpiderLeg {Show 34 fields
pub name: &'static str,
pub base_position_selection_distance: f64,
pub initial_movement_speed: f64,
pub knee_distance_factor: f64,
pub knee_height: f64,
pub minimal_step_size: f64,
pub movement_acceleration: f64,
pub movement_based_position_selection_distance: f64,
pub target_position_randomisation_distance: f64,
pub hidden: Option<bool>,
pub order: Option<&'static str>,
pub subgroup: Option<&'static str>,
pub collision_box: Option<BoundingBox>,
pub flags: Option<&'static [&'static str]>,
pub icon: Option<&'static str>,
pub minable: Option<MinableProperties>,
pub selection_box: Option<BoundingBox>,
pub max_health: Option<f64>,
pub factoriopedia_description: Option<&'static str>,
pub hidden_in_factoriopedia: Option<bool>,
pub localised_description: Option<&'static str>,
pub localised_name: Option<&'static str>,
pub parameter: Option<bool>,
pub factoriopedia_alternative: Option<&'static str>,
pub additional_pastable_entities: Option<&'static [&'static str]>,
pub alert_icon_scale: Option<f64>,
pub allow_copy_paste: Option<bool>,
pub ambient_sounds_group: Option<&'static str>,
pub build_grid_size: Option<i64>,
pub deconstruction_alternative: Option<&'static str>,
pub draw_stateless_visualisations_in_ghost: Option<bool>,
pub drawing_box_vertical_extension: Option<f64>,
pub enemy_map_color: Option<Color>,
pub fast_replaceable_group: Option<&'static str>,
}Expand description
Minimal SpiderLegPrototype for data.extend.
Used by SpiderLegSpecification for SpiderVehiclePrototype, also known as spidertron.
type = "spider-leg" is injected by the Lua generator.
Fields
name: &'static strUnique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.
For a list of all names used in vanilla, see data.raw.
base_position_selection_distance: f64Prototype property base_position_selection_distance.
initial_movement_speed: f64Prototype property initial_movement_speed.
knee_distance_factor: f64The placement of the knee relative to the torso of the spider and the end of the foot when at rest. Used to calculate the shape of the leg and the length of the individual parts. Values between 0 and 1 place the knee between the torso and the leg. Values closer to 0 will place the knee closer to the torso.
knee_height: f64The resting height of the knee from the ground. Used to derive leg part length and size. If set too low, this could cause the knee to invert, bending inwards underneath the spider.
minimal_step_size: f64Prototype property minimal_step_size.
movement_acceleration: f64Prototype property movement_acceleration.
movement_based_position_selection_distance: f64Prototype property movement_based_position_selection_distance.
target_position_randomisation_distance: f64Prototype property target_position_randomisation_distance.
Prototype property hidden.
order: Option<&'static str>Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.
subgroup: Option<&'static str>The name of an ItemSubGroup.
collision_box: Option<BoundingBox>Specification of the entity collision boundaries. Empty collision box means no collision and is used for smoke, projectiles, particles, explosions etc.
The {0,0} coordinate in the collision box will match the entity position. It should be near the center of the collision box, to keep correct entity drawing order. The bounding box must include the {0,0} coordinate.
Note, that for buildings, it is customary to leave 0.1 wide border between the edge of the tile and the edge of the building, this lets the player move between the building and electric poles/inserters etc.
flags: Option<&'static [&'static str]>Prototype property flags.
icon: Option<&'static str>Path to the icon file.
Either this or icons is mandatory for entities that have at least one of these flags active: "placeable-neutral", "placeable-player“, "placeable-enemy".
Only loaded if icons is not defined.
minable: Option<MinableProperties>The item given to the player when they mine the entity and other properties relevant to mining this entity.
selection_box: Option<BoundingBox>Specification of the entity selection area. When empty the entity will have no selection area (and thus is not selectable).
The selection box is usually a little bit bigger than the collision box. For tileable entities (like buildings) it should match the tile size of the building.
max_health: Option<f64>The unit health can never go over the maximum. Default health of units on creation is set to max. Must be greater than 0.
factoriopedia_description: Option<&'static str>Provides additional description used in factoriopedia.
Prototype property hidden_in_factoriopedia.
localised_description: Option<&'static str>Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.
localised_name: Option<&'static str>Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.
parameter: Option<bool>Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.
factoriopedia_alternative: Option<&'static str>The ID type corresponding to the prototype that inherits from this.
For example, if this is an EntityPrototype, this property’s type is EntityID.
additional_pastable_entities: Option<&'static [&'static str]>Names of the entity prototypes this entity prototype can be pasted on to in addition to the standard supported types.
This is used to allow copying between types that aren’t compatible on the C++ code side, by allowing mods to receive the on_entity_settings_pasted event for the given entity and do the setting pasting via script.
alert_icon_scale: Option<f64>Prototype property alert_icon_scale.
allow_copy_paste: Option<bool>Prototype property allow_copy_paste.
ambient_sounds_group: Option<&'static str>Prototype property ambient_sounds_group.
build_grid_size: Option<i64>Supported values are 1 (for 1x1 grid) and 2 (for 2x2 grid, like rails).
Internally forced to be 2 for RailPrototype, RailRemnantsPrototype, TrainStopPrototype, RailSupportPrototype and CargoBayPrototype.
Internally forced to be 256 for SpacePlatformHubPrototype.
deconstruction_alternative: Option<&'static str>Used to merge multiple entities into one entry in the deconstruction planner.
draw_stateless_visualisations_in_ghost: Option<bool>Prototype property draw_stateless_visualisations_in_ghost.
drawing_box_vertical_extension: Option<f64>Specification of extra vertical space needed to see the whole entity in GUIs. This is used to calculate the correct zoom and positioning in the entity info gui, for example in the entity tooltip.
enemy_map_color: Option<Color>Prototype property enemy_map_color.
fast_replaceable_group: Option<&'static str>This allows you to replace an entity that’s already placed, with a different one in your inventory. For example, replacing a burner inserter with a fast inserter. The replacement entity can be a different rotation to the replaced entity and you can replace an entity with the same type.
This is simply a string, so any string can be used here. The entity that should be replaced simply has to use the same string here.
Entities with the same fast replaceable group can be configured as upgrades for each other in the upgrade planner. Refer to the upgrade planner prototype’s page the full requirements for entities to be shown in the upgrade planner.