TrivialSmoke

Struct TrivialSmoke 

pub struct TrivialSmoke {
Show 24 fields pub name: &'static str, pub duration: i64, pub animation: LuaAny, pub hidden: Option<bool>, pub order: Option<&'static str>, pub subgroup: Option<&'static str>, pub factoriopedia_description: Option<&'static str>, pub hidden_in_factoriopedia: Option<bool>, pub localised_description: Option<&'static str>, pub localised_name: Option<&'static str>, pub parameter: Option<bool>, pub factoriopedia_alternative: Option<&'static str>, pub affected_by_wind: Option<bool>, pub color: Option<Color>, pub cyclic: Option<bool>, pub end_scale: Option<f64>, pub fade_away_duration: Option<i64>, pub fade_in_duration: Option<i64>, pub glow_fade_away_duration: Option<i64>, pub movement_slow_down_factor: Option<f64>, pub render_layer: Option<&'static str>, pub show_when_smoke_off: Option<bool>, pub spread_duration: Option<i64>, pub start_scale: Option<f64>,
}
Minimal TrivialSmokePrototype for data.extend.

Smoke, but it’s not an entity for optimization purposes.

type = "trivial-smoke" is injected by the Lua generator.

Fields

name: &'static str

Unique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.

For a list of all names used in vanilla, see data.raw.

duration: i64

Can’t be 0 - the smoke will never render.

animation: LuaAny

Prototype property animation.

hidden: Option<bool>

Prototype property hidden.

order: Option<&'static str>

Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.

subgroup: Option<&'static str>

The name of an ItemSubGroup.

factoriopedia_description: Option<&'static str>

Provides additional description used in factoriopedia.

hidden_in_factoriopedia: Option<bool>

Prototype property hidden_in_factoriopedia.

localised_description: Option<&'static str>

Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.

localised_name: Option<&'static str>

Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.

parameter: Option<bool>

Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.

factoriopedia_alternative: Option<&'static str>

The ID type corresponding to the prototype that inherits from this.

For example, if this is an EntityPrototype, this property’s type is EntityID.

affected_by_wind: Option<bool>

Smoke always moves randomly unless movement_slow_down_factor is 0. If affected_by_wind is true, the smoke will also be moved by wind.

color: Option<Color>

Prototype property color.

cyclic: Option<bool>

Prototype property cyclic.

end_scale: Option<f64>

Prototype property end_scale.

fade_away_duration: Option<i64>

fade_in_duration + fade_away_duration must be <= duration.

fade_in_duration: Option<i64>

fade_in_duration + fade_away_duration must be <= duration.

glow_fade_away_duration: Option<i64>

Prototype property glow_fade_away_duration.

movement_slow_down_factor: Option<f64>

Value between 0 and 1, with 1 being no slowdown and 0 being no movement.

render_layer: Option<&'static str>

Prototype property render_layer.

show_when_smoke_off: Option<bool>

Prototype property show_when_smoke_off.

spread_duration: Option<i64>

Prototype property spread_duration.

start_scale: Option<f64>

Prototype property start_scale.