pub struct UtilitySounds {Show 40 fields
pub name: &'static str,
pub achievement_unlocked: LuaAny,
pub adjust_blueprint_snapping: LuaAny,
pub alert_destroyed: LuaAny,
pub armor_insert: LuaAny,
pub armor_remove: LuaAny,
pub axe_fighting: LuaAny,
pub axe_mining_ore: LuaAny,
pub axe_mining_stone: LuaAny,
pub blueprint_preview_build: LuaAny,
pub blueprint_preview_mine: LuaAny,
pub build_animated_huge: LuaAny,
pub build_animated_large: LuaAny,
pub build_animated_medium: LuaAny,
pub build_animated_small: LuaAny,
pub build_behemoth: LuaAny,
pub build_blueprint_huge: LuaAny,
pub build_blueprint_large: LuaAny,
pub build_blueprint_medium: LuaAny,
pub build_blueprint_small: LuaAny,
pub build_ghost_upgrade: LuaAny,
pub build_ghost_upgrade_cancel: LuaAny,
pub build_huge: LuaAny,
pub build_large: LuaAny,
pub build_medium: LuaAny,
pub build_small: LuaAny,
pub cannot_build: LuaAny,
pub change_quality: LuaAny,
pub clear_cursor: LuaAny,
pub confirm: LuaAny,
pub console_message: LuaAny,
pub console_platform_created: LuaAny,
pub console_platform_destroyed: LuaAny,
pub console_player_changed_logistic_group: LuaAny,
pub console_player_died: LuaAny,
pub console_player_joined: LuaAny,
pub console_player_left: LuaAny,
pub console_player_paused_game: LuaAny,
pub console_player_research: LuaAny,
pub console_player_respawned: LuaAny,
}Expand description
Minimal UtilitySounds for data.extend.
Sounds used by the game that are not specific to certain prototypes.
type = "utility-sounds" is injected by the Lua generator.
Fields
name: &'static strUnique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.
For a list of all names used in vanilla, see data.raw.
achievement_unlocked: LuaAnySound category "gui-effect".
adjust_blueprint_snapping: LuaAnySound category "gui-effect".
alert_destroyed: LuaAnySound category "alert".
armor_insert: LuaAnySound category "gui-effect".
armor_remove: LuaAnySound category "gui-effect".
axe_fighting: LuaAnySound category "game-effect".
axe_mining_ore: LuaAnySound category "game-effect".
axe_mining_stone: LuaAnySound category "game-effect".
blueprint_preview_build: LuaAnySound category "gui-effect".
blueprint_preview_mine: LuaAnySound category "gui-effect".
build_animated_huge: LuaAnySound category "game-effect".
build_animated_large: LuaAnySound category "game-effect".
build_animated_medium: LuaAnySound category "game-effect".
build_animated_small: LuaAnySound category "game-effect".
build_behemoth: LuaAnySound category "game-effect".
build_blueprint_huge: LuaAnySound category "game-effect".
build_blueprint_large: LuaAnySound category "game-effect".
build_blueprint_medium: LuaAnySound category "game-effect".
build_blueprint_small: LuaAnySound category "game-effect".
build_ghost_upgrade: LuaAnySound category "game-effect".
build_ghost_upgrade_cancel: LuaAnySound category "game-effect".
build_huge: LuaAnySound category "game-effect".
build_large: LuaAnySound category "game-effect".
build_medium: LuaAnySound category "game-effect".
build_small: LuaAnySound category "game-effect".
cannot_build: LuaAnySound category "gui-effect".
change_quality: LuaAnySound category "gui-effect".
clear_cursor: LuaAnySound category "gui-effect".
confirm: LuaAnySound category "gui-effect".
console_message: LuaAnySound category "gui-effect".
console_platform_created: LuaAnySound category "gui-effect".
console_platform_destroyed: LuaAnySound category "gui-effect".
console_player_changed_logistic_group: LuaAnySound category "gui-effect".
console_player_died: LuaAnySound category "gui-effect".
console_player_joined: LuaAnySound category "gui-effect".
console_player_left: LuaAnySound category "gui-effect".
console_player_paused_game: LuaAnySound category "gui-effect".
console_player_research: LuaAnySound category "gui-effect".
console_player_respawned: LuaAnySound category "gui-effect".