pub struct UtilitySprites {Show 40 fields
pub name: &'static str,
pub achievement_label: LuaAny,
pub achievement_label_completed: LuaAny,
pub achievement_label_failed: LuaAny,
pub achievement_warning: LuaAny,
pub add: LuaAny,
pub add_white: LuaAny,
pub alert_arrow: LuaAny,
pub ammo_damage_modifier_icon: LuaAny,
pub ammo_icon: LuaAny,
pub and_or: LuaAny,
pub any_quality: LuaAny,
pub area_icon: LuaAny,
pub arrow_button: LuaAny,
pub artillery_range_modifier_icon: LuaAny,
pub asteroid_chunk_editor_icon: LuaAny,
pub asteroid_collector_path_blocked_icon: LuaAny,
pub backward_arrow: LuaAny,
pub backward_arrow_black: LuaAny,
pub bar_gray_pip: LuaAny,
pub battery: LuaAny,
pub beacon_distribution_modifier_icon: LuaAny,
pub belt_stack_size_bonus_modifier_icon: LuaAny,
pub bookmark: LuaAny,
pub brush_circle_shape: LuaAny,
pub brush_icon: LuaAny,
pub brush_square_shape: LuaAny,
pub buildability_collision: LuaAny,
pub buildability_collision_elevated: LuaAny,
pub buildability_elevated_collision_bottom: LuaAny,
pub buildability_elevated_collision_line: LuaAny,
pub buildability_elevated_collision_top: LuaAny,
pub bulk_inserter_capacity_bonus_modifier_icon: LuaAny,
pub cable_editor_icon: LuaAny,
pub cargo_bay_not_connected_icon: LuaAny,
pub cargo_bay_too_far_from_source_icon: LuaAny,
pub cargo_landing_pad_count_modifier_icon: LuaAny,
pub center: LuaAny,
pub change_recipe: LuaAny,
pub change_recipe_productivity_modifier_icon: LuaAny,
}Expand description
Minimal UtilitySprites for data.extend.
Sprites used by the game that are not specific to certain prototypes.
type = "utility-sprites" is injected by the Lua generator.
Fields
name: &'static strUnique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.
For a list of all names used in vanilla, see data.raw.
achievement_label: LuaAnyPrototype property achievement_label.
achievement_label_completed: LuaAnyPrototype property achievement_label_completed.
achievement_label_failed: LuaAnyPrototype property achievement_label_failed.
achievement_warning: LuaAnyPrototype property achievement_warning.
add: LuaAnyPrototype property add.
add_white: LuaAnyPrototype property add_white.
alert_arrow: LuaAnyPrototype property alert_arrow.
ammo_damage_modifier_icon: LuaAnyPrototype property ammo_damage_modifier_icon.
ammo_icon: LuaAnyPrototype property ammo_icon.
and_or: LuaAnyPrototype property and_or.
any_quality: LuaAnyPrototype property any_quality.
area_icon: LuaAnyPrototype property area_icon.
Prototype property arrow_button.
artillery_range_modifier_icon: LuaAnyPrototype property artillery_range_modifier_icon.
asteroid_chunk_editor_icon: LuaAnyPrototype property asteroid_chunk_editor_icon.
asteroid_collector_path_blocked_icon: LuaAnyPrototype property asteroid_collector_path_blocked_icon.
backward_arrow: LuaAnyPrototype property backward_arrow.
backward_arrow_black: LuaAnyPrototype property backward_arrow_black.
bar_gray_pip: LuaAnyPrototype property bar_gray_pip.
battery: LuaAnyPrototype property battery.
beacon_distribution_modifier_icon: LuaAnyPrototype property beacon_distribution_modifier_icon.
belt_stack_size_bonus_modifier_icon: LuaAnyPrototype property belt_stack_size_bonus_modifier_icon.
bookmark: LuaAnyPrototype property bookmark.
brush_circle_shape: LuaAnyPrototype property brush_circle_shape.
brush_icon: LuaAnyPrototype property brush_icon.
brush_square_shape: LuaAnyPrototype property brush_square_shape.
buildability_collision: LuaAnyPrototype property buildability_collision.
buildability_collision_elevated: LuaAnyPrototype property buildability_collision_elevated.
buildability_elevated_collision_bottom: LuaAnyPrototype property buildability_elevated_collision_bottom.
buildability_elevated_collision_line: LuaAnyPrototype property buildability_elevated_collision_line.
buildability_elevated_collision_top: LuaAnyPrototype property buildability_elevated_collision_top.
bulk_inserter_capacity_bonus_modifier_icon: LuaAnyPrototype property bulk_inserter_capacity_bonus_modifier_icon.
cable_editor_icon: LuaAnyPrototype property cable_editor_icon.
cargo_bay_not_connected_icon: LuaAnyPrototype property cargo_bay_not_connected_icon.
cargo_bay_too_far_from_source_icon: LuaAnyPrototype property cargo_bay_too_far_from_source_icon.
cargo_landing_pad_count_modifier_icon: LuaAnyPrototype property cargo_landing_pad_count_modifier_icon.
center: LuaAnyPrototype property center.
change_recipe: LuaAnyPrototype property change_recipe.
change_recipe_productivity_modifier_icon: LuaAnyPrototype property change_recipe_productivity_modifier_icon.