Module unions

Module unions 

Enums

AchievementPrototypeFilterFilter
AchievementPrototypeFilterMode
Alignment
A string that specifies where a GUI element should be.
ApplyTileTint
Refers to tints defined in TilePrototype::particle_tints.
ArithmeticCombinatorParameterOperation
AsteroidChunkPrototypeFilterFilter
AttackParametersType
BeltConnectionType
BlueprintSpoilPriority
CapsuleActionType
CliffOrientation
ComparatorString
A string that specifies how the inputs should be compared.
CursorBoxRenderType
DebugVariablePresentationHintAttributes
DebugVariablesFilterFilter
DeciderCombinatorConditionCompareType
DecorativePrototypeFilterFilter
ElemType
A string specifying a type for choose elem buttons. It’s also used by ElemID for LuaGuiElement::elem_tooltip.
EntityPrototypeFilterFilter
EntityPrototypeFlag
A string specifying an entity prototype flag.
EquipmentPrototypeFilterFilter
FluidFlowDirection
FluidPrototypeFilterFilter
ForceCondition
GuiAnchorGhostMode
GuiArrowType
Used by GuiArrowSpecification.
GuiDirection
Direction of a LuaGuiElement’s layout.
GuiElementType
HeatSettingMode
IDType
All base prototype types.
IconDrawSpecificationRenderLayer
InfinityInventoryFilterMode
IngredientType
ItemPrototypeFilterFilter
ItemPrototypeFlag
A string specifying an item prototype flag.
LinkedGameControl
The internal name of a game control (key binding).
LogisticMode
LuaAutoplaceControlPrototypeCategory
LuaCustomInputPrototypeConsuming
LuaEntityBeltShape
LuaEntityCargoPodState
LuaEntityClonedEventFilterFilter
LuaEntityDamagedEventFilterFilter
LuaEntityDiedEventFilterFilter
LuaEntityInserterFilterMode
LuaEntityPrototypeBeaconCounter
LuaEntityPrototypeBoilerMode
LuaEntityPrototypeGuiMode
LuaEntityPrototypeInventoryType
LuaEntityPrototypeLogisticMode
LuaEntityPrototypeRemoveDecoratives
LuaGuiElementScrollMode
LuaHelpersStage
LuaItemCommonType
LuaItemPrototypeAmmoSourceType
LuaItemPrototypeSendToOrbitMode
LuaLogisticNetworkMember
LuaLogisticNetworkMembers
LuaLogisticNetworkMembers2
LuaModSettingPrototypeSettingType
LuaPostEntityDiedEventFilterFilter
LuaPostSegmentedUnitDiedEventFilterFilter
LuaProcessionPrototypeUsage
LuaRecordType
LuaRenderObjectType
LuaSegmentedUnitCreatedEventFilterFilter
LuaSegmentedUnitDamagedEventFilterFilter
LuaSimulationInventory
LuaStyleHorizontalAlign
LuaStyleVerticalAlign
LuaTrainManagerSearchDirection
ModSettingPrototypeFilterFilter
ModifierType
Used by TechnologyModifier.
OnPermissionGroupEditedType
OnRuntimeModSettingChangedSettingType
PipeConnectionType
PlatformBackdropHeroCloudProjectionStyle
ProductionType
Specifies how the entity will utilize this fluidbox. input-output should only be used for boilers in fluid heating mode.
ProgrammableSpeakerPlaybackMode
Specifies from where the programmable speaker’s sound will be heard.
PrototypeFilterMode
QuickBarSlotType
RangeMode
RecipePrototypeFilterFilter
RequestFromLocation
ResearchTriggerType
ScriptRenderMode
ScriptRenderTargetTableType
ScriptSpriteLightMode
ScrollPolicy
Scroll policy of a scroll pane.
SelectorCombinatorParameterOperation
SignalIDType
SimulationWidgetType
SoundType
Defines which slider in the game’s sound settings affects the volume of this sound. Furthermore, some sound types are mixed differently than others, e.g. zoom level effects are applied.
SpaceLocationPrototypeFilterFilter
SplitterPriority
SpoilPriority
SwitchState
State of a GUI switch.
TargetType
Target type of an AmmoType.
TechnologyPrototypeFilterFilter
TerritoryVisibilityCondition
TextAlign
The text is aligned so that the target position is at the given side of the text.
TilePrototypeFilterFilter
TrainPathRequestType
A string specifying the type of request for LuaTrainManager::request_train_path.
TriggerDeliveryType
TriggerEffectItemType
Used by TriggerEffectItem.
TriggerItemType
UndoRedoActionType
UnlockableIDType
UpgradeMapperDestinationType
ValveMode
Defines the mode of operation for a ValvePrototype.
VerticalTextAlign
The text is aligned so that the target position is at the given side of the text.
VirtualSignalPrototypeFilterFilter
WaitConditionType
Type of a WaitCondition.

Functions

literal_enum_variant_str
Map a generated literal-union enum path (Type, Variant) to its Factorio string.