SoundType

Enum SoundType 

pub enum SoundType {
    GameEffect,
    GuiEffect,
    Ambient,
    Environment,
    Walking,
    Alert,
    Wind,
    WorldAmbient,
    Weapon,
    Explosion,
    Enemy,
}
Defines which slider in the game’s sound settings affects the volume of this sound. Furthermore, some sound types are mixed differently than others, e.g. zoom level effects are applied.

Variants



GameEffect



GuiEffect



Ambient



Environment



Walking



Alert



Wind



WorldAmbient



Weapon



Explosion



Enemy

Implementations

Source

impl SoundType

pub const fn as_str(self) -> &'static str