pub enum TextAlign {
Left,
Right,
Center,
}Expand description
The text is aligned so that the target position is at the given side of the text.
For example, "right" aligned text means the right side of the text is at the target position. Or in other words, the target is on the right of the text.
Variants
Implementations