VerticalTextAlign

Enum VerticalTextAlign 

pub enum VerticalTextAlign {
    Top,
    Middle,
    Baseline,
    Bottom,
}
The text is aligned so that the target position is at the given side of the text.

For example, "top" aligned text means the top of the text is at the target position. Or in other words, the target is at the top of the text.

Variants



Top



Middle



Baseline



Bottom

Implementations

Source

impl VerticalTextAlign

pub const fn as_str(self) -> &'static str