pub struct LuaAchievementPrototype;Expand description
Prototype of a achievement.
Implementations
Sourceimpl LuaAchievementPrototype
impl LuaAchievementPrototype
Sourcepub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
Extra description items in the tooltip and Factoriopedia.
Sourcepub fn factoriopedia_description(&self) -> &str
pub fn factoriopedia_description(&self) -> &str
Provides additional description used in factoriopedia.
pub fn localised_description(&self) -> &str
pub fn localised_name(&self) -> &str
Sourcepub fn order(&self) -> &str
pub fn order(&self) -> &str
The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.
pub fn parameter(&self) -> bool
pub fn allowed_without_fight(&self) -> bool
pub fn alternative_armor(&self) -> LuaItemPrototype
pub fn ammo_type(&self) -> LuaItemPrototype
pub fn amount(&self) -> u32
pub fn armor(&self) -> LuaItemPrototype
pub fn count(&self) -> u32
pub fn damage_dealer(&self) -> Vec<LuaEntityPrototype>
pub fn damage_type(&self) -> LuaDamagePrototype
pub fn dont_build(&self) -> Vec<LuaEntityPrototype>
pub fn dont_research(&self) -> Vec<LuaItemPrototype>
pub fn excluded(&self) -> Vec<LuaEntityPrototype>
pub fn fluid_product(&self) -> LuaFluidPrototype
pub fn in_vehicle(&self) -> bool
pub fn included(&self) -> Vec<LuaEntityPrototype>
pub fn item_product(&self) -> LuaItemPrototype
pub fn last_hour_only(&self) -> bool
pub fn limit_equip_quality(&self) -> LuaQualityPrototype
pub fn limit_quality(&self) -> LuaQualityPrototype
pub fn limited_to_one_game(&self) -> bool
pub fn minimum_damage(&self) -> f32
pub fn minimum_distance(&self) -> f64
pub fn minimum_energy_produced(&self) -> f64
pub fn module(&self) -> Vec<LuaItemPrototype>
pub fn more_than_manually(&self) -> bool
pub fn not_to_kill(&self) -> LuaEntityPrototype
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
pub fn objective_condition(&self) -> &str
pub fn personally(&self) -> bool
pub fn quality(&self) -> LuaQualityPrototype
pub fn research_all(&self) -> bool
pub fn research_with(&self) -> Vec<LuaItemPrototype>
pub fn science_pack(&self) -> LuaItemPrototype
pub fn should_survive(&self) -> bool
pub fn surface(&self) -> &str
pub fn technology(&self) -> LuaTechnologyPrototype
pub fn to_build(&self) -> LuaEntityPrototype
pub fn to_kill(&self) -> Vec<LuaEntityPrototype>
pub fn to_use(&self) -> LuaItemPrototype
pub fn type_not_to_kill(&self) -> &str
pub fn type_of_dealer(&self) -> &str
pub fn type_to_kill(&self) -> &str
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn within(&self) -> u32