pub struct LuaActiveTriggerPrototype;Expand description
Prototype of an Active Trigger.
Implementations
Sourceimpl LuaActiveTriggerPrototype
impl LuaActiveTriggerPrototype
Sourcepub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
Extra description items in the tooltip and Factoriopedia.
Sourcepub fn factoriopedia_description(&self) -> &str
pub fn factoriopedia_description(&self) -> &str
Provides additional description used in factoriopedia.
pub fn localised_description(&self) -> &str
pub fn localised_name(&self) -> &str
Sourcepub fn order(&self) -> &str
pub fn order(&self) -> &str
The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.
pub fn parameter(&self) -> bool
Sourcepub fn fork_chance(&self) -> f64
pub fn fork_chance(&self) -> f64
The chance that a new fork will spawn after each jump [0,1]. default = 0.
Sourcepub fn jump_delay_ticks(&self) -> u32
pub fn jump_delay_ticks(&self) -> u32
The tick delay between each jump. 0 = all jumps instantaneous. default = 0.
Sourcepub fn max_forks(&self) -> u32
pub fn max_forks(&self) -> u32
maximum number of forks allowed to spawn for the entire chain. default = infinity.
Sourcepub fn max_forks_per_jump(&self) -> u32
pub fn max_forks_per_jump(&self) -> u32
The maximum number of forks that can spawn from a single jump. default = 1.
Sourcepub fn max_range(&self) -> f64
pub fn max_range(&self) -> f64
The max distance jumps are allowed to travel away from the original target. default = infinity.
Sourcepub fn max_range_per_jump(&self) -> f64
pub fn max_range_per_jump(&self) -> f64
The max length of jumps. default = 5.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.