LuaAssemblingMachineControlBehavior

Struct LuaAssemblingMachineControlBehavior 

pub struct LuaAssemblingMachineControlBehavior;
Control behavior for assembling machines.

Implementations

Source

impl LuaAssemblingMachineControlBehavior

pub fn entity(&self) -> LuaEntity

The entity this control behavior belongs to.

pub fn input_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to read signals from. Defaults to both wire colors.

nil if this control behavior does not allow selecting the input networks.

pub fn output_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to send signals to. Defaults to both wire colors.

nil if this control behavior does not allow selecting the output networks.

pub fn type(&self) -> &str

The concrete type of this control behavior.

pub fn circuit_condition(&self) -> CircuitConditionDefinition

The circuit condition. Writing nil clears the circuit condition.

pub fn circuit_enable_disable(&self) -> bool

true if this entity enable/disable state is controlled by circuit condition

pub fn connect_to_logistic_network(&self) -> bool

true if this should connect to the logistic network.

pub fn disabled(&self) -> bool

If the entity is currently disabled because of the control behavior.

pub fn logistic_condition(&self) -> CircuitConditionDefinition

The logistic condition. Writing nil clears the logistic condition.

pub fn circuit_read_contents(&self) -> bool

true if the assembling machine reads its ingredients contents, product contents, materials in crafting and trash inventories.

pub fn circuit_read_ingredients(&self) -> bool

true if the assembling machine outputs ingredients of current recipe as a signals to circuit network.

pub fn circuit_read_recipe_finished(&self) -> bool

true if the the assembling machine sends a signal when the recipe finishes.

pub fn circuit_read_working(&self) -> bool

true if the the assembling machine sends a signal when it is working.

pub fn circuit_recipe_finished_signal(&self) -> SignalID

The signal sent when the assembling machine finishes a recipe.

pub fn circuit_set_recipe(&self) -> bool

true if the assembling machine sets its recipe from the circuit network.

See Circuit Recipe Selection for how that recipe is chosen.

pub fn circuit_working_signal(&self) -> SignalID

The signal sent when the assembling machine is working.

pub fn include_in_crafting(&self) -> bool

true if the read contents should include items in crafting.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn read_fuel(&self) -> bool

true if the fuel (content of energy source) should be read.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>