LuaBurner

Struct LuaBurner 

pub struct LuaBurner;
A reference to the burner energy source owned by a specific LuaEntity or LuaEquipment.

Implementations

Source

impl LuaBurner

pub fn burnt_result_inventory(&self) -> LuaInventory

The burnt result inventory.

pub fn currently_burning(&self) -> ItemIDAndQualityIDPair

The currently burning item. Writing nil will void the currently burning item without producing a LuaBurner::burnt_result.

Writing to this automatically handles correcting LuaBurner::remaining_burning_fuel.

pub fn fuel_categories(&self) -> HashMap<String, bool>

The fuel categories this burner uses.

The value in the dictionary is meaningless and exists just to allow for easy lookup.

pub fn heat(&self) -> f64

The current heat (energy) stored in this burner.

pub fn heat_capacity(&self) -> f64

The maximum heat (maximum energy) that this burner can store.

pub fn inventory(&self) -> LuaInventory

The fuel inventory.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn owner(&self) -> LuaAny

The owner of this burner energy source

pub fn remaining_burning_fuel(&self) -> f64

The amount of energy left in the currently-burning fuel item.

Writing to this will silently do nothing if there’s no LuaBurner::currently_burning set.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.