LuaBurnerPrototype

Struct LuaBurnerPrototype 

pub struct LuaBurnerPrototype;
Prototype of a burner energy source.

Implementations

Source

impl LuaBurnerPrototype

pub fn auto_refuel(&self) -> bool

pub fn burnt_inventory_size(&self) -> u32

pub fn effectivity(&self) -> f64

pub fn emissions_per_joule(&self) -> HashMap<String, f64>

The table of emissions of this energy source in pollution/Joule, indexed by pollutant type. Multiplying it by energy consumption in Watt gives pollution/second.

pub fn fuel_categories(&self) -> HashMap<String, bool>

The value in the dictionary is meaningless and exists just to allow for easy lookup.

pub fn fuel_inventory_size(&self) -> u32

pub fn initial_fuel(&self) -> LuaItemPrototype

pub fn initial_fuel_percent(&self) -> f64

pub fn light_flicker(&self) -> LuaBurnerPrototypeLightFlicker

The light flicker definition for this burner prototype.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn render_no_network_icon(&self) -> bool

pub fn render_no_power_icon(&self) -> bool

pub fn smoke(&self) -> Vec<SmokeSource>

The smoke sources for this burner prototype.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.