pub struct LuaCombinatorControlBehavior;Implementations
Sourceimpl LuaCombinatorControlBehavior
impl LuaCombinatorControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn signals_last_tick(&self) -> Vec<Signal>
pub fn signals_last_tick(&self) -> Vec<Signal>
The circuit network signals sent by this combinator last tick.
pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>
Sourcepub fn get_signal_last_tick(&self, signal: SignalID) -> Option<i32>
pub fn get_signal_last_tick(&self, signal: SignalID) -> Option<i32>
Gets the value of a specific signal sent by this combinator behavior last tick or nil if the signal didn’t exist.