pub struct LuaConstantCombinatorControlBehavior;Expand description
Control behavior for constant combinators.
Implementations
Sourceimpl LuaConstantCombinatorControlBehavior
impl LuaConstantCombinatorControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn sections(&self) -> Vec<LuaLogisticSection>
pub fn sections(&self) -> Vec<LuaLogisticSection>
All logistic sections of this constant combinator.
Sourcepub fn sections_count(&self) -> u32
pub fn sections_count(&self) -> u32
Amount of logistic sections this constant combinator has.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>
Sourcepub fn add_section(&self, group: Option<&str>) -> Option<LuaLogisticSection>
pub fn add_section(&self, group: Option<&str>) -> Option<LuaLogisticSection>
Adds a new logistic section to this constant combinator if possible.
Sourcepub fn get_section(&self, section_index: u32) -> Option<LuaLogisticSection>
pub fn get_section(&self, section_index: u32) -> Option<LuaLogisticSection>
Gets section on the selected index, if it exists.
Sourcepub fn remove_section(&self, section_index: u32) -> bool
pub fn remove_section(&self, section_index: u32) -> bool
Removes the given logistic section if possible. Removal may fail if the section index is out of range or the section is not manual.