LuaControlBehavior

Struct LuaControlBehavior 

pub struct LuaControlBehavior;
The control behavior for an entity. Inserters have logistic network and circuit network behavior logic, lamps have circuit logic and so on. This is an abstract base class that concrete control behaviors inherit.

An control reference becomes invalid once the control behavior is removed or the entity (see LuaEntity) it resides in is destroyed.

Implementations

Source

impl LuaControlBehavior

pub fn entity(&self) -> LuaEntity

The entity this control behavior belongs to.

pub fn input_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to read signals from. Defaults to both wire colors.

nil if this control behavior does not allow selecting the input networks.

pub fn output_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to send signals to. Defaults to both wire colors.

nil if this control behavior does not allow selecting the output networks.

pub fn type(&self) -> &str

The concrete type of this control behavior.

pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>