pub struct LuaCustomChartTag;Expand description
A custom tag that shows on the map view.
Implementations
Sourceimpl LuaCustomChartTag
impl LuaCustomChartTag
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn position(&self) -> MapPosition
pub fn position(&self) -> MapPosition
The position of this tag.
Sourcepub fn surface(&self) -> LuaSurface
pub fn surface(&self) -> LuaSurface
The surface this tag belongs to.
Sourcepub fn tag_number(&self) -> u32
pub fn tag_number(&self) -> u32
The unique ID for this tag on this force.
pub fn text(&self) -> &str
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.