pub struct LuaCustomInputPrototype;Expand description
Prototype of a custom input.
Implementations
Sourceimpl LuaCustomInputPrototype
impl LuaCustomInputPrototype
Sourcepub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
Extra description items in the tooltip and Factoriopedia.
Sourcepub fn factoriopedia_description(&self) -> &str
pub fn factoriopedia_description(&self) -> &str
Provides additional description used in factoriopedia.
pub fn localised_description(&self) -> &str
pub fn localised_name(&self) -> &str
Sourcepub fn order(&self) -> &str
pub fn order(&self) -> &str
The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.
pub fn parameter(&self) -> bool
Sourcepub fn alternative_key_sequence(&self) -> &str
pub fn alternative_key_sequence(&self) -> &str
The default alternative key sequence for this custom input, if any
Sourcepub fn consuming(&self) -> LuaCustomInputPrototypeConsuming
pub fn consuming(&self) -> LuaCustomInputPrototypeConsuming
The consuming type.
Sourcepub fn controller_alternative_key_sequence(&self) -> &str
pub fn controller_alternative_key_sequence(&self) -> &str
The default controller alternative key sequence for this custom input, if any
Sourcepub fn controller_key_sequence(&self) -> &str
pub fn controller_key_sequence(&self) -> &str
The default controller key sequence for this custom input, if any
Sourcepub fn enabled(&self) -> bool
pub fn enabled(&self) -> bool
Whether this custom input is enabled. Disabled custom inputs exist but are not used by the game.
Sourcepub fn enabled_while_in_cutscene(&self) -> bool
pub fn enabled_while_in_cutscene(&self) -> bool
Whether this custom input is enabled while using the cutscene controller.
Sourcepub fn enabled_while_spectating(&self) -> bool
pub fn enabled_while_spectating(&self) -> bool
Whether this custom input is enabled while using the spectator controller.
Sourcepub fn include_selected_prototype(&self) -> bool
pub fn include_selected_prototype(&self) -> bool
Whether this custom input will include the selected prototype (if any) when triggered.
Sourcepub fn item_to_spawn(&self) -> LuaItemPrototype
pub fn item_to_spawn(&self) -> LuaItemPrototype
The item that gets spawned when this custom input is fired, if any.
Sourcepub fn key_sequence(&self) -> &str
pub fn key_sequence(&self) -> &str
The default key sequence for this custom input.
Sourcepub fn linked_game_control(&self) -> LinkedGameControl
pub fn linked_game_control(&self) -> LinkedGameControl
The linked game control name, if any.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.