pub struct LuaEntityExtractFluidParams {
pub amount: LuaAny,
pub maximum_temperature: f64,
pub minimum_temperature: f64,
pub name: String,
pub temperature: f64,
}Expand description
Remove fluid from this entity.
If temperature is given only fluid matching that exact temperature is removed. If minimum and maximum is given fluid within that range is removed.
Fields
amount: LuaAnyAmount to remove
maximum_temperature: f64minimum_temperature: f64name: StringFluid prototype name.
temperature: f64Trait Implementations
Sourceimpl Clone for LuaEntityExtractFluidParams
impl Clone for LuaEntityExtractFluidParams
Sourcefn clone(&self) -> LuaEntityExtractFluidParams
fn clone(&self) -> LuaEntityExtractFluidParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LuaEntityExtractFluidParams
impl Debug for LuaEntityExtractFluidParams
Sourceimpl Default for LuaEntityExtractFluidParams
impl Default for LuaEntityExtractFluidParams
Sourcefn default() -> LuaEntityExtractFluidParams
fn default() -> LuaEntityExtractFluidParams
Returns the “default value” for a type. Read more