LuaEquipmentGrid

Struct LuaEquipmentGrid 

pub struct LuaEquipmentGrid;
An equipment grid is for example the inside of a power armor.

Implementations

Source

impl LuaEquipmentGrid

pub fn available_in_batteries(&self) -> f64

The total energy stored in all batteries in the equipment grid.

pub fn battery_capacity(&self) -> f64

Total energy storage capacity of all batteries in the equipment grid.

pub fn entity_owner(&self) -> LuaEntity

The entity that this equipment grid is owned by (in some inventory or item stack.)

If the owning entity is a character owned by some player and the player is disconnected this will return nil.

pub fn equipment(&self) -> Vec<LuaEquipment>

All the equipment in this grid.

pub fn height(&self) -> u32

Height of the equipment grid.

pub fn inhibit_movement_bonus(&self) -> bool

Whether this grid’s equipment movement bonus is active.

pub fn inventory_bonus(&self) -> u32

The total amount of inventory bonus this equipment grid gives.

pub fn itemstack_owner(&self) -> LuaItemStack

The item stack that this equipment grid is owned by.

pub fn max_shield(&self) -> f32

The maximum amount of shield hitpoints this equipment grid has across all shield equipment.

pub fn max_solar_energy(&self) -> f64

Maximum energy per tick that can be created by all solar panels in the equipment grid on the current surface. Actual generated energy varies depending on the daylight levels.

pub fn movement_bonus(&self) -> f64

The total amount of movement bonus this equipment grid gives.

Returns 0 if LuaEquipmentGrid::inhibit_movement_bonus is true.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn player_owner(&self) -> LuaPlayer

The player that this equipment grid is owned by (in some inventory or item stack.)

pub fn prototype(&self) -> LuaEquipmentGridPrototype

pub fn shield(&self) -> f32

The amount of shield hitpoints this equipment grid currently has across all shield equipment.

pub fn unique_id(&self) -> u32

Unique identifier of this equipment grid.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn width(&self) -> u32

Width of the equipment grid.

pub fn can_move(&self, params: LuaEquipmentGridCanMoveParams) -> bool

Check whether moving an equipment would succeed.

pub fn cancel_removal(&self, equipment: LuaEquipment) -> bool

Cancels removal for the given equipment.

pub fn clear(&self, by_player: Option<LuaAny>)

Clear all equipment from the grid, removing it without actually returning it.

pub fn count(&self, equipment: Option<LuaAny>) -> u32

Get the number of all or some equipment in this grid.

pub fn find( &self, equipment: LuaAny, search_ghosts: Option<bool>, ) -> Option<LuaEquipment>

Find equipment by name.

pub fn get(&self, position: EquipmentPosition) -> Option<LuaEquipment>

Find equipment in the Equipment Grid colliding with this position.

pub fn get_contents(&self) -> Vec<EquipmentWithQualityCounts>

Get counts of all equipment in this grid.

pub fn get_generator_energy(&self, quality: Option<LuaAny>) -> f64

Total energy per tick generated by the equipment inside this grid.

pub fn move(&self, params: LuaEquipmentGridMoveParams) -> bool

Move an equipment within this grid.

pub fn order_removal(&self, equipment: LuaEquipment) -> bool

Marks the given equipment for removal. If the given equipment is a ghost it is removed.

pub fn put(&self, params: LuaEquipmentGridPutParams) -> Option<LuaEquipment>

Insert an equipment into the grid.

pub fn revive(&self, equipment: LuaEquipment) -> LuaEquipment

Revives the given equipment ghost if possible.

pub fn take( &self, params: LuaEquipmentGridTakeParams, ) -> Option<ItemWithQualityCount>

Remove an equipment from the grid.

pub fn take_all(&self, by_player: Option<LuaAny>) -> Vec<ItemWithQualityCount>

Remove all equipment from the grid.