pub struct LuaEquipmentPrototype;Expand description
Prototype of a modular equipment.
Implementations
Sourceimpl LuaEquipmentPrototype
impl LuaEquipmentPrototype
Sourcepub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
Extra description items in the tooltip and Factoriopedia.
Sourcepub fn factoriopedia_description(&self) -> &'static str
pub fn factoriopedia_description(&self) -> &'static str
Provides additional description used in factoriopedia.
pub fn localised_description(&self) -> &'static str
pub fn localised_name(&self) -> &'static str
Sourcepub fn order(&self) -> &'static str
pub fn order(&self) -> &'static str
The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.
pub fn parameter(&self) -> bool
Sourcepub fn attack_parameters(&self) -> AttackParameters
pub fn attack_parameters(&self) -> AttackParameters
The equipment attack parameters.
Sourcepub fn automatic(&self) -> bool
pub fn automatic(&self) -> bool
Whether this active defense equipment is automatic. Returns false if not active defense equipment.
Sourcepub fn background_color(&self) -> Color
pub fn background_color(&self) -> Color
The background color of this equipment prototype.
Sourcepub fn burner_prototype(&self) -> LuaBurnerPrototype
pub fn burner_prototype(&self) -> LuaBurnerPrototype
The burner energy source prototype this equipment uses, if any.
pub fn darkness_to_turn_on(&self) -> f32
Sourcepub fn electric_energy_source_prototype(
&self,
) -> LuaElectricEnergySourcePrototype
pub fn electric_energy_source_prototype( &self, ) -> LuaElectricEnergySourcePrototype
The electric energy source prototype this equipment uses, if any.
Sourcepub fn energy_per_shield(&self) -> f64
pub fn energy_per_shield(&self) -> f64
The energy per shield point restored. 0 for non-shield equipment.
Sourcepub fn energy_production(&self) -> f64
pub fn energy_production(&self) -> f64
The max power generated by this equipment.
Sourcepub fn energy_source(&self) -> LuaElectricEnergySourcePrototype
pub fn energy_source(&self) -> LuaElectricEnergySourcePrototype
The energy source prototype for the equipment.
Sourcepub fn equipment_categories(&self) -> Vec<&'static str>
pub fn equipment_categories(&self) -> Vec<&'static str>
Category names for this equipment. These categories will be used to determine whether this equipment is allowed in a particular equipment grid.
pub fn gui_mode(&self) -> LuaEntityPrototypeGuiMode
Sourcepub fn logistic_parameters(&self) -> LuaEquipmentPrototypeLogisticParameters
pub fn logistic_parameters(&self) -> LuaEquipmentPrototypeLogisticParameters
The logistic parameters for this roboport equipment.
Sourcepub fn object_name(&self) -> &'static str
pub fn object_name(&self) -> &'static str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn shape(&self) -> LuaEquipmentPrototypeShape
pub fn shape(&self) -> LuaEquipmentPrototypeShape
Shape of this equipment prototype.
pub fn solar_panel_performance_at_day(&self) -> f64
pub fn solar_panel_performance_at_night(&self) -> f64
pub fn solar_panel_solar_coefficient_property( &self, ) -> LuaSurfacePropertyPrototype
Sourcepub fn take_result(&self) -> LuaItemPrototype
pub fn take_result(&self) -> LuaItemPrototype
The result item when taking this equipment out of an equipment grid, if any.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_energy_consumption(&self, quality: Option<QualityID>) -> f64
pub fn get_inventory_bonus(&self, quality: Option<QualityID>) -> Option<u32>
pub fn get_movement_bonus(&self, quality: Option<QualityID>) -> Option<f32>
Sourcepub fn get_shield(&self, quality: Option<QualityID>) -> f32
pub fn get_shield(&self, quality: Option<QualityID>) -> f32
The shield value of this equipment. 0 for non-shield equipment.