pub struct LuaFluidBoxPrototype;Expand description
A prototype of a fluidbox owned by some LuaEntityPrototype.
Implementations
Sourceimpl LuaFluidBoxPrototype
impl LuaFluidBoxPrototype
Sourcepub fn entity(&self) -> LuaEntityPrototype
pub fn entity(&self) -> LuaEntityPrototype
The entity that this belongs to.
Sourcepub fn filter(&self) -> LuaFluidPrototype
pub fn filter(&self) -> LuaFluidPrototype
The filter, if any is set.
Sourcepub fn maximum_temperature(&self) -> f64
pub fn maximum_temperature(&self) -> f64
The maximum temperature, if any is set.
Sourcepub fn minimum_temperature(&self) -> f64
pub fn minimum_temperature(&self) -> f64
The minimum temperature, if any is set.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn pipe_connections(&self) -> Vec<PipeConnectionDefinition>
pub fn pipe_connections(&self) -> Vec<PipeConnectionDefinition>
The pipe connection points.
Sourcepub fn production_type(&self) -> ProductionType
pub fn production_type(&self) -> ProductionType
The production type.
Sourcepub fn render_layer(&self) -> LuaAny
pub fn render_layer(&self) -> LuaAny
The render layer.
Sourcepub fn secondary_draw_orders(&self) -> Vec<i32>
pub fn secondary_draw_orders(&self) -> Vec<i32>
The secondary draw orders for the 4 possible connection directions.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
Sourcepub fn get_volume(&self, quality: Option<LuaAny>) -> f64
pub fn get_volume(&self, quality: Option<LuaAny>) -> f64
Gets the volume of this fluidbox with the given quality.