pub struct LuaFluidPrototype;Expand description
Prototype of a fluid.
Implementations
Sourceimpl LuaFluidPrototype
impl LuaFluidPrototype
Sourcepub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
pub fn custom_tooltip_fields(&self) -> Vec<CustomTooltipField>
Extra description items in the tooltip and Factoriopedia.
Sourcepub fn factoriopedia_description(&self) -> &str
pub fn factoriopedia_description(&self) -> &str
Provides additional description used in factoriopedia.
pub fn localised_description(&self) -> &str
pub fn localised_name(&self) -> &str
Sourcepub fn order(&self) -> &str
pub fn order(&self) -> &str
The string used to alphabetically sort these prototypes. It is a simple string that has no additional semantic meaning.
pub fn parameter(&self) -> bool
pub fn base_color(&self) -> Color
Sourcepub fn default_temperature(&self) -> f64
pub fn default_temperature(&self) -> f64
Default temperature of this fluid.
Sourcepub fn emissions_multiplier(&self) -> f64
pub fn emissions_multiplier(&self) -> f64
A multiplier on the amount of emissions produced when this fluid is burnt in a generator. A value above 1.0 increases emissions and vice versa. The multiplier can’t be negative.
Sourcepub fn factoriopedia_alternative(&self) -> LuaFluidPrototype
pub fn factoriopedia_alternative(&self) -> LuaFluidPrototype
An alternative prototype that will be used to display info about this prototype in Factoriopedia.
pub fn flow_color(&self) -> Color
Sourcepub fn fuel_value(&self) -> f64
pub fn fuel_value(&self) -> f64
The amount of energy in Joules one unit of this fluid will produce when burnt in a generator. A value of 0 means this fluid can’t be used for energy generation. The value can’t be negative.
Sourcepub fn gas_temperature(&self) -> f64
pub fn gas_temperature(&self) -> f64
The temperature above which this fluid will be shown as gaseous inside tanks and pipes.
Sourcepub fn heat_capacity(&self) -> f64
pub fn heat_capacity(&self) -> f64
The amount of energy in Joules required to heat one unit of this fluid by 1°C.
Sourcepub fn max_temperature(&self) -> f64
pub fn max_temperature(&self) -> f64
Maximum temperature this fluid can reach.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
pub fn spent_fluid(&self) -> SpentFluidSpecification
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn visualization_color(&self) -> Color