LuaGenericOnOffControlBehavior

Struct LuaGenericOnOffControlBehavior 

pub struct LuaGenericOnOffControlBehavior;
An abstract base class for behaviors that support switching the entity on or off based on some condition.

Implementations

Source

impl LuaGenericOnOffControlBehavior

pub fn entity(&self) -> LuaEntity

The entity this control behavior belongs to.

pub fn input_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to read signals from. Defaults to both wire colors.

nil if this control behavior does not allow selecting the input networks.

pub fn output_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to send signals to. Defaults to both wire colors.

nil if this control behavior does not allow selecting the output networks.

pub fn type(&self) -> &str

The concrete type of this control behavior.

pub fn circuit_condition(&self) -> CircuitConditionDefinition

The circuit condition. Writing nil clears the circuit condition.

pub fn circuit_enable_disable(&self) -> bool

true if this entity enable/disable state is controlled by circuit condition

pub fn connect_to_logistic_network(&self) -> bool

true if this should connect to the logistic network.

pub fn disabled(&self) -> bool

If the entity is currently disabled because of the control behavior.

pub fn logistic_condition(&self) -> CircuitConditionDefinition

The logistic condition. Writing nil clears the logistic condition.

pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>