LuaGuiElementAddParams

Struct LuaGuiElementAddParams 

pub struct LuaGuiElementAddParams {
Show 15 fields pub anchor: GuiAnchor, pub caption: String, pub elem_tooltip: ElemID, pub enabled: bool, pub game_controller_interaction: String, pub ignored_by_interaction: bool, pub index: u32, pub locked: bool, pub name: String, pub raise_hover_events: bool, pub style: String, pub tags: LuaAny, pub tooltip: String, pub type: GuiElementType, pub visible: bool,
}
Add a new child element to this GuiElement.

Fields

anchor: GuiAnchor

Where to position the child element when in the relative element.

caption: String

Text displayed on the child element. For frames, this is their title. For other elements, like buttons or labels, this is the content. Whilst this attribute may be used on all elements, it doesn’t make sense for tables and flows as they won’t display it.

elem_tooltip: ElemID

Elem tooltip of the child element. Will be displayed above tooltip.

enabled: bool

Whether the child element is enabled. Defaults to true.

game_controller_interaction: String

How the element should interact with game controllers. Defaults to defines.game_controller_interaction.normal.

ignored_by_interaction: bool

Whether the child element is ignored by interaction. Defaults to false.

index: u32

Location in its parent that the child element should slot into. By default, the child will be appended onto the end.

locked: bool

Whether the child element is locked. Defaults to false.

name: String

Name of the child element. It must be unique within the parent element.

raise_hover_events: bool

Whether this element will raise on_gui_hover and on_gui_leave. Defaults to false.

style: String

The name of the style prototype to apply to the new element.

tags: LuaAny

Tags associated with the child element.

tooltip: String

Tooltip of the child element.

type: GuiElementType

The kind of element to add, which potentially has its own attributes as listed below.

visible: bool

Whether the child element is visible. Defaults to true.