pub struct LuaGuiElementAddParams {Show 15 fields
pub anchor: GuiAnchor,
pub caption: String,
pub elem_tooltip: ElemID,
pub enabled: bool,
pub game_controller_interaction: String,
pub ignored_by_interaction: bool,
pub index: u32,
pub locked: bool,
pub name: String,
pub raise_hover_events: bool,
pub style: String,
pub tags: LuaAny,
pub tooltip: String,
pub type: GuiElementType,
pub visible: bool,
}Expand description
Add a new child element to this GuiElement.
Fields
anchor: GuiAnchorWhere to position the child element when in the relative element.
caption: StringText displayed on the child element. For frames, this is their title. For other elements, like buttons or labels, this is the content. Whilst this attribute may be used on all elements, it doesn’t make sense for tables and flows as they won’t display it.
elem_tooltip: ElemIDElem tooltip of the child element. Will be displayed above tooltip.
enabled: boolWhether the child element is enabled. Defaults to true.
game_controller_interaction: StringHow the element should interact with game controllers. Defaults to defines.game_controller_interaction.normal.
ignored_by_interaction: boolWhether the child element is ignored by interaction. Defaults to false.
index: u32Location in its parent that the child element should slot into. By default, the child will be appended onto the end.
locked: boolWhether the child element is locked. Defaults to false.
name: StringName of the child element. It must be unique within the parent element.
raise_hover_events: boolWhether this element will raise on_gui_hover and on_gui_leave. Defaults to false.
style: StringThe name of the style prototype to apply to the new element.
Tags associated with the child element.
tooltip: StringTooltip of the child element.
type: GuiElementTypeThe kind of element to add, which potentially has its own attributes as listed below.
visible: boolWhether the child element is visible. Defaults to true.