LuaHeatBufferPrototype

Struct LuaHeatBufferPrototype 

pub struct LuaHeatBufferPrototype;
Prototype of a heat buffer.

Implementations

Source

impl LuaHeatBufferPrototype

pub fn connections(&self) -> Vec<HeatConnectionDefinition>

pub fn default_temperature(&self) -> f64

pub fn max_temperature(&self) -> f64

pub fn max_transfer(&self) -> f64

pub fn min_temperature_gradient(&self) -> f64

pub fn min_working_temperature(&self) -> f64

pub fn minimum_glow_temperature(&self) -> f64

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn specific_heat(&self) -> f64

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.