pub struct LuaInserterControlBehavior;Expand description
Control behavior for inserters.
Implementations
Sourceimpl LuaInserterControlBehavior
impl LuaInserterControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn circuit_condition(&self) -> CircuitConditionDefinition
pub fn circuit_condition(&self) -> CircuitConditionDefinition
The circuit condition. Writing nil clears the circuit condition.
Sourcepub fn circuit_enable_disable(&self) -> bool
pub fn circuit_enable_disable(&self) -> bool
true if this entity enable/disable state is controlled by circuit condition
Sourcepub fn connect_to_logistic_network(&self) -> bool
pub fn connect_to_logistic_network(&self) -> bool
true if this should connect to the logistic network.
Sourcepub fn disabled(&self) -> bool
pub fn disabled(&self) -> bool
If the entity is currently disabled because of the control behavior.
Sourcepub fn logistic_condition(&self) -> CircuitConditionDefinition
pub fn logistic_condition(&self) -> CircuitConditionDefinition
The logistic condition. Writing nil clears the logistic condition.
Sourcepub fn circuit_hand_read_mode(&self) -> &str
pub fn circuit_hand_read_mode(&self) -> &str
The hand read mode for the inserter.
Sourcepub fn circuit_read_hand_contents(&self) -> bool
pub fn circuit_read_hand_contents(&self) -> bool
true if the contents of the inserter hand should be sent to the circuit network
Sourcepub fn circuit_set_filters(&self) -> bool
pub fn circuit_set_filters(&self) -> bool
true if filters are set from circuit network
Sourcepub fn circuit_set_stack_size(&self) -> bool
pub fn circuit_set_stack_size(&self) -> bool
If the stack size of the inserter is set through the circuit network or not.
Sourcepub fn circuit_stack_control_signal(&self) -> SignalID
pub fn circuit_stack_control_signal(&self) -> SignalID
The signal used to set the stack size of the inserter.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>