pub struct LuaItemCommonCreateBlueprintParams {
pub always_include_tiles: bool,
pub area: BoundingBox,
pub force: LuaAny,
pub include_entities: bool,
pub include_fuel: bool,
pub include_modules: bool,
pub include_station_names: bool,
pub include_trains: bool,
pub surface: LuaAny,
}Expand description
Sets up this blueprint using the found blueprintable entities/tiles on the surface.
Fields
always_include_tiles: boolWhen true, blueprintable tiles are always included in the blueprint. When false they’re only included if no entities exist in the setup area. Defaults to false.
area: BoundingBoxThe bounding box
force: LuaAnyForce to use for the creation
include_entities: boolWhen true, entities are included in the blueprint. Defaults to true.
include_fuel: boolWhen true, train fuel is included in the blueprint, Defaults to true.
include_modules: boolWhen true, modules are included in the blueprint. Defaults to true.
include_station_names: boolWhen true, station names are included in the blueprint. Defaults to false.
include_trains: boolWhen true, trains are included in the blueprint. Defaults to false.
surface: LuaAnySurface to create from