pub struct LuaLogisticNetworkSelectPickupPointParams {
pub include_buffers: bool,
pub members: LuaLogisticNetworkMembers2,
pub name: ItemWithQualityID,
pub position: MapPosition,
}Expand description
Find the ‘best’ logistic point with this item ID and from the given position or from given chest type.
Fields
include_buffers: boolWhether to consider buffer chests or not. Defaults to false. Only considered if selecting with position.
members: LuaLogisticNetworkMembers2When given, it will find from only the specific type of member. If not specified, selects with normal priorities. Not considered if position is specified.
name: ItemWithQualityIDName of the item to pick up.
position: MapPositionWhen given, it will find the storage ‘best’ storage point from this position.