pub struct LuaLogisticPoint;Expand description
Logistic point of a particular LuaEntity. A “Logistic point” is the name given for settings and properties used by requester, provider, and storage points in a given logistic network. These “points” don’t have to be a logistic container but often are. One other entity that can own several points is the “character” character type entity.
Implementations
Sourceimpl LuaLogisticPoint
impl LuaLogisticPoint
Sourcepub fn enabled(&self) -> bool
pub fn enabled(&self) -> bool
Whether this logistic point is active, related to disabling logistics on player/spidertron.
When the logistic point is disabled it won’t request and auto trash will do nothing.
Sourcepub fn exact(&self) -> bool
pub fn exact(&self) -> bool
If this logistic point is using the exact mode. In exact mode robots never over-deliver requests.
Sourcepub fn filters(&self) -> Vec<CompiledLogisticFilter>
pub fn filters(&self) -> Vec<CompiledLogisticFilter>
The logistic filters for this logistic point, if this uses any.
The returned array will always have an entry for each filter and will be indexed in sequence when not nil.
Sourcepub fn force(&self) -> LuaForce
pub fn force(&self) -> LuaForce
The force of this logistic point.
This will always be the same as the LuaLogisticPoint::owner force.
Sourcepub fn logistic_member_index(&self) -> &str
pub fn logistic_member_index(&self) -> &str
The Logistic member index of this logistic point.
pub fn logistic_network(&self) -> LuaLogisticNetwork
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn sections(&self) -> Vec<LuaLogisticSection>
pub fn sections(&self) -> Vec<LuaLogisticSection>
All logistic sections of this logistic point.
Sourcepub fn sections_count(&self) -> u32
pub fn sections_count(&self) -> u32
Amount of logistic sections this logistic point has.
Sourcepub fn targeted_items_deliver(&self) -> Vec<ItemWithQualityCount>
pub fn targeted_items_deliver(&self) -> Vec<ItemWithQualityCount>
Items targeted to be dropped off into this logistic point by robots or cargo pods.
Sourcepub fn targeted_items_pickup(&self) -> Vec<ItemWithQualityCount>
pub fn targeted_items_pickup(&self) -> Vec<ItemWithQualityCount>
Items targeted to be picked up from this logistic point by robots.
Sourcepub fn trash_not_requested(&self) -> bool
pub fn trash_not_requested(&self) -> bool
Whether this logistic point is set to trash unrequested items.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
Sourcepub fn add_section(&self, group: Option<&str>) -> Option<LuaLogisticSection>
pub fn add_section(&self, group: Option<&str>) -> Option<LuaLogisticSection>
Adds a new logistic section to this logistic point if possible.
Sourcepub fn get_section(&self, section_index: u32) -> LuaLogisticSection
pub fn get_section(&self, section_index: u32) -> LuaLogisticSection
Gets section on the selected index, if it exists
Sourcepub fn remove_section(&self, section_index: u32) -> bool
pub fn remove_section(&self, section_index: u32) -> bool
Removes the given logistic section if possible. Removal may fail if the section index is out of range or the section is not manual.