pub struct LuaPermissionGroup;Expand description
A permission group that defines what players in this group are allowed to do.
Implementations
Sourceimpl LuaPermissionGroup
impl LuaPermissionGroup
Sourcepub fn name(&self) -> &str
pub fn name(&self) -> &str
The name of this group. Setting the name to nil or an empty string sets the name to the default value.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
Sourcepub fn add_player(&self, player: LuaAny) -> bool
pub fn add_player(&self, player: LuaAny) -> bool
Adds the given player to this group.
Sourcepub fn allows_action(&self, action: &str) -> bool
pub fn allows_action(&self, action: &str) -> bool
Whether this group allows the given action.
Sourcepub fn remove_player(&self, player: LuaAny) -> bool
pub fn remove_player(&self, player: LuaAny) -> bool
Removes the given player from this group.
Sourcepub fn set_allows_action(&self, action: &str, allow_action: bool) -> bool
pub fn set_allows_action(&self, action: &str, allow_action: bool) -> bool
Sets whether this group allows the performance the given action.