pub struct LuaPlayerAddPinParams {
pub always_visible: bool,
pub entity: LuaEntity,
pub label: String,
pub player: LuaAny,
pub position: MapPosition,
pub preview_distance: u16,
pub surface: LuaAny,
}Expand description
Adds a pin to this player for the given pin specification. Either entity, player, or surface and position must be defined.
Fields
always_visible: boolDefaults to true.
entity: LuaEntityThe entity to pin.
label: Stringplayer: LuaAnyThe player to pin.
position: MapPositionWhere to create the pin. Required when surface is defined.
preview_distance: u16Defaults to 16.
surface: LuaAnyThe surface to create the pin on.