pub struct LuaPlayerBuildFromCursorParams {
pub build_mode: String,
pub direction: String,
pub flip_horizontal: bool,
pub flip_vertical: bool,
pub mirror: bool,
pub position: MapPosition,
pub skip_fog_of_war: bool,
pub terrain_building_size: u32,
}Expand description
Builds whatever is in the cursor on the surface the player is on. The cursor stack will automatically be reduced as if the player built normally.
Fields
build_mode: StringWhich build mode should be used instead of normal build. Defaults to defines.build_mode.normal.
direction: StringDirection the entity would be placed
flip_horizontal: boolWhether to flip the blueprint horizontally. Defaults to false.
flip_vertical: boolWhether to flip the blueprint vertically. Defaults to false.
mirror: boolWhether to mirror the entity
position: MapPositionWhere the entity would be placed
skip_fog_of_war: boolIf chunks covered by fog-of-war are skipped. Defaults to false.
terrain_building_size: u32The size for building terrain if building terrain. Defaults to 2.