pub struct LuaPlayerDragWireParams {
pub position: MapPosition,
}Expand description
Start/end wire dragging at the specified location, wire type is based on the cursor contents
Fields
position: MapPositionPosition at which cursor was clicked. Used only to decide which side of arithmetic combinator, decider combinator or power switch is to be connected. Entity itself to be connected is based on the player’s selected entity.