pub struct LuaRailPath;Expand description
A rail path.
Implementations
Sourceimpl LuaRailPath
impl LuaRailPath
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn total_distance(&self) -> f64
pub fn total_distance(&self) -> f64
The total path distance.
Sourcepub fn travelled_distance(&self) -> f64
pub fn travelled_distance(&self) -> f64
The total distance traveled.
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.