pub struct LuaRailSignalBaseControlBehavior;Expand description
Control behavior for rail signals and rail chain signals.
Implementations
Sourceimpl LuaRailSignalBaseControlBehavior
impl LuaRailSignalBaseControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
pub fn blue_signal(&self) -> SignalID
Sourcepub fn circuit_condition(&self) -> CircuitConditionDefinition
pub fn circuit_condition(&self) -> CircuitConditionDefinition
The circuit condition when controlling the signal through the circuit network.
Sourcepub fn close_signal(&self) -> bool
pub fn close_signal(&self) -> bool
If this will close the rail signal based off the circuit condition.
pub fn green_signal(&self) -> SignalID
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
pub fn orange_signal(&self) -> SignalID
Sourcepub fn read_signal(&self) -> bool
pub fn read_signal(&self) -> bool
If this will read the rail signal state.
pub fn red_signal(&self) -> SignalID
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>