LuaRenderObject

Struct LuaRenderObject 

pub struct LuaRenderObject;
Reference to a single LuaRendering object.

Implementations

Source

impl LuaRenderObject

pub fn alignment(&self) -> TextAlign

Alignment of this text.

pub fn angle(&self) -> f32

Angle of this arc. Angle in radian.

pub fn animation(&self) -> &str

Animation prototype name of this animation.

pub fn animation_offset(&self) -> f64

Animation offset of this animation. Animation offset in frames.

pub fn animation_speed(&self) -> f64

Animation speed of this animation. Animation speed in frames per tick.

Blink interval of this object based on the internal “update tick”. When zero, blinking is disabled. For other values, the object will be visible the given number of ticks and then invisible for the same duration. Objects with the same blink interval will blink synchronously. Blink interval of game alerts is 30.

For example, when the interval is 60, the object is visible for 60 ticks and hidden for the next 60.

pub fn color(&self) -> Color

Color or tint of the object.

pub fn dash_length(&self) -> f64

Dash length of this line.

pub fn dash_offset(&self) -> f64

Starting offset to apply to dashes of this line. Cannot be greater than dash_length + gap_length.

pub fn draw_on_ground(&self) -> bool

If this object is being drawn on the ground, under most entities and sprites.

In render_mode == “chart”, this value is unused.

pub fn filled(&self) -> bool

If this circle or rectangle is filled.

pub fn font(&self) -> &str

Font of this text.

pub fn forces(&self) -> Vec<LuaForce>

Forces for which this object is rendered or nil if visible to all forces. Writing nil or empty array will make this object visible to all forces.

pub fn from(&self) -> LuaAny

Where this line is drawn from.

pub fn gap_length(&self) -> f64

Length of the gaps in this line.

pub fn id(&self) -> u64

Unique identifier of this render object.

pub fn intensity(&self) -> f32

Intensity of this light.

pub fn left_top(&self) -> LuaAny

Where top left corner of this rectangle is drawn.

pub fn light_mode(&self) -> ScriptSpriteLightMode

Whether this sprite or animation should be rendered as a sprite, light or both at once.

pub fn max_radius(&self) -> f64

Radius of the outer edge of this arc.

pub fn min_radius(&self) -> f64

Radius of the inner edge of this arc.

pub fn minimum_darkness(&self) -> f32

Minimum darkness at which this light is rendered.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn only_in_alt_mode(&self) -> bool

If this object is only rendered in alt-mode.

pub fn orientation(&self) -> LuaAny

Orientation of this object.

Polygon vertices that are set to an entity will ignore this.

pub fn orientation_target(&self) -> LuaAny

Target to which this object rotates so that it faces the target. Note that orientation is still applied to the object. Writing nil will clear the orientation_target. nil if no target.

Polygon vertices that are set to an entity will ignore this.

pub fn oriented(&self) -> bool

If this light is rendered with the same orientation as the target entity. Note that orientation is still applied to the sprite.

pub fn oriented_offset(&self) -> Vector

Offsets the center of the sprite or animation if orientation_target is given. This offset will rotate together with the sprite or animation.

pub fn players(&self) -> LuaAny

Players for which this object is visible or nil if visible to all players. Writing nil or empty array will make this object visible to all players.

pub fn radius(&self) -> f64

Radius of this circle.

pub fn render_layer(&self) -> LuaAny

Render layer of this sprite or animation.

pub fn render_mode(&self) -> ScriptRenderMode

Whether the object is rendered in game world or on the chart (map view).

When it is changed, the object is pushed to front of its new group.

pub fn right_bottom(&self) -> LuaAny

Where bottom right corner of this rectangle is drawn.

pub fn scale(&self) -> f64

Scale of the text or light.

pub fn scale_with_zoom(&self) -> bool

If this text scales with player zoom.

pub fn sprite(&self) -> SpritePath

Sprite of the sprite or light.

pub fn start_angle(&self) -> f32

Where this arc starts. Angle in radian.

pub fn surface(&self) -> LuaSurface

Surface this object is rendered on.

pub fn target(&self) -> LuaAny

Where this object is drawn.

Polygon vertices that are set to an entity will ignore this.

pub fn text(&self) -> &str

Text that is displayed by this text object.

pub fn time_to_live(&self) -> u32

Time to live of this object. This will be 0 if the object does not expire.

pub fn to(&self) -> LuaAny

Where this line is drawn to.

pub fn type(&self) -> LuaRenderObjectType

Type of this object.

pub fn use_rich_text(&self) -> bool

If this text parses rich text tags.

pub fn use_target_orientation(&self) -> bool

If this object uses the target orientation.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn vertical_alignment(&self) -> VerticalTextAlign

Vertical alignment of this text.

pub fn vertices(&self) -> Vec<LuaAny>

Vertices of this polygon.

pub fn visible(&self) -> bool

If this object is rendered to anyone at all.

pub fn width(&self) -> f32

Width of the object. Value is in pixels (32 per tile).

pub fn x_scale(&self) -> f64

Horizontal scale of this sprite or animation.

pub fn y_scale(&self) -> f64

Vertical scale of this sprite or animation.

pub fn bring_to_front(&self)

Reorder this object so that it is drawn in front of the already existing objects.

pub fn destroy(&self)

Destroys this object. Does not error when the object is invalid.

pub fn move_to_back(&self)

Reorder this object so that it is drawn in the back of the already existing objects.

pub fn set_corners(&self, left_top: LuaAny, right_bottom: LuaAny)

Set the corners of the rectangle with this id.

pub fn set_dashes(&self, dash_length: f64, gap_length: f64)

Set the length of the dashes and the length of the gaps in this line.