pub struct LuaRenderingDrawPolygonParams {Show 15 fields
pub blink_interval: u16,
pub color: Color,
pub draw_on_ground: bool,
pub forces: LuaAny,
pub only_in_alt_mode: bool,
pub orientation: LuaAny,
pub orientation_target: LuaAny,
pub players: Vec<LuaAny>,
pub render_mode: ScriptRenderMode,
pub surface: LuaAny,
pub target: LuaAny,
pub time_to_live: u32,
pub use_target_orientation: bool,
pub vertices: Vec<LuaAny>,
pub visible: bool,
}Expand description
Create a triangle mesh defined by a triangle strip.
Fields
blink_interval: u16In ticks. Defaults to 0 (no blinking). Game alerts use 30.
color: Colordraw_on_ground: boolIf this should be drawn below sprites and entities. Defaults to false.
forces: LuaAnyThe forces that this object is rendered to. Passing nil or an empty table will render it to all forces.
only_in_alt_mode: boolIf this should only be rendered in alt mode. Defaults to false.
orientation: LuaAnyThe orientation applied to all vertices. Default is 0.
orientation_target: LuaAnyIf given, the vertices (that are not set to an entity) rotate so that it faces this target. Note that orientation is still applied.
players: Vec<LuaAny>The players that this object is rendered to. Passing nil or an empty table will render it to all players.
render_mode: ScriptRenderModeMode which this object should render in. Defaults to “game”.
surface: LuaAnytarget: LuaAnyActs like an offset applied to all vertices that are not set to an entity.
time_to_live: u32In ticks. Defaults to living forever.
use_target_orientation: boolOnly used if orientation_target is a LuaEntity.
vertices: Vec<LuaAny>visible: boolIf this is rendered to anyone at all. Defaults to true.