pub struct LuaRenderingDrawSpriteParams {Show 19 fields
pub blink_interval: u16,
pub forces: LuaAny,
pub light_mode: ScriptSpriteLightMode,
pub only_in_alt_mode: bool,
pub orientation: LuaAny,
pub orientation_target: LuaAny,
pub oriented_offset: Vector,
pub players: Vec<LuaAny>,
pub render_layer: LuaAny,
pub render_mode: ScriptRenderMode,
pub sprite: SpritePath,
pub surface: LuaAny,
pub target: LuaAny,
pub time_to_live: u32,
pub tint: Color,
pub use_target_orientation: bool,
pub visible: bool,
pub x_scale: f64,
pub y_scale: f64,
}Expand description
Create a sprite.
Fields
blink_interval: u16In ticks. Defaults to 0 (no blinking). Game alerts use 30.
forces: LuaAnyThe forces that this object is rendered to. Passing nil or an empty table will render it to all forces.
light_mode: ScriptSpriteLightModeWhether this object should be rendered as a sprite, light or both at once. Defaults to “occluder”.
only_in_alt_mode: boolIf this should only be rendered in alt mode. Defaults to false.
orientation: LuaAnyThe orientation of the sprite. Default is 0.
orientation_target: LuaAnyIf given, the sprite rotates so that it faces this target. Note that orientation is still applied to the sprite.
oriented_offset: VectorOffsets the center of the sprite if orientation_target is given. This offset will rotate together with the sprite.
players: Vec<LuaAny>The players that this object is rendered to. Passing nil or an empty table will render it to all players.
render_layer: LuaAnyRender layer of the sprite. Defaults to "arrow".
render_mode: ScriptRenderModeMode which this object should render in. Defaults to “game”.
sprite: SpritePathsurface: LuaAnytarget: LuaAnyCenter of the sprite.
time_to_live: u32In ticks. Defaults to living forever.
tint: Coloruse_target_orientation: boolOnly used if orientation_target is a LuaEntity.
visible: boolIf this is rendered to anyone at all. Defaults to true.
x_scale: f64Horizontal scale of the sprite. Default is 1.
y_scale: f64Vertical scale of the sprite. Default is 1.