pub struct LuaRenderingDrawTextParams {Show 19 fields
pub alignment: Option<TextAlign>,
pub blink_interval: Option<u16>,
pub color: Color,
pub draw_on_ground: Option<bool>,
pub font: Option<String>,
pub forces: Option<ForceSet>,
pub only_in_alt_mode: Option<bool>,
pub orientation: Option<RealOrientation>,
pub players: Option<Vec<PlayerIdentification>>,
pub render_mode: Option<ScriptRenderMode>,
pub scale: Option<f64>,
pub scale_with_zoom: Option<bool>,
pub surface: SurfaceIdentification,
pub target: ScriptRenderTarget,
pub text: String,
pub time_to_live: Option<u32>,
pub use_rich_text: Option<bool>,
pub vertical_alignment: Option<VerticalTextAlign>,
pub visible: Option<bool>,
}Expand description
Create a text.
Not all fonts support scaling.
Fields
alignment: Option<TextAlign>Defaults to “left”.
blink_interval: Option<u16>In ticks. Defaults to 0 (no blinking). Game alerts use 30.
color: Colordraw_on_ground: Option<bool>If this should be drawn below sprites and entities. Rich text does not support this option. Defaults to false.
font: Option<String>Name of font to use. Defaults to the same font as flying-text.
forces: Option<ForceSet>The forces that this object is rendered to. Passing nil or an empty table will render it to all forces.
only_in_alt_mode: Option<bool>If this should only be rendered in alt mode. Defaults to false.
orientation: Option<RealOrientation>The orientation of the text. Default is 0.
players: Option<Vec<PlayerIdentification>>The players that this object is rendered to. Passing nil or an empty table will render it to all players.
render_mode: Option<ScriptRenderMode>Mode which this object should render in. Defaults to “game”.
scale: Option<f64>scale_with_zoom: Option<bool>Defaults to false. If true, the text scales with player zoom, resulting in it always being the same size on screen, and the size compared to the game world changes.
surface: SurfaceIdentificationtarget: ScriptRenderTargettext: StringThe text to display.
time_to_live: Option<u32>In ticks. Defaults to living forever.
use_rich_text: Option<bool>If rich text rendering is enabled. Defaults to false.
vertical_alignment: Option<VerticalTextAlign>Defaults to “top”.
visible: Option<bool>If this is rendered to anyone at all. Defaults to true.