pub struct LuaRenderingDrawTextParams {Show 19 fields
pub alignment: TextAlign,
pub blink_interval: u16,
pub color: Color,
pub draw_on_ground: bool,
pub font: String,
pub forces: LuaAny,
pub only_in_alt_mode: bool,
pub orientation: LuaAny,
pub players: Vec<LuaAny>,
pub render_mode: ScriptRenderMode,
pub scale: f64,
pub scale_with_zoom: bool,
pub surface: LuaAny,
pub target: LuaAny,
pub text: String,
pub time_to_live: u32,
pub use_rich_text: bool,
pub vertical_alignment: VerticalTextAlign,
pub visible: bool,
}Expand description
Create a text.
Not all fonts support scaling.
Fields
alignment: TextAlignDefaults to “left”.
blink_interval: u16In ticks. Defaults to 0 (no blinking). Game alerts use 30.
color: Colordraw_on_ground: boolIf this should be drawn below sprites and entities. Rich text does not support this option. Defaults to false.
font: StringName of font to use. Defaults to the same font as flying-text.
forces: LuaAnyThe forces that this object is rendered to. Passing nil or an empty table will render it to all forces.
only_in_alt_mode: boolIf this should only be rendered in alt mode. Defaults to false.
orientation: LuaAnyThe orientation of the text. Default is 0.
players: Vec<LuaAny>The players that this object is rendered to. Passing nil or an empty table will render it to all players.
render_mode: ScriptRenderModeMode which this object should render in. Defaults to “game”.
scale: f64scale_with_zoom: boolDefaults to false. If true, the text scales with player zoom, resulting in it always being the same size on screen, and the size compared to the game world changes.
surface: LuaAnytarget: LuaAnytext: StringThe text to display.
time_to_live: u32In ticks. Defaults to living forever.
use_rich_text: boolIf rich text rendering is enabled. Defaults to false.
vertical_alignment: VerticalTextAlignDefaults to “top”.
visible: boolIf this is rendered to anyone at all. Defaults to true.