pub struct LuaRoboportControlBehavior;Expand description
Control behavior for roboports.
Implementations
Sourceimpl LuaRoboportControlBehavior
impl LuaRoboportControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
pub fn available_construction_output_signal(&self) -> SignalID
pub fn available_logistic_output_signal(&self) -> SignalID
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn read_items_mode(&self) -> &str
pub fn read_items_mode(&self) -> &str
Selects contents that are to be read from the roboport
Sourcepub fn read_logistics(&self) -> bool
pub fn read_logistics(&self) -> bool
Legacy field, please use LuaRoboportControlBehavior::read_items_mode instead. true if the roboport should report the logistics network content to the circuit network.
Sourcepub fn read_robot_stats(&self) -> bool
pub fn read_robot_stats(&self) -> bool
true if the roboport should report the robot statistics to the circuit network.
pub fn roboport_count_output_signal(&self) -> SignalID
pub fn total_construction_output_signal(&self) -> SignalID
pub fn total_logistic_output_signal(&self) -> SignalID
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>