LuaSpacePlatformHubControlBehavior

Struct LuaSpacePlatformHubControlBehavior 

pub struct LuaSpacePlatformHubControlBehavior;
Control behavior for space platform hubs

Implementations

Source

impl LuaSpacePlatformHubControlBehavior

pub fn entity(&self) -> LuaEntity

The entity this control behavior belongs to.

pub fn input_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to read signals from. Defaults to both wire colors.

nil if this control behavior does not allow selecting the input networks.

pub fn output_networks(&self) -> CircuitNetworkSelection

Which circuit networks (red/green) to send signals to. Defaults to both wire colors.

nil if this control behavior does not allow selecting the output networks.

pub fn type(&self) -> &str

The concrete type of this control behavior.

pub fn damage_taken_signal(&self) -> SignalID

Signal to be transmitted with platform’s damage taken value.

pub fn object_name(&self) -> &str

The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.

pub fn read_contents(&self) -> bool

true if this hub is sending its content to a circuit network

pub fn read_damage_taken(&self) -> bool

Whether damage taken by the space platform is sent to circuit network.

pub fn read_moving_from(&self) -> bool

Whether current connection “from” end is sent to circuit network.

pub fn read_moving_to(&self) -> bool

Whether current connection “to” end is sent to circuit network.

pub fn read_speed(&self) -> bool

Whether current speed of space platform is sent to circuit network.

pub fn send_to_platform(&self) -> bool

Whether the signals are used for circuit conditions in the platform’s schedule

pub fn set_requests(&self) -> bool

pub fn speed_signal(&self) -> SignalID

Signal to be transmitted with platform’s current speed.

pub fn valid(&self) -> bool

Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.

pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>