pub struct LuaSurfaceCloneAreaParams {
pub clear_destination_decoratives: bool,
pub clear_destination_entities: bool,
pub clone_decoratives: bool,
pub clone_entities: bool,
pub clone_tiles: bool,
pub create_build_effect_smoke: bool,
pub destination_area: BoundingBox,
pub destination_force: LuaAny,
pub destination_surface: LuaAny,
pub expand_map: bool,
pub source_area: BoundingBox,
}Expand description
Clones the given area.
Entities are cloned in an order such that they can always be created, eg rails before trains.
Fields
clear_destination_decoratives: boolIf the destination decoratives should be cleared
clear_destination_entities: boolIf the destination entities should be cleared
clone_decoratives: boolIf decoratives should be cloned
clone_entities: boolIf entities should be cloned
clone_tiles: boolIf tiles should be cloned
create_build_effect_smoke: boolIf true, the building effect smoke will be shown around the new entities. Defaults to false.
destination_area: BoundingBoxdestination_force: LuaAnydestination_surface: LuaAnyexpand_map: boolIf the destination surface should be expanded when destination_area is outside current bounds. Defaults to false.
source_area: BoundingBoxTrait Implementations
Sourceimpl Clone for LuaSurfaceCloneAreaParams
impl Clone for LuaSurfaceCloneAreaParams
Sourcefn clone(&self) -> LuaSurfaceCloneAreaParams
fn clone(&self) -> LuaSurfaceCloneAreaParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LuaSurfaceCloneAreaParams
impl Debug for LuaSurfaceCloneAreaParams
Sourceimpl Default for LuaSurfaceCloneAreaParams
impl Default for LuaSurfaceCloneAreaParams
Sourcefn default() -> LuaSurfaceCloneAreaParams
fn default() -> LuaSurfaceCloneAreaParams
Returns the “default value” for a type. Read more