LuaSurfaceCreateSegmentedUnitParams

Struct LuaSurfaceCreateSegmentedUnitParams 

pub struct LuaSurfaceCreateSegmentedUnitParams {
    pub force: LuaAny,
    pub name: LuaAny,
    pub quality: LuaAny,
    pub territory: LuaTerritory,
}
Create a segmented unit on the surface. This differs from creating an entity with type "segmented-unit" in that this method can create the entity in non-generated chunks and with any arbitrary body shape and pre-assigned to a territory.

Fields

force: LuaAny

Force of the segmented unit. Defaults to enemy.

name: LuaAny

The segmented-unit prototype name to create. Must be of type "segmented-unit".

quality: LuaAny

Quality of the entity to be created. Defaults to normal.

territory: LuaTerritory

The territory that the segmented unit is assigned to. If nil, the segmented unit will patrol around its spawn location. Must be located on this same surface.