pub struct LuaSurfaceCreateSegmentedUnitParams {
pub force: LuaAny,
pub name: LuaAny,
pub quality: LuaAny,
pub territory: LuaTerritory,
}Expand description
Create a segmented unit on the surface. This differs from creating an entity with type "segmented-unit" in that this method can create the entity in non-generated chunks and with any arbitrary body shape and pre-assigned to a territory.
Fields
force: LuaAnyForce of the segmented unit. Defaults to enemy.
name: LuaAnyThe segmented-unit prototype name to create. Must be of type "segmented-unit".
quality: LuaAnyQuality of the entity to be created. Defaults to normal.
territory: LuaTerritoryThe territory that the segmented unit is assigned to. If nil, the segmented unit will patrol around its spawn location. Must be located on this same surface.