pub struct LuaTrainStopControlBehavior;Expand description
Control behavior for train stops.
Implementations
Sourceimpl LuaTrainStopControlBehavior
impl LuaTrainStopControlBehavior
Sourcepub fn input_networks(&self) -> CircuitNetworkSelection
pub fn input_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to read signals from. Defaults to both wire colors.
nil if this control behavior does not allow selecting the input networks.
Sourcepub fn output_networks(&self) -> CircuitNetworkSelection
pub fn output_networks(&self) -> CircuitNetworkSelection
Which circuit networks (red/green) to send signals to. Defaults to both wire colors.
nil if this control behavior does not allow selecting the output networks.
Sourcepub fn circuit_condition(&self) -> CircuitConditionDefinition
pub fn circuit_condition(&self) -> CircuitConditionDefinition
The circuit condition. Writing nil clears the circuit condition.
Sourcepub fn circuit_enable_disable(&self) -> bool
pub fn circuit_enable_disable(&self) -> bool
true if this entity enable/disable state is controlled by circuit condition
Sourcepub fn connect_to_logistic_network(&self) -> bool
pub fn connect_to_logistic_network(&self) -> bool
true if this should connect to the logistic network.
Sourcepub fn disabled(&self) -> bool
pub fn disabled(&self) -> bool
If the entity is currently disabled because of the control behavior.
Sourcepub fn logistic_condition(&self) -> CircuitConditionDefinition
pub fn logistic_condition(&self) -> CircuitConditionDefinition
The logistic condition. Writing nil clears the logistic condition.
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
The class name of this object. Available even when valid is false. For LuaStruct objects it may also be suffixed with a dotted path to a member of the struct.
Sourcepub fn priority_signal(&self) -> SignalID
pub fn priority_signal(&self) -> SignalID
The signal to be used by set-priority change priority of the train stop
Sourcepub fn read_from_train(&self) -> bool
pub fn read_from_train(&self) -> bool
true if the train stop should send the train contents to the circuit network.
Sourcepub fn read_stopped_train(&self) -> bool
pub fn read_stopped_train(&self) -> bool
true if the train stop should send the stopped train id to the circuit network.
Sourcepub fn read_trains_count(&self) -> bool
pub fn read_trains_count(&self) -> bool
true if the train stop should send amount of incoming trains to the circuit network.
Sourcepub fn send_to_train(&self) -> bool
pub fn send_to_train(&self) -> bool
true if the train stop should send the circuit network contents to the train to use.
Sourcepub fn set_priority(&self) -> bool
pub fn set_priority(&self) -> bool
true if the priority_signal is used to set a priority of the train stop.
Sourcepub fn set_trains_limit(&self) -> bool
pub fn set_trains_limit(&self) -> bool
true if the trains_limit_signal is used to set a limit of trains incoming for train stop.
Sourcepub fn stopped_train_signal(&self) -> SignalID
pub fn stopped_train_signal(&self) -> SignalID
The signal that will be sent when using the send-train-id option.
Sourcepub fn trains_count_signal(&self) -> SignalID
pub fn trains_count_signal(&self) -> SignalID
The signal that will be sent when using the read-trains-count option.
Sourcepub fn trains_limit_signal(&self) -> SignalID
pub fn trains_limit_signal(&self) -> SignalID
The signal to be used by set-trains-limit to limit amount of incoming trains
Sourcepub fn valid(&self) -> bool
pub fn valid(&self) -> bool
Is this object valid? This Lua object holds a reference to an object within the game engine. It is possible that the game-engine object is removed whilst a mod still holds the corresponding Lua object. If that happens, the object becomes invalid, i.e. this attribute will be false. Mods are advised to check for object validity if any change to the game state might have occurred between the creation of the Lua object and its access.
pub fn get_circuit_network( &self, wire_connector_id: &str, ) -> Option<LuaCircuitNetwork>