pub enum ScriptRenderTarget {
Entity(LuaEntity),
Position(MapPosition),
Table(ScriptRenderTargetTable),
}Expand description
When writing it is possible to give LuaEntity or MapPosition directly. However, reading always returns the full ScriptRenderTargetTable.
The full ScriptRenderTargetTable allows specifying cursor targets and an offset for entity targets.
If an entity target of an object (except its orientation_target) is destroyed or changes surface, then the object is also destroyed.
Variants