pub struct BoundingBox {
pub left_top: LuaAny,
pub orientation: LuaAny,
pub right_bottom: LuaAny,
}Expand description
Two positions, specifying the top-left and bottom-right corner of the box respectively. Like with MapPosition, the names of the members may be omitted. When read from the game, the third member orientation is present if it is non-zero.
Fields
left_top: LuaAnyorientation: LuaAnyright_bottom: LuaAnyTrait Implementations
Sourceimpl Clone for BoundingBox
impl Clone for BoundingBox
Sourcefn clone(&self) -> BoundingBox
fn clone(&self) -> BoundingBox
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for BoundingBox
Sourceimpl Debug for BoundingBox
impl Debug for BoundingBox
Sourceimpl Default for BoundingBox
impl Default for BoundingBox
Sourcefn default() -> BoundingBox
fn default() -> BoundingBox
Returns the “default value” for a type. Read more
Sourceimpl From<BoundingBox> for LuaAny
impl From<BoundingBox> for LuaAny
Sourcefn from(_: BoundingBox) -> Self
fn from(_: BoundingBox) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for BoundingBox
impl PartialEq for BoundingBox
impl StructuralPartialEq for BoundingBox