pub struct ScriptRenderTargetTable {
pub entity: LuaEntity,
pub offset: LuaAny,
pub position: LuaAny,
pub type: ScriptRenderTargetTableType,
}Expand description
If an entity target of an object (except its orientation_target) is destroyed or changes surface, then the object is also destroyed.
Targets of type "cursor" draw at the position of the player’s cursor.
Targets of type "build-cursor" draw at the position of the player’s build cursor, including snapping to the build position. The offset is rotated by the entity’s direction and mirrored if the entity to be built is mirrored. Recommended to be combined with ScriptRenderMode::build-cursor.
Fields
entity: LuaEntityoffset: LuaAnyposition: LuaAnytype: ScriptRenderTargetTableTypeTrait Implementations
Sourceimpl Clone for ScriptRenderTargetTable
impl Clone for ScriptRenderTargetTable
Sourcefn clone(&self) -> ScriptRenderTargetTable
fn clone(&self) -> ScriptRenderTargetTable
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ScriptRenderTargetTable
Sourceimpl Debug for ScriptRenderTargetTable
impl Debug for ScriptRenderTargetTable
Sourceimpl Default for ScriptRenderTargetTable
impl Default for ScriptRenderTargetTable
Sourcefn default() -> ScriptRenderTargetTable
fn default() -> ScriptRenderTargetTable
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ScriptRenderTargetTable
impl PartialEq for ScriptRenderTargetTable
impl StructuralPartialEq for ScriptRenderTargetTable