pub type SpritePath = &'static str;Expand description
It can be either the name of a SpritePrototype defined in the data stage, or a path in form “type/name” or “type.name”.
The validity of a SpritePath can be verified at runtime using LuaHelpers::is_valid_sprite_path.