Modules
- alert_
type - behavior_
result - AI command exit status, see LuaCommandable::set_command
- build_
check_ type - build_
mode - cargo_
destination - chain_
signal_ state - State of a chain signal.
- chunk_
generated_ status - command
- Command given to units describing what they should do.
- compound_
command - How commands are joined together in a compound command (see defines.command.compound).
- constant
- control_
behavior - controllers
- deconstruction_
item - difficulty
- direction
- disconnect_
reason - distraction
- electric_
interface_ mode - entity_
status - entity_
status_ diode - events
- See the events page for more info on what events contain and when they get raised.
- flow_
precision_ index - game_
controller_ interaction - group_
state - gui_
type - input_
action - input_
method - inventory
- inventory_
actions - logistic_
group_ type - logistic_
member_ index - logistic_
mode - logistic_
section_ type - mouse_
button_ type - moving_
state - print_
skip - print_
sound - prototypes
- This define describes all top-level prototypes and their associated subtypes. It is organized as a lookup table, meaning the values of all the defines is
0. As an example,defines.prototypes['entity']looks like{furnace=0, inserter=0, container=0, ...}. - rail_
connection_ direction - rail_
direction - rail_
layer - relative_
gui_ position - relative_
gui_ type - render_
mode - rich_
text_ setting - riding
- robot_
order_ type - rocket_
silo_ status - The various parts of the launch sequence of the rocket silo.
- segmented_
unit_ activity_ mode - segmented_
unit_ ai_ state - segmented_
unit_ created_ cause - selection_
mode - shooting
- signal_
state - State of an ordinary rail signal.
- space_
platform_ state - target_
type - territory_
created_ cause - train_
state - transport_
line - wire_
connector_ id - wire_
origin - wire_
type