Only used for sending a space platform starter pack to a platform that is waiting for one. Regular deliveries to space platform hubs use station destination type instead.
Cargo pods will switch destination type from surface to station before starting descent if there is a station available and CargoDestination::position has not been specified. Note, setting the destination to “surface” when the surface is the same as the one the pod is on forces it to find and set a landing position.