Module segmented_unit_activity_mode

Module segmented_unit_activity_mode 

Constants

ASLEEP
The segmented unit is completely asleep, only performing the bare minimum checks to wake up if needed.
FULL
The segmented unit is fully active and simulated as if it is being observed by a player.
MINIMAL
The segmented unit is minimally active, reducing unnecessary entity movement and trigger effects while continuing to patrol around its territory.