The segmented unit is angry because it was attacked but it does not have a valid attack target, so it is wandering around trying to find a valid attack target.
The segmented unit is navigating its territory’s patrol path. If the unit is not assigned to a territory, then it is patrolling around the position it was created.