OnGuiClosedEvent

Struct OnGuiClosedEvent 

pub struct OnGuiClosedEvent {
    pub element: LuaGuiElement,
    pub entity: LuaEntity,
    pub equipment: LuaEquipment,
    pub gui_type: &'static str,
    pub inventory: LuaInventory,
    pub item: LuaItemStack,
    pub name: &'static str,
    pub other_player: LuaPlayer,
    pub player_index: u32,
    pub surface_index: u32,
    pub tick: u32,
    pub tile_position: LuaAny,
}
Called when the player closes the GUI they have open.

This can only be raised when the GUI’s player controller is still valid. If a GUI is thus closed due to the player disconnecting, dying, or becoming a spectator in other ways, it won’t cause this event to be raised.

It’s not advised to open any other GUI during this event because if this is run as a request to open a different GUI the game will force close the new opened GUI without notice to ensure the original requested GUI is opened.

Fields

element: LuaGuiElemententity: LuaEntityequipment: LuaEquipmentgui_type: &'static strinventory: LuaInventoryitem: LuaItemStackname: &'static strother_player: LuaPlayerplayer_index: u32surface_index: u32tick: u32tile_position: LuaAny