OnObjectDestroyedEvent

Struct OnObjectDestroyedEvent 

pub struct OnObjectDestroyedEvent {
    pub name: &'static str,
    pub registration_number: u64,
    pub tick: u32,
    pub type: &'static str,
    pub useful_id: u64,
}
Called after an object is destroyed which was registered with LuaBootstrap::register_on_object_destroyed previously.

Depending on when a given object is destroyed, this event will be fired at the end of the current tick or at the end of the next tick. The event’s timing is independent of the in-world object being destroyed.

Fields

name: &'static strregistration_number: u64tick: u32type: &'static struseful_id: u64