pub struct OnPlayerCraftedItemEvent {
pub item_stack: LuaItemStack,
pub name: &'static str,
pub player_index: u32,
pub recipe: LuaRecipe,
pub tick: u32,
}Expand description
Called when the player finishes crafting an item. This event fires just before the results are inserted into the player’s inventory, not when the crafting is queued (see on_pre_player_crafted_item).
Fields
item_stack: LuaItemStackname: &'static strplayer_index: u32recipe: LuaRecipetick: u32Trait Implementations
Sourceimpl Clone for OnPlayerCraftedItemEvent
impl Clone for OnPlayerCraftedItemEvent
Sourcefn clone(&self) -> OnPlayerCraftedItemEvent
fn clone(&self) -> OnPlayerCraftedItemEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnPlayerCraftedItemEvent
Sourceimpl Debug for OnPlayerCraftedItemEvent
impl Debug for OnPlayerCraftedItemEvent
Sourceimpl Default for OnPlayerCraftedItemEvent
impl Default for OnPlayerCraftedItemEvent
Sourcefn default() -> OnPlayerCraftedItemEvent
fn default() -> OnPlayerCraftedItemEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnPlayerCraftedItemEvent
impl PartialEq for OnPlayerCraftedItemEvent
impl StructuralPartialEq for OnPlayerCraftedItemEvent