pub struct OnPlayerFlippedEntityEvent {
pub entity: LuaEntity,
pub horizontal: bool,
pub name: &'static str,
pub player_index: u32,
pub tick: u32,
}Expand description
Called when the player flips an entity. This event is only fired when the entity actually changes its orientation or mirroring, so it won’t be triggered when pressing the flip keys on an entity that can’t be flipped.
This event reflects a change in the LuaEntity::mirroring property.
Fields
entity: LuaEntityhorizontal: boolname: &'static strplayer_index: u32tick: u32Trait Implementations
Sourceimpl Clone for OnPlayerFlippedEntityEvent
impl Clone for OnPlayerFlippedEntityEvent
Sourcefn clone(&self) -> OnPlayerFlippedEntityEvent
fn clone(&self) -> OnPlayerFlippedEntityEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnPlayerFlippedEntityEvent
Sourceimpl Debug for OnPlayerFlippedEntityEvent
impl Debug for OnPlayerFlippedEntityEvent
Sourceimpl Default for OnPlayerFlippedEntityEvent
impl Default for OnPlayerFlippedEntityEvent
Sourcefn default() -> OnPlayerFlippedEntityEvent
fn default() -> OnPlayerFlippedEntityEvent
Returns the “default value” for a type. Read more
impl StructuralPartialEq for OnPlayerFlippedEntityEvent