OnPlayerRotatedEntityEvent

Struct OnPlayerRotatedEntityEvent 

pub struct OnPlayerRotatedEntityEvent {
    pub entity: LuaEntity,
    pub name: &'static str,
    pub player_index: u32,
    pub previous_direction: &'static str,
    pub previous_mirroring: bool,
    pub tick: u32,
}
Called when the player rotates an entity. This event is only fired when the entity actually changes its orientation – pressing the rotate key on an entity that can’t be rotated won’t fire this event.

Entities being flipped will not fire this event, even if the flip involves rotating. See on_player_flipped_entity.

Fields

entity: LuaEntityname: &'static strplayer_index: u32previous_direction: &'static strprevious_mirroring: booltick: u32