pub struct OnTowerMinedPlantEvent {
pub buffer: LuaInventory,
pub name: &'static str,
pub plant: LuaEntity,
pub tick: u32,
pub tower: LuaEntity,
}Expand description
Called after the results of an entity being mined are collected just before the entity is destroyed.
After this event any items in the buffer will be transferred into the tower as if they came from mining the entity.
The buffer inventory is special in that it’s only valid during this event and has a dynamic size expanding as more items are transferred into it.
Fields
buffer: LuaInventoryname: &'static strplant: LuaEntitytick: u32tower: LuaEntityTrait Implementations
Sourceimpl Clone for OnTowerMinedPlantEvent
impl Clone for OnTowerMinedPlantEvent
Sourcefn clone(&self) -> OnTowerMinedPlantEvent
fn clone(&self) -> OnTowerMinedPlantEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OnTowerMinedPlantEvent
Sourceimpl Debug for OnTowerMinedPlantEvent
impl Debug for OnTowerMinedPlantEvent
Sourceimpl Default for OnTowerMinedPlantEvent
impl Default for OnTowerMinedPlantEvent
Sourcefn default() -> OnTowerMinedPlantEvent
fn default() -> OnTowerMinedPlantEvent
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OnTowerMinedPlantEvent
impl PartialEq for OnTowerMinedPlantEvent
impl StructuralPartialEq for OnTowerMinedPlantEvent