pub struct OnBlueprintSettingsPasted;Expand description
Called when a blueprint entity is pasted over an existing entity or entity ghost.
The entity’s settings, rotation, mirroring, wire connections, etc. may have been updated. This event is raised even if no settings actually changed.
Note this event is not raised when an entity is upgraded or marked for upgrade, when a new entity is created, or when an entity ghost is instantly revived. on_built_entity is raised instead in those cases.
Implementations