pub struct OnObjectDestroyed;Expand description
Called after an object is destroyed which was registered with LuaBootstrap::register_on_object_destroyed previously.
Depending on when a given object is destroyed, this event will be fired at the end of the current tick or at the end of the next tick. The event’s timing is independent of the in-world object being destroyed.
Implementations