pub struct OnPlayerCraftedItem;Expand description
Called when the player finishes crafting an item. This event fires just before the results are inserted into the player’s inventory, not when the crafting is queued (see on_pre_player_crafted_item).
Implementations