pub struct OnPlayerFlippedEntity;Expand description
Called when the player flips an entity. This event is only fired when the entity actually changes its orientation or mirroring, so it won’t be triggered when pressing the flip keys on an entity that can’t be flipped.
This event reflects a change in the LuaEntity::mirroring property.
Implementations