pub struct OnPrePlayerMinedItem;Expand description
Called when the player completes a mining action, but before the entity is potentially removed from the map. This is called even if the entity does not end up being removed.
Implementations