Quality

Struct Quality 

pub struct Quality {
Show 28 fields pub name: &'static str, pub color: Color, pub level: i64, pub hidden: Option<bool>, pub order: Option<&'static str>, pub subgroup: Option<&'static str>, pub icon: Option<&'static str>, pub factoriopedia_description: Option<&'static str>, pub hidden_in_factoriopedia: Option<bool>, pub localised_description: Option<&'static str>, pub localised_name: Option<&'static str>, pub parameter: Option<bool>, pub factoriopedia_alternative: Option<&'static str>, pub accumulator_capacity_multiplier: Option<f64>, pub asteroid_collector_collection_radius_bonus: Option<f64>, pub beacon_module_slots_bonus: Option<i64>, pub beacon_power_usage_multiplier: Option<f64>, pub beacon_supply_area_distance_bonus: Option<f64>, pub cargo_wagon_inventory_size_multiplier: Option<f64>, pub chain_probability: Option<f64>, pub crafting_machine_energy_usage_multiplier: Option<f64>, pub crafting_machine_module_slots_bonus: Option<i64>, pub crafting_machine_speed_multiplier: Option<f64>, pub default_multiplier: Option<f64>, pub draw_sprite_by_default: Option<bool>, pub electric_pole_supply_area_distance_bonus: Option<f64>, pub electric_pole_wire_reach_bonus: Option<f64>, pub equipment_grid_height_bonus: Option<i64>,
}
Minimal QualityPrototype for data.extend.

One quality step. Its effects are specified by the level and the various multiplier and bonus properties. Properties ending in _multiplier are applied multiplicatively to their base property, properties ending in _bonus are applied additively.

type = "quality" is injected by the Lua generator.

Fields

name: &'static str

Unique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.

For a list of all names used in vanilla, see data.raw.

color: Color

Prototype property color.

level: i64

Requires Space Age to use level greater than 0.

hidden: Option<bool>

Prototype property hidden.

order: Option<&'static str>

Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.

subgroup: Option<&'static str>

The name of an ItemSubGroup.

icon: Option<&'static str>

Path to the icon file.

Only loaded, and mandatory if icons is not defined.

factoriopedia_description: Option<&'static str>

Provides additional description used in factoriopedia.

hidden_in_factoriopedia: Option<bool>

Prototype property hidden_in_factoriopedia.

localised_description: Option<&'static str>

Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.

localised_name: Option<&'static str>

Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.

parameter: Option<bool>

Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.

factoriopedia_alternative: Option<&'static str>

The ID type corresponding to the prototype that inherits from this.

For example, if this is an EntityPrototype, this property’s type is EntityID.

accumulator_capacity_multiplier: Option<f64>

Must be >= 0.01.

asteroid_collector_collection_radius_bonus: Option<f64>

Must be >= 0.

Performance warning: the navigation has to pre-calculate ranges for the highest tier collector possible, so you should keep this collection radius within reasonable values.

beacon_module_slots_bonus: Option<i64>

Only affects beacons with BeaconPrototype::quality_affects_module_slots set.

beacon_power_usage_multiplier: Option<f64>

Must be >= 0.01.

beacon_supply_area_distance_bonus: Option<f64>

Only affects beacons with BeaconPrototype::quality_affects_supply_area_distance set.

Must be >= 0 and <= 64.

cargo_wagon_inventory_size_multiplier: Option<f64>

Must be >= 0.01.

chain_probability: Option<f64>

Probability of additional quality increase happening after quality was increased to reach this quality in the same crafting/mining operation.

Must be in range [0, 1].

crafting_machine_energy_usage_multiplier: Option<f64>

Must be >= 0.01.

Only affects crafting machines with CraftingMachinePrototype::quality_affects_energy_usage set.

Will be ignored by crafting machines with CraftingMachinePrototype::energy_usage_quality_multiplier set.

crafting_machine_module_slots_bonus: Option<i64>

Only affects crafting machines with CraftingMachinePrototype::quality_affects_module_slots set.

Will be ignored by crafting machines with CraftingMachinePrototype::module_slots_quality_bonus set.

crafting_machine_speed_multiplier: Option<f64>

Must be >= 0.01.

Will be ignored by crafting machines with CraftingMachinePrototype::crafting_speed_quality_multiplier set.

default_multiplier: Option<f64>

Must be >= 0.01.

draw_sprite_by_default: Option<bool>

Prototype property draw_sprite_by_default.

electric_pole_supply_area_distance_bonus: Option<f64>

Must be >= 0.

electric_pole_wire_reach_bonus: Option<f64>

Must be >= 0.

equipment_grid_height_bonus: Option<i64>

Prototype property equipment_grid_height_bonus.