pub struct Tile {Show 30 fields
pub name: &'static str,
pub layer: i64,
pub map_color: Color,
pub collision_mask: LuaAny,
pub variants: LuaAny,
pub hidden: Option<bool>,
pub order: Option<&'static str>,
pub subgroup: Option<&'static str>,
pub icon: Option<&'static str>,
pub factoriopedia_description: Option<&'static str>,
pub hidden_in_factoriopedia: Option<bool>,
pub localised_description: Option<&'static str>,
pub localised_name: Option<&'static str>,
pub parameter: Option<bool>,
pub factoriopedia_alternative: Option<&'static str>,
pub allowed_neighbors: Option<&'static [&'static str]>,
pub allows_being_covered: Option<bool>,
pub ambient_sounds_group: Option<&'static str>,
pub built_animation_frame: Option<i64>,
pub can_be_part_of_blueprint: Option<bool>,
pub check_collision_with_entities: Option<bool>,
pub decorative_removal_probability: Option<f64>,
pub default_cover_tile: Option<&'static str>,
pub destroys_dropped_items: Option<bool>,
pub effect: Option<&'static str>,
pub effect_color: Option<Color>,
pub effect_color_secondary: Option<Color>,
pub effect_is_opaque: Option<bool>,
pub fluid: Option<&'static str>,
pub frozen_variant: Option<&'static str>,
}Expand description
Fields
name: &'static strUnique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.
For a list of all names used in vanilla, see data.raw.
layer: i64Specifies transition drawing priority. This represents the positive offset from this tile’s layer_group. Internally, the final layer is computed as layer_group + layer (a uint16), wrapping back to "zero" after the "top" layer.
map_color: ColorPrototype property map_color.
collision_mask: LuaAnyPrototype property collision_mask.
variants: LuaAnyGraphics for this tile.
Prototype property hidden.
order: Option<&'static str>Used to order prototypes in inventory, recipes and GUIs. May not exceed a length of 200 characters.
subgroup: Option<&'static str>The name of an ItemSubGroup.
icon: Option<&'static str>Path to the icon file. If this and icons is not set, the material_background in variants is used as the icon.
Only loaded if icons is not defined.
factoriopedia_description: Option<&'static str>Provides additional description used in factoriopedia.
Prototype property hidden_in_factoriopedia.
localised_description: Option<&'static str>Overwrites the description set in the locale file. The description is usually shown in the tooltip of the prototype.
localised_name: Option<&'static str>Overwrites the name set in the locale file. Can be used to easily set a procedurally-generated name because the LocalisedString format allows to insert parameters into the name directly from the Lua script.
parameter: Option<bool>Whether the prototype is a special type which can be used to parametrize blueprints and doesn’t have other function.
factoriopedia_alternative: Option<&'static str>The ID type corresponding to the prototype that inherits from this.
For example, if this is an EntityPrototype, this property’s type is EntityID.
allowed_neighbors: Option<&'static [&'static str]>Array of tile names that are allowed next to this one.
allows_being_covered: Option<bool>Prototype property allows_being_covered.
ambient_sounds_group: Option<&'static str>Prototype property ambient_sounds_group.
built_animation_frame: Option<i64>When the build_animations frame reaches this point the tile is built.
Mandatory if build_animations is defined.
can_be_part_of_blueprint: Option<bool>Prototype property can_be_part_of_blueprint.
check_collision_with_entities: Option<bool>If set to true, the game will check for collisions with entities before building or mining the tile. If entities are in the way it is not possible to mine/build the tile.
decorative_removal_probability: Option<f64>Prototype property decorative_removal_probability.
default_cover_tile: Option<&'static str>Prototype property default_cover_tile.
destroys_dropped_items: Option<bool>If items dropped on this tile are destroyed.
effect: Option<&'static str>Prototype property effect.
effect_color: Option<Color>Prototype property effect_color.
effect_color_secondary: Option<Color>Used by the pollution shader.
effect_is_opaque: Option<bool>Prototype property effect_is_opaque.
fluid: Option<&'static str>Prototype property fluid.
frozen_variant: Option<&'static str>Prototype property frozen_variant.