UtilityConstants

Struct UtilityConstants 

pub struct UtilityConstants {
Show 40 fields pub name: &'static str, pub agricultural_range_visualization_color: Color, pub artillery_range_visualization_color: Color, pub asteroid_collector_blockage_update_tile_distance: i64, pub asteroid_collector_max_nurbs_control_point_separation: f64, pub asteroid_collector_navmesh_refresh_tick_interval: i64, pub asteroid_collector_static_head_swing_segment_count: i64, pub asteroid_collector_static_head_swing_strength_scale: f64, pub asteroid_fading_range: f64, pub asteroid_position_offset_to_speed_coefficient: f64, pub asteroid_spawning_with_random_orientation_max_speed: f64, pub blueprint_big_slots_per_row: i64, pub blueprint_small_slots_per_row: i64, pub building_buildable_tint: Color, pub building_buildable_too_far_tint: Color, pub building_ignorable_tint: Color, pub building_no_tint: Color, pub building_not_buildable_tint: Color, pub capsule_range_visualization_color: Color, pub capture_water_mask_at_layer: i64, pub chart_search_highlight: Color, pub checkerboard_black: Color, pub checkerboard_white: Color, pub clear_cursor_volume_modifier: f64, pub clipboard_history_size: i64, pub construction_robots_use_busy_robots_queue: bool, pub count_button_size: i64, pub crafting_queue_slots_per_row: i64, pub deconstruct_mark_tint: Color, pub default_alert_icon_scale: f64, pub default_enemy_force_color: Color, pub default_item_weight: f64, pub default_other_force_color: Color, pub default_pipeline_extent: f64, pub default_player_force_color: Color, pub default_rocket_lift_weight: f64, pub default_scorch_mark_color: Color, pub disabled_recipe_slot_background_tint: Color, pub disabled_recipe_slot_tint: Color, pub drop_item_radius: f64,
}
Minimal UtilityConstants for data.extend.

Constants used by the game that are not specific to certain prototypes. See utility-constants.lua for the values used by the base game.

type = "utility-constants" is injected by the Lua generator.

Fields

name: &'static str

Unique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.

For a list of all names used in vanilla, see data.raw.

agricultural_range_visualization_color: Color

Prototype property agricultural_range_visualization_color.

artillery_range_visualization_color: Color

Prototype property artillery_range_visualization_color.

asteroid_collector_blockage_update_tile_distance: i64

Prototype property asteroid_collector_blockage_update_tile_distance.

asteroid_collector_max_nurbs_control_point_separation: f64

Prototype property asteroid_collector_max_nurbs_control_point_separation.

asteroid_collector_navmesh_refresh_tick_interval: i64

Prototype property asteroid_collector_navmesh_refresh_tick_interval.

asteroid_collector_static_head_swing_segment_count: i64

Prototype property asteroid_collector_static_head_swing_segment_count.

asteroid_collector_static_head_swing_strength_scale: f64

Prototype property asteroid_collector_static_head_swing_strength_scale.

asteroid_fading_range: f64

Prototype property asteroid_fading_range.

asteroid_position_offset_to_speed_coefficient: f64

Prototype property asteroid_position_offset_to_speed_coefficient.

asteroid_spawning_with_random_orientation_max_speed: f64

Prototype property asteroid_spawning_with_random_orientation_max_speed.

blueprint_big_slots_per_row: i64

Will be clamped to the range [2, 100].

blueprint_small_slots_per_row: i64

Will be clamped to the range [2, 100].

building_buildable_tint: Color

Prototype property building_buildable_tint.

building_buildable_too_far_tint: Color

Prototype property building_buildable_too_far_tint.

building_ignorable_tint: Color

Prototype property building_ignorable_tint.

building_no_tint: Color

Prototype property building_no_tint.

building_not_buildable_tint: Color

Prototype property building_not_buildable_tint.

capsule_range_visualization_color: Color

Prototype property capsule_range_visualization_color.

capture_water_mask_at_layer: i64

Layer within ground-natural tile render layer group, before which terrain lightmap alpha channel is copied into water mask. Decals, which need to be masked by water should have their DecorativePrototype::tile_layer set to only slightly larger value than capture_water_mask_at_layer, to avoid risk of undefined behavior caused by rendering tiles into layers between capture_water_mask_at_layer and decal’s tile_layer.

chart_search_highlight: Color

Prototype property chart_search_highlight.

checkerboard_black: Color

Prototype property checkerboard_black.

checkerboard_white: Color

Prototype property checkerboard_white.

clear_cursor_volume_modifier: f64

Prototype property clear_cursor_volume_modifier.

clipboard_history_size: i64

Prototype property clipboard_history_size.

construction_robots_use_busy_robots_queue: bool

Prototype property construction_robots_use_busy_robots_queue.

count_button_size: i64

Prototype property count_button_size.

crafting_queue_slots_per_row: i64

Will be clamped to the range [1, 100].

deconstruct_mark_tint: Color

Prototype property deconstruct_mark_tint.

default_alert_icon_scale: f64

Prototype property default_alert_icon_scale.

default_enemy_force_color: Color

Prototype property default_enemy_force_color.

default_item_weight: f64

Prototype property default_item_weight.

default_other_force_color: Color

Prototype property default_other_force_color.

default_pipeline_extent: f64

The default value of FluidBox::max_pipeline_extent.

default_player_force_color: Color

Prototype property default_player_force_color.

default_rocket_lift_weight: f64

Used for “Rocket capacity” item tooltip and for comparing rocket silo lift weight in GUI to this value.

default_scorch_mark_color: Color

Prototype property default_scorch_mark_color.

disabled_recipe_slot_background_tint: Color

Prototype property disabled_recipe_slot_background_tint.

disabled_recipe_slot_tint: Color

Prototype property disabled_recipe_slot_tint.

drop_item_radius: f64

Prototype property drop_item_radius.