UtilitySounds

Struct UtilitySounds 

pub struct UtilitySounds {
Show 40 fields pub name: &'static str, pub achievement_unlocked: LuaAny, pub adjust_blueprint_snapping: LuaAny, pub alert_destroyed: LuaAny, pub armor_insert: LuaAny, pub armor_remove: LuaAny, pub axe_fighting: LuaAny, pub axe_mining_ore: LuaAny, pub axe_mining_stone: LuaAny, pub blueprint_preview_build: LuaAny, pub blueprint_preview_mine: LuaAny, pub build_animated_huge: LuaAny, pub build_animated_large: LuaAny, pub build_animated_medium: LuaAny, pub build_animated_small: LuaAny, pub build_behemoth: LuaAny, pub build_blueprint_huge: LuaAny, pub build_blueprint_large: LuaAny, pub build_blueprint_medium: LuaAny, pub build_blueprint_small: LuaAny, pub build_ghost_upgrade: LuaAny, pub build_ghost_upgrade_cancel: LuaAny, pub build_huge: LuaAny, pub build_large: LuaAny, pub build_medium: LuaAny, pub build_small: LuaAny, pub cannot_build: LuaAny, pub change_quality: LuaAny, pub clear_cursor: LuaAny, pub confirm: LuaAny, pub console_message: LuaAny, pub console_platform_created: LuaAny, pub console_platform_destroyed: LuaAny, pub console_player_changed_logistic_group: LuaAny, pub console_player_died: LuaAny, pub console_player_joined: LuaAny, pub console_player_left: LuaAny, pub console_player_paused_game: LuaAny, pub console_player_research: LuaAny, pub console_player_respawned: LuaAny,
}
Minimal UtilitySounds for data.extend.

Sounds used by the game that are not specific to certain prototypes.

type = "utility-sounds" is injected by the Lua generator.

Fields

name: &'static str

Unique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.

For a list of all names used in vanilla, see data.raw.

achievement_unlocked: LuaAny

Sound category "gui-effect".

adjust_blueprint_snapping: LuaAny

Sound category "gui-effect".

alert_destroyed: LuaAny

Sound category "alert".

armor_insert: LuaAny

Sound category "gui-effect".

armor_remove: LuaAny

Sound category "gui-effect".

axe_fighting: LuaAny

Sound category "game-effect".

axe_mining_ore: LuaAny

Sound category "game-effect".

axe_mining_stone: LuaAny

Sound category "game-effect".

blueprint_preview_build: LuaAny

Sound category "gui-effect".

blueprint_preview_mine: LuaAny

Sound category "gui-effect".

build_animated_huge: LuaAny

Sound category "game-effect".

build_animated_large: LuaAny

Sound category "game-effect".

build_animated_medium: LuaAny

Sound category "game-effect".

build_animated_small: LuaAny

Sound category "game-effect".

build_behemoth: LuaAny

Sound category "game-effect".

build_blueprint_huge: LuaAny

Sound category "game-effect".

build_blueprint_large: LuaAny

Sound category "game-effect".

build_blueprint_medium: LuaAny

Sound category "game-effect".

build_blueprint_small: LuaAny

Sound category "game-effect".

build_ghost_upgrade: LuaAny

Sound category "game-effect".

build_ghost_upgrade_cancel: LuaAny

Sound category "game-effect".

build_huge: LuaAny

Sound category "game-effect".

build_large: LuaAny

Sound category "game-effect".

build_medium: LuaAny

Sound category "game-effect".

build_small: LuaAny

Sound category "game-effect".

cannot_build: LuaAny

Sound category "gui-effect".

change_quality: LuaAny

Sound category "gui-effect".

clear_cursor: LuaAny

Sound category "gui-effect".

confirm: LuaAny

Sound category "gui-effect".

console_message: LuaAny

Sound category "gui-effect".

console_platform_created: LuaAny

Sound category "gui-effect".

console_platform_destroyed: LuaAny

Sound category "gui-effect".

console_player_changed_logistic_group: LuaAny

Sound category "gui-effect".

console_player_died: LuaAny

Sound category "gui-effect".

console_player_joined: LuaAny

Sound category "gui-effect".

console_player_left: LuaAny

Sound category "gui-effect".

console_player_paused_game: LuaAny

Sound category "gui-effect".

console_player_research: LuaAny

Sound category "gui-effect".

console_player_respawned: LuaAny

Sound category "gui-effect".