UtilitySprites

Struct UtilitySprites 

pub struct UtilitySprites {
Show 40 fields pub name: &'static str, pub achievement_label: LuaAny, pub achievement_label_completed: LuaAny, pub achievement_label_failed: LuaAny, pub achievement_warning: LuaAny, pub add: LuaAny, pub add_white: LuaAny, pub alert_arrow: LuaAny, pub ammo_damage_modifier_icon: LuaAny, pub ammo_icon: LuaAny, pub and_or: LuaAny, pub any_quality: LuaAny, pub area_icon: LuaAny, pub arrow_button: LuaAny, pub artillery_range_modifier_icon: LuaAny, pub asteroid_chunk_editor_icon: LuaAny, pub asteroid_collector_path_blocked_icon: LuaAny, pub backward_arrow: LuaAny, pub backward_arrow_black: LuaAny, pub bar_gray_pip: LuaAny, pub battery: LuaAny, pub beacon_distribution_modifier_icon: LuaAny, pub belt_stack_size_bonus_modifier_icon: LuaAny, pub bookmark: LuaAny, pub brush_circle_shape: LuaAny, pub brush_icon: LuaAny, pub brush_square_shape: LuaAny, pub buildability_collision: LuaAny, pub buildability_collision_elevated: LuaAny, pub buildability_elevated_collision_bottom: LuaAny, pub buildability_elevated_collision_line: LuaAny, pub buildability_elevated_collision_top: LuaAny, pub bulk_inserter_capacity_bonus_modifier_icon: LuaAny, pub cable_editor_icon: LuaAny, pub cargo_bay_not_connected_icon: LuaAny, pub cargo_bay_too_far_from_source_icon: LuaAny, pub cargo_landing_pad_count_modifier_icon: LuaAny, pub center: LuaAny, pub change_recipe: LuaAny, pub change_recipe_productivity_modifier_icon: LuaAny,
}
Minimal UtilitySprites for data.extend.

Sprites used by the game that are not specific to certain prototypes.

type = "utility-sprites" is injected by the Lua generator.

Fields

name: &'static str

Unique textual identification of the prototype. May only contain alphanumeric characters, dashes and underscores. May not exceed a length of 200 characters.

For a list of all names used in vanilla, see data.raw.

achievement_label: LuaAny

Prototype property achievement_label.

achievement_label_completed: LuaAny

Prototype property achievement_label_completed.

achievement_label_failed: LuaAny

Prototype property achievement_label_failed.

achievement_warning: LuaAny

Prototype property achievement_warning.

add: LuaAny

Prototype property add.

add_white: LuaAny

Prototype property add_white.

alert_arrow: LuaAny

Prototype property alert_arrow.

ammo_damage_modifier_icon: LuaAny

Prototype property ammo_damage_modifier_icon.

ammo_icon: LuaAny

Prototype property ammo_icon.

and_or: LuaAny

Prototype property and_or.

any_quality: LuaAny

Prototype property any_quality.

area_icon: LuaAny

Prototype property area_icon.

arrow_button: LuaAny

Prototype property arrow_button.

artillery_range_modifier_icon: LuaAny

Prototype property artillery_range_modifier_icon.

asteroid_chunk_editor_icon: LuaAny

Prototype property asteroid_chunk_editor_icon.

asteroid_collector_path_blocked_icon: LuaAny

Prototype property asteroid_collector_path_blocked_icon.

backward_arrow: LuaAny

Prototype property backward_arrow.

backward_arrow_black: LuaAny

Prototype property backward_arrow_black.

bar_gray_pip: LuaAny

Prototype property bar_gray_pip.

battery: LuaAny

Prototype property battery.

beacon_distribution_modifier_icon: LuaAny

Prototype property beacon_distribution_modifier_icon.

belt_stack_size_bonus_modifier_icon: LuaAny

Prototype property belt_stack_size_bonus_modifier_icon.

bookmark: LuaAny

Prototype property bookmark.

brush_circle_shape: LuaAny

Prototype property brush_circle_shape.

brush_icon: LuaAny

Prototype property brush_icon.

brush_square_shape: LuaAny

Prototype property brush_square_shape.

buildability_collision: LuaAny

Prototype property buildability_collision.

buildability_collision_elevated: LuaAny

Prototype property buildability_collision_elevated.

buildability_elevated_collision_bottom: LuaAny

Prototype property buildability_elevated_collision_bottom.

buildability_elevated_collision_line: LuaAny

Prototype property buildability_elevated_collision_line.

buildability_elevated_collision_top: LuaAny

Prototype property buildability_elevated_collision_top.

bulk_inserter_capacity_bonus_modifier_icon: LuaAny

Prototype property bulk_inserter_capacity_bonus_modifier_icon.

cable_editor_icon: LuaAny

Prototype property cable_editor_icon.

cargo_bay_not_connected_icon: LuaAny

Prototype property cargo_bay_not_connected_icon.

cargo_bay_too_far_from_source_icon: LuaAny

Prototype property cargo_bay_too_far_from_source_icon.

cargo_landing_pad_count_modifier_icon: LuaAny

Prototype property cargo_landing_pad_count_modifier_icon.

center: LuaAny

Prototype property center.

change_recipe: LuaAny

Prototype property change_recipe.

change_recipe_productivity_modifier_icon: LuaAny

Prototype property change_recipe_productivity_modifier_icon.