pub enum SoundType {
GameEffect,
GuiEffect,
Ambient,
Environment,
Walking,
Alert,
Wind,
WorldAmbient,
Weapon,
Explosion,
Enemy,
}Expand description
Defines which slider in the game’s sound settings affects the volume of this sound. Furthermore, some sound types are mixed differently than others, e.g. zoom level effects are applied.
Variants
Implementations