pub enum VerticalTextAlign {
Top,
Middle,
Baseline,
Bottom,
}Expand description
The text is aligned so that the target position is at the given side of the text.
For example, "top" aligned text means the top of the text is at the target position. Or in other words, the target is at the top of the text.
Variants
Implementations